Learn R Programming

paws.management (version 0.2.0)

applicationcostprofiler_get_report_definition: Retrieves the definition of a report already configured in AWS Application Cost Profiler

Description

Retrieves the definition of a report already configured in AWS Application Cost Profiler.

See https://paws-r.github.io/docs/applicationcostprofiler/get_report_definition.html for full documentation.

Usage

applicationcostprofiler_get_report_definition(reportId)

Arguments

reportId

[required] ID of the report to retrieve.