Learn R Programming

paws.management (version 0.2.0)

applicationcostprofiler_list_report_definitions: Retrieves a list of all reports and their configurations for your AWS account

Description

Retrieves a list of all reports and their configurations for your AWS account.

See https://paws-r.github.io/docs/applicationcostprofiler/list_report_definitions.html for full documentation.

Usage

applicationcostprofiler_list_report_definitions(
  nextToken = NULL,
  maxResults = NULL
)

Arguments

nextToken

The token value from a previous call to access the next page of results.

maxResults

The maximum number of results to return.