Learn R Programming

paws.management (version 0.2.0)

applicationinsights_create_component: Creates a custom component by grouping similar standalone instances to monitor

Description

Creates a custom component by grouping similar standalone instances to monitor.

See https://paws-r.github.io/docs/applicationinsights/create_component.html for full documentation.

Usage

applicationinsights_create_component(
  ResourceGroupName,
  ComponentName,
  ResourceList
)

Arguments

ResourceGroupName

[required] The name of the resource group.

ComponentName

[required] The name of the component.

ResourceList

[required] The list of resource ARNs that belong to the component.