Learn R Programming

paws.management (version 0.2.0)

applicationinsights_delete_component: Ungroups a custom component

Description

Ungroups a custom component. When you ungroup custom components, all applicable monitors that are set up for the component are removed and the instances revert to their standalone status.

See https://paws-r.github.io/docs/applicationinsights/delete_component.html for full documentation.

Usage

applicationinsights_delete_component(ResourceGroupName, ComponentName)

Arguments

ResourceGroupName

[required] The name of the resource group.

ComponentName

[required] The name of the component.