Learn R Programming

paws.management (version 0.2.0)

applicationinsights_describe_component: Describes a component and lists the resources that are grouped together in a component

Description

Describes a component and lists the resources that are grouped together in a component.

See https://paws-r.github.io/docs/applicationinsights/describe_component.html for full documentation.

Usage

applicationinsights_describe_component(ResourceGroupName, ComponentName)

Arguments

ResourceGroupName

[required] The name of the resource group.

ComponentName

[required] The name of the component.