Lists the auto-grouped, standalone, and custom components of the application.
See https://paws-r.github.io/docs/applicationinsights/list_components.html for full documentation.
applicationinsights_list_components(
ResourceGroupName,
MaxResults = NULL,
NextToken = NULL
)[required] The name of the resource group.
The maximum number of results to return in a single call. To retrieve
the remaining results, make another call with the returned NextToken
value.
The token to request the next page of results.