Learn R Programming

paws.management (version 0.2.0)

applicationinsights_list_log_patterns: Lists the log patterns in the specific log LogPatternSet

Description

Lists the log patterns in the specific log LogPatternSet.

See https://paws-r.github.io/docs/applicationinsights/list_log_patterns.html for full documentation.

Usage

applicationinsights_list_log_patterns(
  ResourceGroupName,
  PatternSetName = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

ResourceGroupName

[required] The name of the resource group.

PatternSetName

The name of the log pattern set.

MaxResults

The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value.

NextToken

The token to request the next page of results.