Learn R Programming

paws.management (version 0.2.0)

appregistry_associate_attribute_group: Associates an attribute group with an application to augment the application's metadata with the group's attributes

Description

Associates an attribute group with an application to augment the application's metadata with the group's attributes. This feature enables applications to be described with user-defined details that are machine-readable, such as third-party integrations.

See https://paws-r.github.io/docs/appregistry/associate_attribute_group.html for full documentation.

Usage

appregistry_associate_attribute_group(application, attributeGroup)

Arguments

application

[required] The name or ID of the application.

attributeGroup

[required] The name or ID of the attribute group that holds the attributes to describe the application.