Learn R Programming

paws.management (version 0.2.0)

appregistry_associate_resource: Associates a resource with an application

Description

Associates a resource with an application. Both the resource and the application can be specified either by ID or name.

See https://paws-r.github.io/docs/appregistry/associate_resource.html for full documentation.

Usage

appregistry_associate_resource(application, resourceType, resource)

Arguments

application

[required] The name or ID of the application.

resourceType

[required] The type of resource of which the application will be associated.

resource

[required] The name or ID of the resource of which the application will be associated.