Learn R Programming

paws.management (version 0.2.0)

appregistry_create_application: Creates a new application that is the top-level node in a hierarchy of related cloud resource abstractions

Description

Creates a new application that is the top-level node in a hierarchy of related cloud resource abstractions.

See https://paws-r.github.io/docs/appregistry/create_application.html for full documentation.

Usage

appregistry_create_application(
  name,
  description = NULL,
  tags = NULL,
  clientToken
)

Arguments

name

[required] The name of the application. The name must be unique in the region in which you are creating the application.

description

The description of the application.

tags

Key-value pairs you can use to associate with the application.

clientToken

[required] A unique identifier that you provide to ensure idempotency. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails.