Learn R Programming

paws.management (version 0.2.0)

appregistry_delete_application: Deletes an application that is specified either by its application ID or name

Description

Deletes an application that is specified either by its application ID or name. All associated attribute groups and resources must be disassociated from it before deleting an application.

See https://paws-r.github.io/docs/appregistry/delete_application.html for full documentation.

Usage

appregistry_delete_application(application)

Arguments

application

[required] The name or ID of the application.