Disassociates an attribute group from an application to remove the extra attributes contained in the attribute group from the application's metadata. This operation reverts associate_attribute_group.
See https://paws-r.github.io/docs/appregistry/disassociate_attribute_group.html for full documentation.
appregistry_disassociate_attribute_group(application, attributeGroup)[required] The name or ID of the application.
[required] The name or ID of the attribute group that holds the attributes to describe the application.