Learn R Programming

paws.management (version 0.2.0)

appregistry_disassociate_resource: Disassociates a resource from application

Description

Disassociates a resource from application. Both the resource and the application can be specified either by ID or name.

See https://paws-r.github.io/docs/appregistry/disassociate_resource.html for full documentation.

Usage

appregistry_disassociate_resource(application, resourceType, resource)

Arguments

application

[required] The name or ID of the application.

resourceType

[required] The type of the resource that is being disassociated.

resource

[required] The name or ID of the resource.