Learn R Programming

paws.management (version 0.2.0)

appregistry_get_attribute_group: Retrieves an attribute group, either by its name or its ID

Description

Retrieves an attribute group, either by its name or its ID. The attribute group can be specified either by its unique ID or by its name.

See https://paws-r.github.io/docs/appregistry/get_attribute_group.html for full documentation.

Usage

appregistry_get_attribute_group(attributeGroup)

Arguments

attributeGroup

[required] The name or ID of the attribute group that holds the attributes to describe the application.