Retrieves a list of all of your applications. Results are paginated.
See https://paws-r.github.io/docs/appregistry/list_applications.html for full documentation.
appregistry_list_applications(nextToken = NULL, maxResults = NULL)The token to use to get the next page of results after a previous API call.
The upper bound of the number of results to return (cannot exceed 25). If this parameter is omitted, it defaults to 25. This value is optional.