Lists all attribute groups that are associated with specified application. Results are paginated.
See https://paws-r.github.io/docs/appregistry/list_associated_attribute_groups.html for full documentation.
appregistry_list_associated_attribute_groups(
application,
nextToken = NULL,
maxResults = NULL
)[required] The name or ID of the application.
The token to use to get the next page of results after a previous API call.
The upper bound of the number of results to return (cannot exceed 25). If this parameter is omitted, it defaults to 25. This value is optional.