Learn R Programming

paws.management (version 0.2.0)

appregistry_list_attribute_groups: Lists all attribute groups which you have access to

Description

Lists all attribute groups which you have access to. Results are paginated.

See https://paws-r.github.io/docs/appregistry/list_attribute_groups.html for full documentation.

Usage

appregistry_list_attribute_groups(nextToken = NULL, maxResults = NULL)

Arguments

nextToken

The token to use to get the next page of results after a previous API call.

maxResults

The upper bound of the number of results to return (cannot exceed 25). If this parameter is omitted, it defaults to 25. This value is optional.