Learn R Programming

paws.management (version 0.2.0)

appregistry_sync_resource: Syncs the resource with current AppRegistry records

Description

Syncs the resource with current AppRegistry records.

See https://paws-r.github.io/docs/appregistry/sync_resource.html for full documentation.

Usage

appregistry_sync_resource(resourceType, resource)

Arguments

resourceType

[required] The type of resource of which the application will be associated.

resource

[required] An entity you can work with and specify with a name or ID. Examples include an Amazon EC2 instance, an Amazon Web Services CloudFormation stack, or an Amazon S3 bucket.