Updates an existing application with new attributes.
See https://paws-r.github.io/docs/appregistry/update_application.html for full documentation.
appregistry_update_application(application, name = NULL, description = NULL)[required] The name or ID of the application that will be updated.
Deprecated: The new name of the application. The name must be unique in the region in which you are updating the application. Please do not use this field as we have stopped supporting name updates.
The new description of the application.