Creates a custom framework in Audit Manager.
See https://paws-r.github.io/docs/auditmanager/create_assessment_framework.html for full documentation.
auditmanager_create_assessment_framework(
name,
description = NULL,
complianceType = NULL,
controlSets,
tags = NULL
)[required] The name of the new custom framework.
An optional description for the new custom framework.
The compliance type that the new custom framework supports, such as CIS or HIPAA.
[required] The control sets that are associated with the framework.
The tags that are associated with the framework.