Learn R Programming

paws.management (version 0.2.0)

auditmanager_deregister_organization_admin_account: Removes the specified Amazon Web Services account as a delegated administrator for Audit Manager

Description

Removes the specified Amazon Web Services account as a delegated administrator for Audit Manager.

See https://paws-r.github.io/docs/auditmanager/deregister_organization_admin_account.html for full documentation.

Usage

auditmanager_deregister_organization_admin_account(adminAccountId = NULL)

Arguments

adminAccountId

The identifier for the administrator account.