Returns a list of delegations from an audit owner to a delegate.
See https://paws-r.github.io/docs/auditmanager/get_delegations.html for full documentation.
auditmanager_get_delegations(nextToken = NULL, maxResults = NULL)The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.