Returns the evidence folders from a specified assessment in Audit Manager.
See https://paws-r.github.io/docs/auditmanager/get_evidence_folders_by_assessment.html for full documentation.
auditmanager_get_evidence_folders_by_assessment(
assessmentId,
nextToken = NULL,
maxResults = NULL
)[required] The unique identifier for the assessment.
The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.