Learn R Programming

paws.management (version 0.2.0)

auditmanager_get_evidence_folders_by_assessment_control: Returns a list of evidence folders that are associated with a specified control of an assessment in Audit Manager

Description

Returns a list of evidence folders that are associated with a specified control of an assessment in Audit Manager.

See https://paws-r.github.io/docs/auditmanager/get_evidence_folders_by_assessment_control.html for full documentation.

Usage

auditmanager_get_evidence_folders_by_assessment_control(
  assessmentId,
  controlSetId,
  controlId,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

assessmentId

[required] The identifier for the assessment.

controlSetId

[required] The identifier for the control set.

controlId

[required] The identifier for the control.

nextToken

The pagination token that's used to fetch the next set of results.

maxResults

Represents the maximum number of results on a page or for an API request call.