Learn R Programming

paws.management (version 0.2.0)

auditmanager_get_organization_admin_account: Returns the name of the delegated Amazon Web Services administrator account for the organization

Description

Returns the name of the delegated Amazon Web Services administrator account for the organization.

See https://paws-r.github.io/docs/auditmanager/get_organization_admin_account.html for full documentation.

Usage

auditmanager_get_organization_admin_account()

Arguments