Learn R Programming

paws.management (version 0.2.0)

auditmanager_get_settings: Returns the settings for the specified Amazon Web Services account

Description

Returns the settings for the specified Amazon Web Services account.

See https://paws-r.github.io/docs/auditmanager/get_settings.html for full documentation.

Usage

auditmanager_get_settings(attribute)

Arguments

attribute

[required] The list of SettingAttribute enum values.