Returns a list of sent or received share requests for custom frameworks in Audit Manager.
See https://paws-r.github.io/docs/auditmanager/list_assessment_framework_share_requests.html for full documentation.
auditmanager_list_assessment_framework_share_requests(
requestType,
nextToken = NULL,
maxResults = NULL
)[required] Specifies whether the share request is a sent request or a received request.
The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.