Learn R Programming

paws.management (version 0.2.0)

auditmanager_list_assessment_frameworks: Returns a list of the frameworks that are available in the Audit Manager framework library

Description

Returns a list of the frameworks that are available in the Audit Manager framework library.

See https://paws-r.github.io/docs/auditmanager/list_assessment_frameworks.html for full documentation.

Usage

auditmanager_list_assessment_frameworks(
  frameworkType,
  nextToken = NULL,
  maxResults = NULL
)

Arguments

frameworkType

[required] The type of framework, such as a standard framework or a custom framework.

nextToken

The pagination token that's used to fetch the next set of results.

maxResults

Represents the maximum number of results on a page or for an API request call.