Returns a list of current and past assessments from Audit Manager.
See https://paws-r.github.io/docs/auditmanager/list_assessments.html for full documentation.
auditmanager_list_assessments(
status = NULL,
nextToken = NULL,
maxResults = NULL
)The current status of the assessment.
The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.