Lists the latest analytics data for control domains across all of your active assessments.
See https://paws-r.github.io/docs/auditmanager/list_control_domain_insights.html for full documentation.
auditmanager_list_control_domain_insights(nextToken = NULL, maxResults = NULL)The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.