Lists analytics data for control domains within a specified active assessment.
See https://paws-r.github.io/docs/auditmanager/list_control_domain_insights_by_assessment.html for full documentation.
auditmanager_list_control_domain_insights_by_assessment(
assessmentId,
nextToken = NULL,
maxResults = NULL
)[required] The unique identifier for the active assessment.
The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.