Lists the latest analytics data for controls within a specific control domain across all active assessments.
See https://paws-r.github.io/docs/auditmanager/list_control_insights_by_control_domain.html for full documentation.
auditmanager_list_control_insights_by_control_domain(
controlDomainId,
nextToken = NULL,
maxResults = NULL
)[required] The unique identifier for the control domain.
The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.