Returns a list of controls from Audit Manager.
See https://paws-r.github.io/docs/auditmanager/list_controls.html for full documentation.
auditmanager_list_controls(controlType, nextToken = NULL, maxResults = NULL)[required] The type of control, such as a standard control or a custom control.
The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.