Returns a list of all Audit Manager notifications.
See https://paws-r.github.io/docs/auditmanager/list_notifications.html for full documentation.
auditmanager_list_notifications(nextToken = NULL, maxResults = NULL)The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.