Learn R Programming

paws.management (version 0.2.0)

auditmanager_register_account: Enables Audit Manager for the specified Amazon Web Services account

Description

Enables Audit Manager for the specified Amazon Web Services account.

See https://paws-r.github.io/docs/auditmanager/register_account.html for full documentation.

Usage

auditmanager_register_account(kmsKey = NULL, delegatedAdminAccount = NULL)

Arguments

kmsKey

The KMS key details.

delegatedAdminAccount

The delegated administrator account for Audit Manager.