Creates a share request for a custom framework in Audit Manager.
See https://paws-r.github.io/docs/auditmanager/start_assessment_framework_share.html for full documentation.
auditmanager_start_assessment_framework_share(
frameworkId,
destinationAccount,
destinationRegion,
comment = NULL
)[required] The unique identifier for the custom framework to be shared.
[required] The Amazon Web Services account of the recipient.
[required] The Amazon Web Services Region of the recipient.
An optional comment from the sender about the share request.