Learn R Programming

paws.management (version 0.2.0)

auditmanager_update_assessment_control: Updates a control within an assessment in Audit Manager

Description

Updates a control within an assessment in Audit Manager.

See https://paws-r.github.io/docs/auditmanager/update_assessment_control.html for full documentation.

Usage

auditmanager_update_assessment_control(
  assessmentId,
  controlSetId,
  controlId,
  controlStatus = NULL,
  commentBody = NULL
)

Arguments

assessmentId

[required] The unique identifier for the assessment.

controlSetId

[required] The unique identifier for the control set.

controlId

[required] The unique identifier for the control.

controlStatus

The status of the control.

commentBody

The comment body text for the control.