Updates a custom framework in Audit Manager.
See https://paws-r.github.io/docs/auditmanager/update_assessment_framework.html for full documentation.
auditmanager_update_assessment_framework(
frameworkId,
name,
description = NULL,
complianceType = NULL,
controlSets
)[required] The unique identifier for the framework.
[required] The name of the framework to be updated.
The description of the updated framework.
The compliance type that the new custom framework supports, such as CIS or HIPAA.
[required] The control sets that are associated with the framework.