Learn R Programming

paws.management (version 0.2.0)

auditmanager_update_settings: Updates Audit Manager settings for the current user account

Description

Updates Audit Manager settings for the current user account.

See https://paws-r.github.io/docs/auditmanager/update_settings.html for full documentation.

Usage

auditmanager_update_settings(
  snsTopic = NULL,
  defaultAssessmentReportsDestination = NULL,
  defaultProcessOwners = NULL,
  kmsKey = NULL
)

Arguments

snsTopic

The Amazon Simple Notification Service (Amazon SNS) topic that Audit Manager sends notifications to.

defaultAssessmentReportsDestination

The default storage destination for assessment reports.

defaultProcessOwners

A list of the default audit owners.

kmsKey

The KMS key details.