Learn R Programming

paws.management (version 0.2.0)

autoscaling_attach_load_balancer_target_groups: Attaches one or more target groups to the specified Auto Scaling group

Description

Attaches one or more target groups to the specified Auto Scaling group.

See https://paws-r.github.io/docs/autoscaling/attach_load_balancer_target_groups.html for full documentation.

Usage

autoscaling_attach_load_balancer_target_groups(
  AutoScalingGroupName,
  TargetGroupARNs
)

Arguments

AutoScalingGroupName

[required] The name of the Auto Scaling group.

TargetGroupARNs

[required] The Amazon Resource Names (ARN) of the target groups. You can specify up to 10 target groups. To get the ARN of a target group, use the Elastic Load Balancing DescribeTargetGroups API operation.