Attaches one or more traffic sources to the specified Auto Scaling group.
See https://www.paws-r-sdk.com/docs/autoscaling_attach_traffic_sources/ for full documentation.
autoscaling_attach_traffic_sources(
AutoScalingGroupName,
TrafficSources,
SkipZonalShiftValidation = NULL
)[required] The name of the Auto Scaling group.
[required] The unique identifiers of one or more traffic sources. You can specify up to 10 traffic sources.
If you enable zonal shift with cross-zone disabled load balancers,
capacity could become imbalanced across Availability Zones. To skip the
validation, specify true. For more information, see Auto Scaling group zonal shift
in the Amazon EC2 Auto Scaling User Guide.