Learn R Programming

paws.management (version 0.2.0)

autoscaling_batch_delete_scheduled_action: Deletes one or more scheduled actions for the specified Auto Scaling group

Description

Deletes one or more scheduled actions for the specified Auto Scaling group.

See https://paws-r.github.io/docs/autoscaling/batch_delete_scheduled_action.html for full documentation.

Usage

autoscaling_batch_delete_scheduled_action(
  AutoScalingGroupName,
  ScheduledActionNames
)

Arguments

AutoScalingGroupName

[required] The name of the Auto Scaling group.

ScheduledActionNames

[required] The names of the scheduled actions to delete. The maximum number allowed is 50.