Learn R Programming

paws.management (version 0.2.0)

autoscaling_cancel_instance_refresh: Cancels an instance refresh operation in progress

Description

Cancels an instance refresh operation in progress. Cancellation does not roll back any replacements that have already been completed, but it prevents new replacements from being started.

See https://paws-r.github.io/docs/autoscaling/cancel_instance_refresh.html for full documentation.

Usage

autoscaling_cancel_instance_refresh(AutoScalingGroupName)

Arguments

AutoScalingGroupName

[required] The name of the Auto Scaling group.