We strongly recommend using a launch template when calling this operation to ensure full functionality for Amazon EC2 Auto Scaling and Amazon EC2.
See https://paws-r.github.io/docs/autoscaling/create_auto_scaling_group.html for full documentation.
autoscaling_create_auto_scaling_group(
AutoScalingGroupName,
LaunchConfigurationName = NULL,
LaunchTemplate = NULL,
MixedInstancesPolicy = NULL,
InstanceId = NULL,
MinSize,
MaxSize,
DesiredCapacity = NULL,
DefaultCooldown = NULL,
AvailabilityZones = NULL,
LoadBalancerNames = NULL,
TargetGroupARNs = NULL,
HealthCheckType = NULL,
HealthCheckGracePeriod = NULL,
PlacementGroup = NULL,
VPCZoneIdentifier = NULL,
TerminationPolicies = NULL,
NewInstancesProtectedFromScaleIn = NULL,
CapacityRebalance = NULL,
LifecycleHookSpecificationList = NULL,
Tags = NULL,
ServiceLinkedRoleARN = NULL,
MaxInstanceLifetime = NULL,
Context = NULL,
DesiredCapacityType = NULL,
DefaultInstanceWarmup = NULL
)[required] The name of the Auto Scaling group. This name must be unique per Region per account.
The name of the launch configuration to use to launch instances.
Conditional: You must specify either a launch template (LaunchTemplate
or MixedInstancesPolicy) or a launch configuration
(LaunchConfigurationName or InstanceId).
Information used to specify the launch template and version to use to launch instances.
Conditional: You must specify either a launch template (LaunchTemplate
or MixedInstancesPolicy) or a launch configuration
(LaunchConfigurationName or InstanceId).
The launch template that is specified must be configured for use with an Auto Scaling group. For more information, see Creating a launch template for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.
An embedded object that specifies a mixed instances policy.
For more information, see Auto Scaling groups with multiple instance types and purchase options in the Amazon EC2 Auto Scaling User Guide.
The ID of the instance used to base the launch configuration on. If specified, Amazon EC2 Auto Scaling uses the configuration values from the specified instance to create a new launch configuration. To get the instance ID, use the Amazon EC2 DescribeInstances API operation. For more information, see Creating an Auto Scaling group using an EC2 instance in the Amazon EC2 Auto Scaling User Guide.
[required] The minimum size of the group.
[required] The maximum size of the group.
With a mixed instances policy that uses instance weighting, Amazon EC2
Auto Scaling may need to go above MaxSize to meet your capacity
requirements. In this event, Amazon EC2 Auto Scaling will never go above
MaxSize by more than your largest instance weight (weights that define
how many units each instance contributes to the desired capacity of the
group).
The desired capacity is the initial capacity of the Auto Scaling group at the time of its creation and the capacity it attempts to maintain. It can scale beyond this capacity if you configure auto scaling. This number must be greater than or equal to the minimum size of the group and less than or equal to the maximum size of the group. If you do not specify a desired capacity, the default is the minimum size of the group.
Only needed if you use simple scaling policies.
The amount of time, in seconds, between one scaling activity ending and another one starting due to simple scaling policies. For more information, see Scaling cooldowns for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.
Default: 300 seconds
A list of Availability Zones where instances in the Auto Scaling group
can be created. Used for launching into the default VPC subnet in each
Availability Zone when not using the VPCZoneIdentifier property, or
for attaching a network interface when an existing network interface ID
is specified in a launch template.
A list of Classic Load Balancers associated with this Auto Scaling
group. For Application Load Balancers, Network Load Balancers, and
Gateway Load Balancer, specify the TargetGroupARNs property instead.
The Amazon Resource Names (ARN) of the target groups to associate with the Auto Scaling group. Instances are registered as targets with the target groups. The target groups receive incoming traffic and route requests to one or more registered targets. For more information, see Use Elastic Load Balancing to distribute traffic across the instances in your Auto Scaling group in the Amazon EC2 Auto Scaling User Guide.
The service to use for the health checks. The valid values are EC2
(default) and ELB. If you configure an Auto Scaling group to use load
balancer (ELB) health checks, it considers the instance unhealthy if it
fails either the EC2 status checks or the load balancer health checks.
For more information, see Health checks for Auto Scaling instances
in the Amazon EC2 Auto Scaling User Guide.
The amount of time, in seconds, that Amazon EC2 Auto Scaling waits
before checking the health status of an EC2 instance that has come into
service and marking it unhealthy due to a failed Elastic Load Balancing
or custom health check. This is useful if your instances do not
immediately pass these health checks after they enter the InService
state. For more information, see Health check grace period
in the Amazon EC2 Auto Scaling User Guide.
Default: 0 seconds
The name of the placement group into which to launch your instances. For more information, see Placement groups in the Amazon EC2 User Guide for Linux Instances.
A cluster placement group is a logical grouping of instances within a single Availability Zone. You cannot specify multiple Availability Zones and a cluster placement group.
A comma-separated list of subnet IDs for a virtual private cloud (VPC)
where instances in the Auto Scaling group can be created. If you specify
VPCZoneIdentifier with AvailabilityZones, the subnets that you
specify must reside in those Availability Zones.
A policy or a list of policies that are used to select the instance to terminate. These policies are executed in the order that you list them. For more information, see Work with Amazon EC2 Auto Scaling termination policies in the Amazon EC2 Auto Scaling User Guide.
Valid values: Default | AllocationStrategy |
ClosestToNextInstanceHour | NewestInstance | OldestInstance |
OldestLaunchConfiguration | OldestLaunchTemplate |
arn:aws:lambda:region:account-id:function:my-function:my-alias
Indicates whether newly launched instances are protected from termination by Amazon EC2 Auto Scaling when scaling in. For more information about preventing instances from terminating on scale in, see Using instance scale-in protection in the Amazon EC2 Auto Scaling User Guide.
Indicates whether Capacity Rebalancing is enabled. Otherwise, Capacity Rebalancing is disabled. When you turn on Capacity Rebalancing, Amazon EC2 Auto Scaling attempts to launch a Spot Instance whenever Amazon EC2 notifies that a Spot Instance is at an elevated risk of interruption. After launching a new instance, it then terminates an old instance. For more information, see Use Capacity Rebalancing to handle Amazon EC2 Spot Interruptions in the in the Amazon EC2 Auto Scaling User Guide.
One or more lifecycle hooks to add to the Auto Scaling group before instances are launched.
One or more tags. You can tag your Auto Scaling group and propagate the tags to the Amazon EC2 instances it launches. Tags are not propagated to Amazon EBS volumes. To add tags to Amazon EBS volumes, specify the tags in a launch template but use caution. If the launch template specifies an instance tag with a key that is also specified for the Auto Scaling group, Amazon EC2 Auto Scaling overrides the value of that instance tag with the value specified by the Auto Scaling group. For more information, see Tag Auto Scaling groups and instances in the Amazon EC2 Auto Scaling User Guide.
The Amazon Resource Name (ARN) of the service-linked role that the Auto
Scaling group uses to call other Amazon Web Services service on your
behalf. By default, Amazon EC2 Auto Scaling uses a service-linked role
named AWSServiceRoleForAutoScaling, which it creates if it does not
exist. For more information, see Service-linked roles
in the Amazon EC2 Auto Scaling User Guide.
The maximum amount of time, in seconds, that an instance can be in service. The default is null. If specified, the value must be either 0 or a number equal to or greater than 86,400 seconds (1 day). For more information, see Replacing Auto Scaling instances based on maximum instance lifetime in the Amazon EC2 Auto Scaling User Guide.
Reserved.
The unit of measurement for the value specified for desired capacity.
Amazon EC2 Auto Scaling supports DesiredCapacityType for
attribute-based instance type selection only. For more information, see
Creating an Auto Scaling group using attribute-based instance type selection
in the Amazon EC2 Auto Scaling User Guide.
By default, Amazon EC2 Auto Scaling specifies units, which translates
into number of instances.
Valid values: units | vcpu | memory-mib
The amount of time, in seconds, until a newly launched instance can
contribute to the Amazon CloudWatch metrics. This delay lets an instance
finish initializing before Amazon EC2 Auto Scaling aggregates instance
metrics, resulting in more reliable usage data. Set this value equal to
the amount of time that it takes for resource consumption to become
stable after an instance reaches the InService state. For more
information, see Set the default instance warmup for an Auto Scaling group
in the Amazon EC2 Auto Scaling User Guide.
To manage your warm-up settings at the group level, we recommend that you set the default instance warmup, even if its value is set to 0 seconds. This also optimizes the performance of scaling policies that scale continuously, such as target tracking and step scaling policies.
If you need to remove a value that you previously set, include the
property but specify -1 for the value. However, we strongly recommend
keeping the default instance warmup enabled by specifying a minimum
value of 0.
Default: None