Gets information about the instance refreshes for the specified Auto Scaling group.
See https://paws-r.github.io/docs/autoscaling/describe_instance_refreshes.html for full documentation.
autoscaling_describe_instance_refreshes(
AutoScalingGroupName,
InstanceRefreshIds = NULL,
NextToken = NULL,
MaxRecords = NULL
)[required] The name of the Auto Scaling group.
One or more instance refresh IDs.
The token for the next set of items to return. (You received this token from a previous call.)
The maximum number of items to return with this call. The default value
is 50 and the maximum value is 100.