Learn R Programming

paws.management (version 0.2.0)

autoscaling_describe_lifecycle_hooks: Gets information about the lifecycle hooks for the specified Auto Scaling group

Description

Gets information about the lifecycle hooks for the specified Auto Scaling group.

See https://paws-r.github.io/docs/autoscaling/describe_lifecycle_hooks.html for full documentation.

Usage

autoscaling_describe_lifecycle_hooks(
  AutoScalingGroupName,
  LifecycleHookNames = NULL
)

Arguments

AutoScalingGroupName

[required] The name of the Auto Scaling group.

LifecycleHookNames

The names of one or more lifecycle hooks. If you omit this property, all lifecycle hooks are described.