Gets information about the Amazon SNS notifications that are configured for one or more Auto Scaling groups.
See https://paws-r.github.io/docs/autoscaling/describe_notification_configurations.html for full documentation.
autoscaling_describe_notification_configurations(
AutoScalingGroupNames = NULL,
NextToken = NULL,
MaxRecords = NULL
)The name of the Auto Scaling group.
The token for the next set of items to return. (You received this token from a previous call.)
The maximum number of items to return with this call. The default value
is 50 and the maximum value is 100.