Learn R Programming

paws.management (version 0.2.0)

autoscaling_detach_instances: Removes one or more instances from the specified Auto Scaling group

Description

Removes one or more instances from the specified Auto Scaling group.

See https://paws-r.github.io/docs/autoscaling/detach_instances.html for full documentation.

Usage

autoscaling_detach_instances(
  InstanceIds = NULL,
  AutoScalingGroupName,
  ShouldDecrementDesiredCapacity
)

Arguments

InstanceIds

The IDs of the instances. You can specify up to 20 instances.

AutoScalingGroupName

[required] The name of the Auto Scaling group.

ShouldDecrementDesiredCapacity

[required] Indicates whether the Auto Scaling group decrements the desired capacity value by the number of instances detached.