Learn R Programming

paws.management (version 0.2.0)

autoscaling_detach_load_balancer_target_groups: Detaches one or more target groups from the specified Auto Scaling group

Description

Detaches one or more target groups from the specified Auto Scaling group.

See https://paws-r.github.io/docs/autoscaling/detach_load_balancer_target_groups.html for full documentation.

Usage

autoscaling_detach_load_balancer_target_groups(
  AutoScalingGroupName,
  TargetGroupARNs
)

Arguments

AutoScalingGroupName

[required] The name of the Auto Scaling group.

TargetGroupARNs

[required] The Amazon Resource Names (ARN) of the target groups. You can specify up to 10 target groups.