Learn R Programming

paws.management (version 0.2.0)

autoscaling_enter_standby: Moves the specified instances into the standby state

Description

Moves the specified instances into the standby state.

See https://paws-r.github.io/docs/autoscaling/enter_standby.html for full documentation.

Usage

autoscaling_enter_standby(
  InstanceIds = NULL,
  AutoScalingGroupName,
  ShouldDecrementDesiredCapacity
)

Arguments

InstanceIds

The IDs of the instances. You can specify up to 20 instances.

AutoScalingGroupName

[required] The name of the Auto Scaling group.

ShouldDecrementDesiredCapacity

[required] Indicates whether to decrement the desired capacity of the Auto Scaling group by the number of instances moved to Standby mode.