Learn R Programming

paws.management (version 0.2.0)

autoscaling_exit_standby: Moves the specified instances out of the standby state

Description

Moves the specified instances out of the standby state.

See https://paws-r.github.io/docs/autoscaling/exit_standby.html for full documentation.

Usage

autoscaling_exit_standby(InstanceIds = NULL, AutoScalingGroupName)

Arguments

InstanceIds

The IDs of the instances. You can specify up to 20 instances.

AutoScalingGroupName

[required] The name of the Auto Scaling group.