Resumes the specified suspended auto scaling processes, or all suspended process, for the specified Auto Scaling group.
See https://paws-r.github.io/docs/autoscaling/resume_processes.html for full documentation.
autoscaling_resume_processes(AutoScalingGroupName, ScalingProcesses = NULL)[required] The name of the Auto Scaling group.
One or more of the following processes:
Launch
Terminate
AddToLoadBalancer
AlarmNotification
AZRebalance
HealthCheck
InstanceRefresh
ReplaceUnhealthy
ScheduledActions
If you omit this property, all processes are specified.