Terminates the specified instance and optionally adjusts the desired group size. This operation cannot be called on instances in a warm pool.
See https://paws-r.github.io/docs/autoscaling/terminate_instance_in_auto_scaling_group.html for full documentation.
autoscaling_terminate_instance_in_auto_scaling_group(
InstanceId,
ShouldDecrementDesiredCapacity
)[required] The ID of the instance.
[required] Indicates whether terminating the instance also decrements the size of the Auto Scaling group.