We strongly recommend that all Auto Scaling groups use launch templates to ensure full functionality for Amazon EC2 Auto Scaling and Amazon EC2.
See https://paws-r.github.io/docs/autoscaling/update_auto_scaling_group.html for full documentation.
autoscaling_update_auto_scaling_group(
AutoScalingGroupName,
LaunchConfigurationName = NULL,
LaunchTemplate = NULL,
MixedInstancesPolicy = NULL,
MinSize = NULL,
MaxSize = NULL,
DesiredCapacity = NULL,
DefaultCooldown = NULL,
AvailabilityZones = NULL,
HealthCheckType = NULL,
HealthCheckGracePeriod = NULL,
PlacementGroup = NULL,
VPCZoneIdentifier = NULL,
TerminationPolicies = NULL,
NewInstancesProtectedFromScaleIn = NULL,
ServiceLinkedRoleARN = NULL,
MaxInstanceLifetime = NULL,
CapacityRebalance = NULL,
Context = NULL,
DesiredCapacityType = NULL,
DefaultInstanceWarmup = NULL
)[required] The name of the Auto Scaling group.
The name of the launch configuration. If you specify
LaunchConfigurationName in your update request, you can't specify
LaunchTemplate or MixedInstancesPolicy.
The launch template and version to use to specify the updates. If you
specify LaunchTemplate in your update request, you can't specify
LaunchConfigurationName or MixedInstancesPolicy.
An embedded object that specifies a mixed instances policy. For more information, see Auto Scaling groups with multiple instance types and purchase options in the Amazon EC2 Auto Scaling User Guide.
The minimum size of the Auto Scaling group.
The maximum size of the Auto Scaling group.
With a mixed instances policy that uses instance weighting, Amazon EC2
Auto Scaling may need to go above MaxSize to meet your capacity
requirements. In this event, Amazon EC2 Auto Scaling will never go above
MaxSize by more than your largest instance weight (weights that define
how many units each instance contributes to the desired capacity of the
group).
The desired capacity is the initial capacity of the Auto Scaling group after this operation completes and the capacity it attempts to maintain. This number must be greater than or equal to the minimum size of the group and less than or equal to the maximum size of the group.
Only needed if you use simple scaling policies.
The amount of time, in seconds, between one scaling activity ending and another one starting due to simple scaling policies. For more information, see Scaling cooldowns for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.
One or more Availability Zones for the group.
The service to use for the health checks. The valid values are EC2 and
ELB. If you configure an Auto Scaling group to use ELB health
checks, it considers the instance unhealthy if it fails either the EC2
status checks or the load balancer health checks.
The amount of time, in seconds, that Amazon EC2 Auto Scaling waits
before checking the health status of an EC2 instance that has come into
service and marking it unhealthy due to a failed Elastic Load Balancing
or custom health check. This is useful if your instances do not
immediately pass these health checks after they enter the InService
state. For more information, see Health check grace period
in the Amazon EC2 Auto Scaling User Guide.
The name of an existing placement group into which to launch your instances. For more information, see Placement groups in the Amazon EC2 User Guide for Linux Instances.
A cluster placement group is a logical grouping of instances within a single Availability Zone. You cannot specify multiple Availability Zones and a cluster placement group.
A comma-separated list of subnet IDs for a virtual private cloud (VPC).
If you specify VPCZoneIdentifier with AvailabilityZones, the subnets
that you specify must reside in those Availability Zones.
A policy or a list of policies that are used to select the instances to terminate. The policies are executed in the order that you list them. For more information, see Work with Amazon EC2 Auto Scaling termination policies in the Amazon EC2 Auto Scaling User Guide.
Valid values: Default | AllocationStrategy |
ClosestToNextInstanceHour | NewestInstance | OldestInstance |
OldestLaunchConfiguration | OldestLaunchTemplate |
arn:aws:lambda:region:account-id:function:my-function:my-alias
Indicates whether newly launched instances are protected from termination by Amazon EC2 Auto Scaling when scaling in. For more information about preventing instances from terminating on scale in, see Using instance scale-in protection in the Amazon EC2 Auto Scaling User Guide.
The Amazon Resource Name (ARN) of the service-linked role that the Auto Scaling group uses to call other Amazon Web Services on your behalf. For more information, see Service-linked roles in the Amazon EC2 Auto Scaling User Guide.
The maximum amount of time, in seconds, that an instance can be in service. The default is null. If specified, the value must be either 0 or a number equal to or greater than 86,400 seconds (1 day). To clear a previously set value, specify a new value of 0. For more information, see Replacing Auto Scaling instances based on maximum instance lifetime in the Amazon EC2 Auto Scaling User Guide.
Enables or disables Capacity Rebalancing. For more information, see Use Capacity Rebalancing to handle Amazon EC2 Spot Interruptions in the Amazon EC2 Auto Scaling User Guide.
Reserved.
The unit of measurement for the value specified for desired capacity.
Amazon EC2 Auto Scaling supports DesiredCapacityType for
attribute-based instance type selection only. For more information, see
Creating an Auto Scaling group using attribute-based instance type selection
in the Amazon EC2 Auto Scaling User Guide.
By default, Amazon EC2 Auto Scaling specifies units, which translates
into number of instances.
Valid values: units | vcpu | memory-mib
The amount of time, in seconds, until a newly launched instance can
contribute to the Amazon CloudWatch metrics. This delay lets an instance
finish initializing before Amazon EC2 Auto Scaling aggregates instance
metrics, resulting in more reliable usage data. Set this value equal to
the amount of time that it takes for resource consumption to become
stable after an instance reaches the InService state. For more
information, see Set the default instance warmup for an Auto Scaling group
in the Amazon EC2 Auto Scaling User Guide.
To manage your warm-up settings at the group level, we recommend that you set the default instance warmup, even if its value is set to 0 seconds. This also optimizes the performance of scaling policies that scale continuously, such as target tracking and step scaling policies.
If you need to remove a value that you previously set, include the
property but specify -1 for the value. However, we strongly recommend
keeping the default instance warmup enabled by specifying a minimum
value of 0.