Creates a scaling plan.
See https://paws-r.github.io/docs/autoscalingplans/create_scaling_plan.html for full documentation.
autoscalingplans_create_scaling_plan(
ScalingPlanName,
ApplicationSource,
ScalingInstructions
)[required] The name of the scaling plan. Names cannot contain vertical bars, colons, or forward slashes.
[required] A CloudFormation stack or set of tags. You can create one scaling plan per application source.
For more information, see ApplicationSource in the AWS Auto Scaling API Reference.
[required] The scaling instructions.
For more information, see ScalingInstruction in the AWS Auto Scaling API Reference.