Learn R Programming

paws.management (version 0.2.0)

autoscalingplans_describe_scaling_plan_resources: Describes the scalable resources in the specified scaling plan

Description

Describes the scalable resources in the specified scaling plan.

See https://paws-r.github.io/docs/autoscalingplans/describe_scaling_plan_resources.html for full documentation.

Usage

autoscalingplans_describe_scaling_plan_resources(
  ScalingPlanName,
  ScalingPlanVersion,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

ScalingPlanName

[required] The name of the scaling plan.

ScalingPlanVersion

[required] The version number of the scaling plan. Currently, the only valid value is 1.

MaxResults

The maximum number of scalable resources to return. The value must be between 1 and 50. The default value is 50.

NextToken

The token for the next set of results.