Learn R Programming

paws.management (version 0.2.0)

cloudformation_delete_change_set: Deletes the specified change set

Description

Deletes the specified change set. Deleting change sets ensures that no one executes the wrong change set.

See https://paws-r.github.io/docs/cloudformation/delete_change_set.html for full documentation.

Usage

cloudformation_delete_change_set(ChangeSetName, StackName = NULL)

Arguments

ChangeSetName

[required] The name or Amazon Resource Name (ARN) of the change set that you want to delete.

StackName

If you specified the name of a change set to delete, specify the stack name or Amazon Resource Name (ARN) that's associated with it.