Returns the description of the specified stack set operation.
See https://paws-r.github.io/docs/cloudformation/describe_stack_set_operation.html for full documentation.
cloudformation_describe_stack_set_operation(
StackSetName,
OperationId,
CallAs = NULL
)[required] The name or the unique stack ID of the stack set for the stack operation.
[required] The unique ID of the stack set operation.
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account.
By default, SELF is specified. Use SELF for stack sets with
self-managed permissions.
If you are signed in to the management account, specify SELF.
If you are signed in to a delegated administrator account, specify
DELEGATED_ADMIN.
Your Amazon Web Services account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.