Learn R Programming

paws.management (version 0.2.0)

cloudformation_get_stack_policy: Returns the stack policy for a specified stack

Description

Returns the stack policy for a specified stack. If a stack doesn't have a policy, a null value is returned.

See https://paws-r.github.io/docs/cloudformation/get_stack_policy.html for full documentation.

Usage

cloudformation_get_stack_policy(StackName)

Arguments

StackName

[required] The name or unique stack ID that's associated with the stack whose policy you want to get.