Import existing stacks into a new stack sets. Use the stack import operation to import up to 10 stacks into a new stack set in the same account as the source stack or in a different administrator account and Region, by specifying the stack ID of the stack you intend to import.
See https://paws-r.github.io/docs/cloudformation/import_stacks_to_stack_set.html for full documentation.
cloudformation_import_stacks_to_stack_set(
StackSetName,
StackIds = NULL,
StackIdsUrl = NULL,
OrganizationalUnitIds = NULL,
OperationPreferences = NULL,
OperationId = NULL,
CallAs = NULL
)[required] The name of the stack set. The name must be unique in the Region where you create your stack set.
The IDs of the stacks you are importing into a stack set. You import up to 10 stacks per stack set at a time.
Specify either StackIds or StackIdsUrl.
The Amazon S3 URL which contains list of stack ids to be inputted.
Specify either StackIds or StackIdsUrl.
The list of OU ID's to which the stacks being imported has to be mapped as deployment target.
A unique, user defined, identifier for the stack set operation.
By default, SELF is specified. Use SELF for stack sets with
self-managed permissions.
If you are signed in to the management account, specify SELF.
For service managed stack sets, specify DELEGATED_ADMIN.