Returns the ID and status of each active change set for a stack. For example, CloudFormation lists change sets that are in the CREATE_IN_PROGRESS or CREATE_PENDING state.
See https://paws-r.github.io/docs/cloudformation/list_change_sets.html for full documentation.
cloudformation_list_change_sets(StackName, NextToken = NULL)[required] The name or the Amazon Resource Name (ARN) of the stack for which you want to list change sets.
A string (provided by the
list_change_sets response output)
that identifies the next page of change sets that you want to retrieve.