Returns descriptions of all resources of the specified stack.
See https://paws-r.github.io/docs/cloudformation/list_stack_resources.html for full documentation.
cloudformation_list_stack_resources(StackName, NextToken = NULL)[required] The name or the unique stack ID that is associated with the stack, which aren't always interchangeable:
Running stacks: You can specify either the stack's name or its unique stack ID.
Deleted stacks: You must specify the unique stack ID.
Default: There is no default value.
A string that identifies the next page of stack resources that you want to retrieve.