View source: R/cloudformation_operations.R
| cloudformation_list_stack_sets | R Documentation |
Returns summary information about StackSets that are associated with the user.
See https://www.paws-r-sdk.com/docs/cloudformation_list_stack_sets/ for full documentation.
cloudformation_list_stack_sets(
NextToken = NULL,
MaxResults = NULL,
Status = NULL,
CallAs = NULL
)
NextToken |
The token for the next set of items to return. (You received this token from a previous call.) |
MaxResults |
The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a |
Status |
The status of the StackSets that you want to get summary information about. |
CallAs |
[Service-managed permissions] Specifies whether you are acting as an account administrator in the management account or as a delegated administrator in a member account. By default,
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.