View source: R/cloudformation_operations.R
| cloudformation_update_stack_set | R Documentation |
Updates the StackSet and associated stack instances in the specified accounts and Amazon Web Services Regions.
See https://www.paws-r-sdk.com/docs/cloudformation_update_stack_set/ for full documentation.
cloudformation_update_stack_set(
StackSetName,
Description = NULL,
TemplateBody = NULL,
TemplateURL = NULL,
UsePreviousTemplate = NULL,
Parameters = NULL,
Capabilities = NULL,
Tags = NULL,
OperationPreferences = NULL,
AdministrationRoleARN = NULL,
ExecutionRoleName = NULL,
DeploymentTargets = NULL,
PermissionModel = NULL,
AutoDeployment = NULL,
OperationId = NULL,
Accounts = NULL,
Regions = NULL,
CallAs = NULL,
ManagedExecution = NULL
)
StackSetName |
[required] The name or unique ID of the StackSet that you want to update. |
Description |
A brief description of updates that you are making. |
TemplateBody |
The structure that contains the template body, with a minimum length of 1 byte and a maximum length of 51,200 bytes. Conditional: You must specify only one of the following parameters: |
TemplateURL |
The URL of a file that contains the template body. The URL must point to a template (maximum size: 1 MB) that is located in an Amazon S3 bucket or a Systems Manager document. The location for an Amazon S3 bucket must start with Conditional: You must specify only one of the following parameters: |
UsePreviousTemplate |
Use the existing template that's associated with the StackSet that you're updating. Conditional: You must specify only one of the following parameters: |
Parameters |
A list of input parameters for the StackSet template. |
Capabilities |
In some cases, you must explicitly acknowledge that your stack template contains certain capabilities in order for CloudFormation to update the StackSet and its associated stack instances.
|
Tags |
The key-value pairs to associate with this StackSet and the stacks created from it. CloudFormation also propagates these tags to supported resources that are created in the stacks. You can specify a maximum number of 50 tags. If you specify tags for this parameter, those tags replace any list of tags that are currently associated with this StackSet. This means:
If you specify new tags as part of an |
OperationPreferences |
Preferences for how CloudFormation performs this StackSet operation. |
AdministrationRoleARN |
[Self-managed permissions] The Amazon Resource Name (ARN) of the IAM role to use to update this StackSet. Specify an IAM role only if you are using customized administrator roles to control which users or groups can manage specific StackSets within the same administrator account. For more information, see Grant self-managed permissions in the CloudFormation User Guide. If you specified a customized administrator role when you created the StackSet, you must specify a customized administrator role, even if it is the same customized administrator role used with this StackSet previously. |
ExecutionRoleName |
[Self-managed permissions] The name of the IAM execution role to use to update the stack set. If you do not specify an execution role, CloudFormation uses the Specify an IAM role only if you are using customized execution roles to control which stack resources users and groups can include in their StackSets. If you specify a customized execution role, CloudFormation uses that role to update the stack. If you do not specify a customized execution role, CloudFormation performs the update using the role previously associated with the StackSet, so long as you have permissions to perform operations on the StackSet. |
DeploymentTargets |
[Service-managed permissions] The Organizations accounts in which to update associated stack instances. To update all the stack instances associated with this StackSet, do not specify If the StackSet update includes changes to the template (that is, if |
PermissionModel |
Describes how the IAM roles required for StackSet operations are created. You cannot modify
|
AutoDeployment |
[Service-managed permissions] Describes whether StackSets automatically deploys to Organizations accounts that are added to a target organization or organizational unit (OU). For more information, see Enable or disable automatic deployments for StackSets in Organizations in the CloudFormation User Guide. If you specify |
OperationId |
The unique ID for this StackSet operation. The operation ID also functions as an idempotency token, to ensure that CloudFormation performs the StackSet operation only once, even if you retry the request multiple times. You might retry StackSet operation requests to ensure that CloudFormation successfully received them. If you don't specify an operation ID, CloudFormation generates one automatically. Repeating this StackSet operation with a new operation ID retries all stack instances whose status is |
Accounts |
[Self-managed permissions] The accounts in which to update associated stack instances. If you specify accounts, you must also specify the Amazon Web Services Regions in which to update StackSet instances. To update all the stack instances associated with this StackSet, don't specify the If the StackSet update includes changes to the template (that is, if the |
Regions |
The Amazon Web Services Regions in which to update associated stack instances. If you specify Regions, you must also specify accounts in which to update StackSet instances. To update all the stack instances associated with this StackSet, do not specify the If the StackSet update includes changes to the template (that is, if the |
CallAs |
[Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default,
|
ManagedExecution |
Describes whether CloudFormation performs non-conflicting operations concurrently and queues conflicting operations. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.