Updates termination protection for the specified stack. If a user attempts to delete a stack with termination protection enabled, the operation fails and the stack remains unchanged. For more information, see Protecting a Stack From Being Deleted in the CloudFormation User Guide.
See https://paws-r.github.io/docs/cloudformation/update_termination_protection.html for full documentation.
cloudformation_update_termination_protection(
EnableTerminationProtection,
StackName
)[required] Whether to enable termination protection on the specified stack.
[required] The name or unique ID of the stack for which you want to set termination protection.