Disables the event data store specified by EventDataStore, which accepts an event data store ARN. After you run delete_event_data_store, the event data store enters a PENDING_DELETION state, and is automatically deleted after a wait period of seven days. TerminationProtectionEnabled must be set to False on the event data store; this operation cannot work if TerminationProtectionEnabled is True.
See https://paws-r.github.io/docs/cloudtrail/delete_event_data_store.html for full documentation.
cloudtrail_delete_event_data_store(EventDataStore)[required] The ARN (or the ID suffix of the ARN) of the event data store to delete.