Deletes a trail. This operation must be called from the region in which the trail was created. delete_trail cannot be called on the shadow trails (replicated trails in other regions) of a trail that is enabled in all regions.
See https://paws-r.github.io/docs/cloudtrail/delete_trail.html for full documentation.
cloudtrail_delete_trail(Name)[required] Specifies the name or the CloudTrail ARN of the trail to be deleted. The
following is the format of a trail ARN.
arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail