Learn R Programming

paws.management (version 0.4.0)

cloudtrail_deregister_organization_delegated_admin: Removes CloudTrail delegated administrator permissions from a member account in an organization

Description

Removes CloudTrail delegated administrator permissions from a member account in an organization.

See https://www.paws-r-sdk.com/docs/cloudtrail_deregister_organization_delegated_admin/ for full documentation.

Usage

cloudtrail_deregister_organization_delegated_admin(DelegatedAdminAccountId)

Arguments

DelegatedAdminAccountId

[required] A delegated administrator account ID. This is a member account in an organization that is currently designated as a delegated administrator.