Learn R Programming

paws.management (version 0.2.0)

cloudtrail_describe_query: Returns metadata about a query, including query run time in milliseconds, number of events scanned and matched, and query status

Description

Returns metadata about a query, including query run time in milliseconds, number of events scanned and matched, and query status. You must specify an ARN for EventDataStore, and a value for QueryID.

See https://paws-r.github.io/docs/cloudtrail/describe_query.html for full documentation.

Usage

cloudtrail_describe_query(EventDataStore, QueryId)

Arguments

EventDataStore

[required] The ARN (or the ID suffix of the ARN) of an event data store on which the specified query was run.

QueryId

[required] The query ID.