Returns information about an event data store specified as either an ARN or the ID portion of the ARN.
See https://paws-r.github.io/docs/cloudtrail/get_event_data_store.html for full documentation.
cloudtrail_get_event_data_store(EventDataStore)[required] The ARN (or ID suffix of the ARN) of the event data store about which you want information.