Learn R Programming

paws.management (version 0.2.0)

cloudtrail_get_query_results: Gets event data results of a query

Description

Gets event data results of a query. You must specify the QueryID value returned by the start_query operation, and an ARN for EventDataStore.

See https://paws-r.github.io/docs/cloudtrail/get_query_results.html for full documentation.

Usage

cloudtrail_get_query_results(
  EventDataStore,
  QueryId,
  NextToken = NULL,
  MaxQueryResults = NULL
)

Arguments

EventDataStore

[required] The ARN (or ID suffix of the ARN) of the event data store against which the query was run.

QueryId

[required] The ID of the query for which you want to get results.

NextToken

A token you can use to get the next page of query results.

MaxQueryResults

The maximum number of query results to display on a single page.