Returns information about all event data stores in the account, in the current region.
See https://paws-r.github.io/docs/cloudtrail/list_event_data_stores.html for full documentation.
cloudtrail_list_event_data_stores(NextToken = NULL, MaxResults = NULL)A token you can use to get the next page of event data store results.
The maximum number of event data stores to display on a single page.