cloudtrail_list_tags: Lists the tags for the trail in the current region
Description
Lists the tags for the trail in the current region.
Usage
cloudtrail_list_tags(ResourceIdList, NextToken)
Arguments
ResourceIdList
[required] Specifies a list of trail ARNs whose tags will be listed. The list has a
limit of 20 ARNs. The format of a trail ARN is:
arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail
Request syntax
svc$list_tags(
ResourceIdList = list(
"string"
),
NextToken = "string"
)