Learn R Programming

paws.management (version 0.2.0)

cloudtrail_put_insight_selectors: Lets you enable Insights event logging by specifying the Insights selectors that you want to enable on an existing trail

Description

Lets you enable Insights event logging by specifying the Insights selectors that you want to enable on an existing trail. You also use put_insight_selectors to turn off Insights event logging, by passing an empty list of insight types. The valid Insights event types in this release are ApiErrorRateInsight and ApiCallRateInsight.

See https://paws-r.github.io/docs/cloudtrail/put_insight_selectors.html for full documentation.

Usage

cloudtrail_put_insight_selectors(TrailName, InsightSelectors)

Arguments

TrailName

[required] The name of the CloudTrail trail for which you want to change or add Insights selectors.

InsightSelectors

[required] A JSON string that contains the insight types you want to log on a trail. ApiCallRateInsight and ApiErrorRateInsight are valid insight types.