Restores a deleted event data store specified by EventDataStore, which accepts an event data store ARN. You can only restore a deleted event data store within the seven-day wait period after deletion. Restoring an event data store can take several minutes, depending on the size of the event data store.
See https://paws-r.github.io/docs/cloudtrail/restore_event_data_store.html for full documentation.
cloudtrail_restore_event_data_store(EventDataStore)[required] The ARN (or the ID suffix of the ARN) of the event data store that you want to restore.