Learn R Programming

paws.management (version 0.2.0)

cloudwatch_disable_insight_rules: Disables the specified Contributor Insights rules

Description

Disables the specified Contributor Insights rules. When rules are disabled, they do not analyze log groups and do not incur costs.

See https://paws-r.github.io/docs/cloudwatch/disable_insight_rules.html for full documentation.

Usage

cloudwatch_disable_insight_rules(RuleNames)

Arguments

RuleNames

[required] An array of the rule names to disable. If you need to find out the names of your rules, use describe_insight_rules.