Learn R Programming

paws.management (version 0.2.0)

cloudwatch_enable_insight_rules: Enables the specified Contributor Insights rules

Description

Enables the specified Contributor Insights rules. When rules are enabled, they immediately begin analyzing log data.

See https://paws-r.github.io/docs/cloudwatch/enable_insight_rules.html for full documentation.

Usage

cloudwatch_enable_insight_rules(RuleNames)

Arguments

RuleNames

[required] An array of the rule names to enable. If you need to find out the names of your rules, use describe_insight_rules.