Learn R Programming

paws.management (version 0.2.0)

cloudwatch_get_dashboard: Displays the details of the dashboard that you specify

Description

Displays the details of the dashboard that you specify.

See https://paws-r.github.io/docs/cloudwatch/get_dashboard.html for full documentation.

Usage

cloudwatch_get_dashboard(DashboardName)

Arguments

DashboardName

[required] The name of the dashboard to be described.