Learn R Programming

paws.management (version 0.2.0)

cloudwatch_get_metric_stream: Returns information about the metric stream that you specify

Description

Returns information about the metric stream that you specify.

See https://paws-r.github.io/docs/cloudwatch/get_metric_stream.html for full documentation.

Usage

cloudwatch_get_metric_stream(Name)

Arguments

Name

[required] The name of the metric stream to retrieve information about.