Returns a list of metric streams in this account.
See https://paws-r.github.io/docs/cloudwatch/list_metric_streams.html for full documentation.
cloudwatch_list_metric_streams(NextToken = NULL, MaxResults = NULL)Include this value, if it was returned by the previous call, to get the next set of metric streams.
The maximum number of results to return in one operation.