List the specified metrics. You can use the returned metrics with get_metric_data or get_metric_statistics to obtain statistical data.
See https://paws-r.github.io/docs/cloudwatch/list_metrics.html for full documentation.
cloudwatch_list_metrics(
Namespace = NULL,
MetricName = NULL,
Dimensions = NULL,
NextToken = NULL,
RecentlyActive = NULL
)The metric namespace to filter against. Only the namespace that matches exactly will be returned.
The name of the metric to filter against. Only the metrics with names that match exactly will be returned.
The dimensions to filter against. Only the dimensions that match exactly will be returned.
The token returned by a previous call to indicate that there is more data available.
To filter the results to show only metrics that have had data points
published in the past three hours, specify this parameter with a value
of PT3H. This is the only valid value for this parameter.
The results that are returned are an approximation of the value you specify. There is a low probability that the returned results include metrics with last published data as much as 40 minutes more than the specified time interval.