Learn R Programming

paws.management (version 0.2.0)

cloudwatch_put_metric_data: Publishes metric data points to Amazon CloudWatch

Description

Publishes metric data points to Amazon CloudWatch. CloudWatch associates the data points with the specified metric. If the specified metric does not exist, CloudWatch creates the metric. When CloudWatch creates a metric, it can take up to fifteen minutes for the metric to appear in calls to list_metrics.

See https://paws-r.github.io/docs/cloudwatch/put_metric_data.html for full documentation.

Usage

cloudwatch_put_metric_data(Namespace, MetricData)

Arguments

Namespace

[required] The namespace for the metric data.

To avoid conflicts with Amazon Web Services service namespaces, you should not specify a namespace that begins with AWS/

MetricData

[required] The data for the metric. The array can include no more than 1000 metrics per call.