Learn R Programming

paws.management (version 0.2.0)

cloudwatch_untag_resource: Removes one or more tags from the specified resource

Description

Removes one or more tags from the specified resource.

See https://paws-r.github.io/docs/cloudwatch/untag_resource.html for full documentation.

Usage

cloudwatch_untag_resource(ResourceARN, TagKeys)

Arguments

ResourceARN

[required] The ARN of the CloudWatch resource that you're removing tags from.

The ARN format of an alarm is arn:aws:cloudwatch:Region:account-id:alarm:alarm-name

The ARN format of a Contributor Insights rule is arn:aws:cloudwatch:Region:account-id:insight-rule:insight-rule-name

For more information about ARN format, see Resource Types Defined by Amazon CloudWatch in the Amazon Web Services General Reference.

TagKeys

[required] The list of tag keys to remove from the resource.