Returns information about a service discovered by Application Signals.
See https://www.paws-r-sdk.com/docs/cloudwatchapplicationsignals_get_service/ for full documentation.
cloudwatchapplicationsignals_get_service(StartTime, EndTime, KeyAttributes)[required] The start of the time period to retrieve information about. When used in
a raw HTTP Query API, it is formatted as be epoch time in seconds. For
example: 1698778057
Your requested start time will be rounded to the nearest hour.
[required] The end of the time period to retrieve information about. When used in a
raw HTTP Query API, it is formatted as be epoch time in seconds. For
example: 1698778057
Your requested start time will be rounded to the nearest hour.
[required] Use this field to specify which service you want to retrieve information
for. You must specify at least the Type, Name, and Environment
attributes.
This is a string-to-string map. It can include the following fields.
Type designates the type of object this is.
ResourceType specifies the type of the resource. This field is
used only when the value of the Type field is Resource or
AWS::Resource.
Name specifies the name of the object. This is used only if the
value of the Type field is Service, RemoteService, or
AWS::Service.
Identifier identifies the resource objects of this resource. This
is used only if the value of the Type field is Resource or
AWS::Resource.
Environment specifies the location where this object is hosted, or
what it belongs to.