Learn R Programming

paws.management (version 0.2.0)

cloudwatchevents_activate_event_source: Activates a partner event source that has been deactivated

Description

Activates a partner event source that has been deactivated. Once activated, your matching event bus will start receiving events from the event source.

See https://paws-r.github.io/docs/cloudwatchevents/activate_event_source.html for full documentation.

Usage

cloudwatchevents_activate_event_source(Name)

Arguments

Name

[required] The name of the partner event source to activate.