Creates an API destination, which is an HTTP invocation endpoint configured as a target for events.
See https://paws-r.github.io/docs/cloudwatchevents/create_api_destination.html for full documentation.
cloudwatchevents_create_api_destination(
Name,
Description = NULL,
ConnectionArn,
InvocationEndpoint,
HttpMethod,
InvocationRateLimitPerSecond = NULL
)[required] The name for the API destination to create.
A description for the API destination to create.
[required] The ARN of the connection to use for the API destination. The destination endpoint must support the authorization type specified for the connection.
[required] The URL to the HTTP invocation endpoint for the API destination.
[required] The method to use for the request to the HTTP invocation endpoint.
The maximum number of requests per second to send to the HTTP invocation endpoint.