Learn R Programming

paws.management (version 0.2.0)

cloudwatchevents_deactivate_event_source: You can use this operation to temporarily stop receiving events from the specified partner event source

Description

You can use this operation to temporarily stop receiving events from the specified partner event source. The matching event bus is not deleted.

See https://paws-r.github.io/docs/cloudwatchevents/deactivate_event_source.html for full documentation.

Usage

cloudwatchevents_deactivate_event_source(Name)

Arguments

Name

[required] The name of the partner event source to deactivate.