Removes all authorization parameters from the connection. This lets you remove the secret from the connection so you can reuse it without having to create a new connection.
See https://paws-r.github.io/docs/cloudwatchevents/deauthorize_connection.html for full documentation.
cloudwatchevents_deauthorize_connection(Name)[required] The name of the connection to remove authorization from.