This operation is used by SaaS partners to delete a partner event source. This operation is not used by Amazon Web Services customers.
See https://paws-r.github.io/docs/cloudwatchevents/delete_partner_event_source.html for full documentation.
cloudwatchevents_delete_partner_event_source(Name, Account)[required] The name of the event source to delete.
[required] The Amazon Web Services account ID of the Amazon Web Services customer that the event source was created for.