An SaaS partner can use this operation to list details about a partner event source that they have created. Amazon Web Services customers do not use this operation. Instead, Amazon Web Services customers can use describe_event_source to see details about a partner event source that is shared with them.
See https://paws-r.github.io/docs/cloudwatchevents/describe_partner_event_source.html for full documentation.
cloudwatchevents_describe_partner_event_source(Name)[required] The name of the event source to display.