Learn R Programming

paws.management (version 0.2.0)

cloudwatchevents_disable_rule: Disables the specified rule

Description

Disables the specified rule. A disabled rule won't match any events, and won't self-trigger if it has a schedule expression.

See https://paws-r.github.io/docs/cloudwatchevents/disable_rule.html for full documentation.

Usage

cloudwatchevents_disable_rule(Name, EventBusName = NULL)

Arguments

Name

[required] The name of the rule.

EventBusName

The name or ARN of the event bus associated with the rule. If you omit this, the default event bus is used.