Learn R Programming

paws.management (version 0.2.0)

cloudwatchevents_enable_rule: Enables the specified rule

Description

Enables the specified rule. If the rule does not exist, the operation fails.

See https://paws-r.github.io/docs/cloudwatchevents/enable_rule.html for full documentation.

Usage

cloudwatchevents_enable_rule(Name, EventBusName = NULL)

Arguments

Name

[required] The name of the rule.

EventBusName

The name or ARN of the event bus associated with the rule. If you omit this, the default event bus is used.