Learn R Programming

paws.management (version 0.2.0)

cloudwatchevents_list_api_destinations: Retrieves a list of API destination in the account in the current Region

Description

Retrieves a list of API destination in the account in the current Region.

See https://paws-r.github.io/docs/cloudwatchevents/list_api_destinations.html for full documentation.

Usage

cloudwatchevents_list_api_destinations(
  NamePrefix = NULL,
  ConnectionArn = NULL,
  NextToken = NULL,
  Limit = NULL
)

Arguments

NamePrefix

A name prefix to filter results returned. Only API destinations with a name that starts with the prefix are returned.

ConnectionArn

The ARN of the connection specified for the API destination.

NextToken

The token returned by a previous call to retrieve the next set of results.

Limit

The maximum number of API destinations to include in the response.