Learn R Programming

paws.management (version 0.2.0)

cloudwatchevents_list_connections: Retrieves a list of connections from the account

Description

Retrieves a list of connections from the account.

See https://paws-r.github.io/docs/cloudwatchevents/list_connections.html for full documentation.

Usage

cloudwatchevents_list_connections(
  NamePrefix = NULL,
  ConnectionState = NULL,
  NextToken = NULL,
  Limit = NULL
)

Arguments

NamePrefix

A name prefix to filter results returned. Only connections with a name that starts with the prefix are returned.

ConnectionState

The state of the connection.

NextToken

The token returned by a previous call to retrieve the next set of results.

Limit

The maximum number of connections to return.