Lists all the event buses in your account, including the default event bus, custom event buses, and partner event buses.
See https://paws-r.github.io/docs/cloudwatchevents/list_event_buses.html for full documentation.
cloudwatchevents_list_event_buses(
NamePrefix = NULL,
NextToken = NULL,
Limit = NULL
)Specifying this limits the results to only those event buses with names that start with the specified prefix.
The token returned by a previous call to retrieve the next set of results.
Specifying this limits the number of results returned by this operation. The operation also returns a NextToken which you can use in a subsequent operation to retrieve the next set of results.