An SaaS partner can use this operation to list all the partner event source names that they have created. This operation is not used by Amazon Web Services customers.
See https://paws-r.github.io/docs/cloudwatchevents/list_partner_event_sources.html for full documentation.
cloudwatchevents_list_partner_event_sources(
NamePrefix,
NextToken = NULL,
Limit = NULL
)[required] If you specify this, the results are limited to only those partner event sources that start with the string you specify.
The token returned by a previous call to this operation. Specifying this retrieves the next set of results.
pecifying this limits the number of results returned by this operation. The operation also returns a NextToken which you can use in a subsequent operation to retrieve the next set of results.