This is used by SaaS partners to write events to a customer's partner event bus. Amazon Web Services customers do not use this operation.
See https://paws-r.github.io/docs/cloudwatchevents/put_partner_events.html for full documentation.
cloudwatchevents_put_partner_events(Entries)[required] The list of events to write to the event bus.