Tests whether the specified event pattern matches the provided event.
See https://paws-r.github.io/docs/cloudwatchevents/test_event_pattern.html for full documentation.
cloudwatchevents_test_event_pattern(EventPattern, Event)[required] The event pattern. For more information, see Events and Event Patterns in the Amazon EventBridge User Guide.
[required] The event, in JSON format, to test against the event pattern. The JSON must follow the format specified in Amazon Web Services Events, and the following fields are mandatory:
id
account
source
time
region
resources
detail-type