Removes one or more tags from the specified EventBridge resource. In Amazon EventBridge (CloudWatch Events), rules and event buses can be tagged.
See https://paws-r.github.io/docs/cloudwatchevents/untag_resource.html for full documentation.
cloudwatchevents_untag_resource(ResourceARN, TagKeys)[required] The ARN of the EventBridge resource from which you are removing tags.
[required] The list of tag keys to remove from the resource.