Learn R Programming

paws.management (version 0.2.0)

cloudwatchevidently_delete_experiment: Deletes an Evidently experiment

Description

Deletes an Evidently experiment. The feature used for the experiment is not deleted.

See https://paws-r.github.io/docs/cloudwatchevidently/delete_experiment.html for full documentation.

Usage

cloudwatchevidently_delete_experiment(experiment, project)

Arguments

experiment

[required] The name of the experiment to delete.

project

[required] The name or ARN of the project that contains the experiment to delete.