Learn R Programming

paws.management (version 0.2.0)

cloudwatchevidently_delete_launch: Deletes an Evidently launch

Description

Deletes an Evidently launch. The feature used for the launch is not deleted.

See https://paws-r.github.io/docs/cloudwatchevidently/delete_launch.html for full documentation.

Usage

cloudwatchevidently_delete_launch(launch, project)

Arguments

launch

[required] The name of the launch to delete.

project

[required] The name or ARN of the project that contains the launch to delete.