Returns the details about one experiment. You must already know the experiment name. To retrieve a list of experiments in your account, use list_experiments.
See https://paws-r.github.io/docs/cloudwatchevidently/get_experiment.html for full documentation.
cloudwatchevidently_get_experiment(experiment, project)[required] The name of the experiment that you want to see the details of.
[required] The name or ARN of the project that contains the experiment.