Returns the details about one feature. You must already know the feature name. To retrieve a list of features in your account, use list_features.
See https://paws-r.github.io/docs/cloudwatchevidently/get_feature.html for full documentation.
cloudwatchevidently_get_feature(feature, project)[required] The name of the feature that you want to retrieve information for.
[required] The name or ARN of the project that contains the feature.