Learn R Programming

paws.management (version 0.2.0)

cloudwatchevidently_get_launch: Returns the details about one launch

Description

Returns the details about one launch. You must already know the launch name. To retrieve a list of launches in your account, use list_launches.

See https://paws-r.github.io/docs/cloudwatchevidently/get_launch.html for full documentation.

Usage

cloudwatchevidently_get_launch(launch, project)

Arguments

launch

[required] The name of the launch that you want to see the details of.

project

[required] The name or ARN of the project that contains the launch.