Learn R Programming

paws.management (version 0.2.0)

cloudwatchevidently_get_project: Returns the details about one launch

Description

Returns the details about one launch. You must already know the project name. To retrieve a list of projects in your account, use list_projects.

See https://paws-r.github.io/docs/cloudwatchevidently/get_project.html for full documentation.

Usage

cloudwatchevidently_get_project(project)

Arguments

project

[required] The name or ARN of the project that you want to see the details of.