Learn R Programming

paws.management (version 0.2.0)

cloudwatchevidently_list_features: Returns configuration details about all the features in the specified project

Description

Returns configuration details about all the features in the specified project.

See https://paws-r.github.io/docs/cloudwatchevidently/list_features.html for full documentation.

Usage

cloudwatchevidently_list_features(maxResults = NULL, nextToken = NULL, project)

Arguments

maxResults

The maximum number of results to include in the response.

nextToken

The token to use when requesting the next set of results. You received this token from a previous list_features operation.

project

[required] The name or ARN of the project to return the feature list from.