Learn R Programming

paws.management (version 0.2.0)

cloudwatchevidently_stop_experiment: Stops an experiment that is currently running

Description

Stops an experiment that is currently running. If you stop an experiment, you can't resume it or restart it.

See https://paws-r.github.io/docs/cloudwatchevidently/stop_experiment.html for full documentation.

Usage

cloudwatchevidently_stop_experiment(
  desiredState = NULL,
  experiment,
  project,
  reason = NULL
)

Arguments

desiredState

Specify whether the experiment is to be considered COMPLETED or CANCELLED after it stops.

experiment

[required] The name of the experiment to stop.

project

[required] The name or ARN of the project that contains the experiment to stop.

reason

A string that describes why you are stopping the experiment.