Use this operation to test a rules pattern that you plan to use to create an audience segment. For more information about segments, see create_segment.
See https://paws-r.github.io/docs/cloudwatchevidently/test_segment_pattern.html for full documentation.
cloudwatchevidently_test_segment_pattern(pattern, payload)[required] The pattern to test.
[required] A sample evaluationContext JSON block to test against the specified
pattern.