Learn R Programming

paws.management (version 0.2.0)

cloudwatchevidently_untag_resource: Removes one or more tags from the specified resource

Description

Removes one or more tags from the specified resource.

See https://paws-r.github.io/docs/cloudwatchevidently/untag_resource.html for full documentation.

Usage

cloudwatchevidently_untag_resource(resourceArn, tagKeys)

Arguments

resourceArn

[required] The ARN of the CloudWatch Evidently resource that you're removing tags from.

tagKeys

[required] The list of tag keys to remove from the resource.