Learn R Programming

paws.management (version 0.2.0)

cloudwatchlogs_create_log_stream: Creates a log stream for the specified log group

Description

Creates a log stream for the specified log group. A log stream is a sequence of log events that originate from a single source, such as an application instance or a resource that is being monitored.

See https://paws-r.github.io/docs/cloudwatchlogs/create_log_stream.html for full documentation.

Usage

cloudwatchlogs_create_log_stream(logGroupName, logStreamName)

Arguments

logGroupName

[required] The name of the log group.

logStreamName

[required] The name of the log stream.