Deletes the specified destination, and eventually disables all the subscription filters that publish to it. This operation does not delete the physical resource encapsulated by the destination.
See https://paws-r.github.io/docs/cloudwatchlogs/delete_destination.html for full documentation.
cloudwatchlogs_delete_destination(destinationName)[required] The name of the destination.