Deletes the specified log group and permanently deletes all the archived log events associated with the log group.
See https://paws-r.github.io/docs/cloudwatchlogs/delete_log_group.html for full documentation.
cloudwatchlogs_delete_log_group(logGroupName)[required] The name of the log group.