Deletes the specified log stream and permanently deletes all the archived log events associated with the log stream.
See https://paws-r.github.io/docs/cloudwatchlogs/delete_log_stream.html for full documentation.
cloudwatchlogs_delete_log_stream(logGroupName, logStreamName)[required] The name of the log group.
[required] The name of the log stream.