Deletes a saved CloudWatch Logs Insights query definition. A query definition contains details about a saved CloudWatch Logs Insights query.
See https://paws-r.github.io/docs/cloudwatchlogs/delete_query_definition.html for full documentation.
cloudwatchlogs_delete_query_definition(queryDefinitionId)[required] The ID of the query definition that you want to delete. You can use
describe_query_definitions
to retrieve the IDs of your saved query definitions.