Learn R Programming

paws.management (version 0.2.0)

cloudwatchlogs_delete_resource_policy: Deletes a resource policy from this account

Description

Deletes a resource policy from this account. This revokes the access of the identities in that policy to put log events to this account.

See https://paws-r.github.io/docs/cloudwatchlogs/delete_resource_policy.html for full documentation.

Usage

cloudwatchlogs_delete_resource_policy(policyName = NULL)

Arguments

policyName

The name of the policy to be revoked. This parameter is required.