Learn R Programming

paws.management (version 0.2.0)

cloudwatchlogs_describe_destinations: Lists all your destinations

Description

Lists all your destinations. The results are ASCII-sorted by destination name.

See https://paws-r.github.io/docs/cloudwatchlogs/describe_destinations.html for full documentation.

Usage

cloudwatchlogs_describe_destinations(
  DestinationNamePrefix = NULL,
  nextToken = NULL,
  limit = NULL
)

Arguments

DestinationNamePrefix

The prefix to match. If you don't specify a value, no prefix filter is applied.

nextToken

The token for the next set of items to return. (You received this token from a previous call.)

limit

The maximum number of items returned. If you don't specify a value, the default is up to 50 items.