Lists the specified export tasks. You can list all your export tasks or filter the results based on task ID or task status.
See https://paws-r.github.io/docs/cloudwatchlogs/describe_export_tasks.html for full documentation.
cloudwatchlogs_describe_export_tasks(
taskId = NULL,
statusCode = NULL,
nextToken = NULL,
limit = NULL
)The ID of the export task. Specifying a task ID filters the results to zero or one export tasks.
The status code of the export task. Specifying a status code filters the results to zero or more export tasks.
The token for the next set of items to return. (You received this token from a previous call.)
The maximum number of items returned. If you don't specify a value, the default is up to 50 items.