Lists the subscription filters for the specified log group. You can list all the subscription filters or filter the results by prefix. The results are ASCII-sorted by filter name.
cloudwatchlogs_describe_subscription_filters(logGroupName,
filterNamePrefix, nextToken, limit)[required] The name of the log group.
The prefix to match. If you don't specify a value, no prefix filter is applied.
The token for the next set of items to return. (You received this token from a previous call.)
The maximum number of items returned. If you don't specify a value, the default is up to 50 items.
svc$describe_subscription_filters( logGroupName = "string", filterNamePrefix = "string", nextToken = "string", limit = 123 )