Learn R Programming

paws.management (version 0.2.0)

cloudwatchlogs_disassociate_kms_key: Disassociates the associated Key Management Service customer master key (CMK) from the specified log group

Description

Disassociates the associated Key Management Service customer master key (CMK) from the specified log group.

See https://paws-r.github.io/docs/cloudwatchlogs/disassociate_kms_key.html for full documentation.

Usage

cloudwatchlogs_disassociate_kms_key(logGroupName)

Arguments

logGroupName

[required] The name of the log group.