Learn R Programming

paws.management (version 0.2.0)

cloudwatchlogs_get_log_events: Lists log events from the specified log stream

Description

Lists log events from the specified log stream. You can list all of the log events or filter using a time range.

See https://paws-r.github.io/docs/cloudwatchlogs/get_log_events.html for full documentation.

Usage

cloudwatchlogs_get_log_events(
  logGroupName,
  logStreamName,
  startTime = NULL,
  endTime = NULL,
  nextToken = NULL,
  limit = NULL,
  startFromHead = NULL
)

Arguments

logGroupName

[required] The name of the log group.

logStreamName

[required] The name of the log stream.

startTime

The start of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp equal to this time or later than this time are included. Events with a timestamp earlier than this time are not included.

endTime

The end of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp equal to or later than this time are not included.

nextToken

The token for the next set of items to return. (You received this token from a previous call.)

limit

The maximum number of log events returned. If you don't specify a value, the maximum is as many log events as can fit in a response size of 1 MB, up to 10,000 log events.

startFromHead

If the value is true, the earliest log events are returned first. If the value is false, the latest log events are returned first. The default value is false.

If you are using a previous nextForwardToken value as the nextToken in this operation, you must specify true for startFromHead.