Returns the results from the specified query.
Only the fields requested in the query are returned, along with a @ptr
field, which is the identifier for the log record. You can use the value
of @ptr in a get_log_record
operation to get the full log record.
get_query_results does not start a
query execution. To run a query, use
start_query.
If the value of the Status field in the output is Running, this
operation returns only partial results. If you see a value of
Scheduled or Running for the status, you can retry the operation
later to see the final results.
cloudwatchlogs_get_query_results(queryId)[required] The ID number of the query.
A list with the following syntax:
list(
results = list(
list(
list(
field = "string",
value = "string"
)
)
),
statistics = list(
recordsMatched = 123.0,
recordsScanned = 123.0,
bytesScanned = 123.0
),
status = "Scheduled"|"Running"|"Complete"|"Failed"|"Cancelled"
)
svc$get_query_results( queryId = "string" )