Learn R Programming

paws.management (version 0.2.0)

cloudwatchlogs_put_destination: Creates or updates a destination

Description

Creates or updates a destination. This operation is used only to create destinations for cross-account subscriptions.

See https://paws-r.github.io/docs/cloudwatchlogs/put_destination.html for full documentation.

Usage

cloudwatchlogs_put_destination(destinationName, targetArn, roleArn)

Arguments

destinationName

[required] A name for the destination.

targetArn

[required] The ARN of an Amazon Kinesis stream to which to deliver matching log events.

roleArn

[required] The ARN of an IAM role that grants CloudWatch Logs permissions to call the Amazon Kinesis PutRecord operation on the destination stream.