Creates or updates an access policy associated with an existing destination. An access policy is an IAM policy document that is used to authorize claims to register a subscription filter against a given destination.
See https://paws-r.github.io/docs/cloudwatchlogs/put_destination_policy.html for full documentation.
cloudwatchlogs_put_destination_policy(
destinationName,
accessPolicy,
forceUpdate = NULL
)[required] A name for an existing destination.
[required] An IAM policy document that authorizes cross-account users to deliver their log events to the associated destination. This can be up to 5120 bytes.
Specify true if you are updating an existing destination policy to grant
permission to an organization ID instead of granting permission to
individual AWS accounts. Before you update a destination policy this
way, you must first update the subscription filters in the accounts that
send logs to this destination. If you do not, the subscription filters
might stop working. By specifying true for forceUpdate, you are
affirming that you have already updated the subscription filters. For
more information, see Updating an existing cross-account subscription
If you omit this parameter, the default of false is used.