Learn R Programming

paws.management (version 0.2.0)

cloudwatchlogs_put_log_events: Uploads a batch of log events to the specified log stream

Description

Uploads a batch of log events to the specified log stream.

See https://paws-r.github.io/docs/cloudwatchlogs/put_log_events.html for full documentation.

Usage

cloudwatchlogs_put_log_events(
  logGroupName,
  logStreamName,
  logEvents,
  sequenceToken = NULL
)

Arguments

logGroupName

[required] The name of the log group.

logStreamName

[required] The name of the log stream.

logEvents

[required] The log events.

sequenceToken

The sequence token obtained from the response of the previous put_log_events call. An upload in a newly created log stream does not require a sequence token. You can also get the sequence token using describe_log_streams. If you call put_log_events twice within a narrow time period using the same value for sequenceToken, both calls might be successful or one might be rejected.