Learn R Programming

paws.management (version 0.2.0)

cloudwatchlogs_stop_query: Stops a CloudWatch Logs Insights query that is in progress

Description

Stops a CloudWatch Logs Insights query that is in progress. If the query has already ended, the operation returns an error indicating that the specified query is not running.

See https://paws-r.github.io/docs/cloudwatchlogs/stop_query.html for full documentation.

Usage

cloudwatchlogs_stop_query(queryId)

Arguments

queryId

[required] The ID number of the query to stop. To find this ID number, use describe_queries.