Adds or updates the specified tags for the specified log group.
cloudwatchlogs_tag_log_group(logGroupName, tags)[required] The name of the log group.
[required] The key-value pairs to use for the tags.
svc$tag_log_group(
logGroupName = "string",
tags = list(
"string"
)
)
To list the tags for a log group, use ListTagsLogGroup. To remove tags, use UntagLogGroup.
For more information about tags, see Tag Log Groups in Amazon CloudWatch Logs in the Amazon CloudWatch Logs User Guide.