Learn R Programming

paws.management (version 0.2.0)

cloudwatchrum_list_app_monitors: Returns a list of the Amazon CloudWatch RUM app monitors in the account

Description

Returns a list of the Amazon CloudWatch RUM app monitors in the account.

See https://paws-r.github.io/docs/cloudwatchrum/list_app_monitors.html for full documentation.

Usage

cloudwatchrum_list_app_monitors(MaxResults = NULL, NextToken = NULL)

Arguments

MaxResults

The maximum number of results to return in one operation.

NextToken

Use the token returned by the previous operation to request the next page of results.