Learn R Programming

paws.management (version 0.2.0)

cloudwatchrum_untag_resource: Removes one or more tags from the specified resource

Description

Removes one or more tags from the specified resource.

See https://paws-r.github.io/docs/cloudwatchrum/untag_resource.html for full documentation.

Usage

cloudwatchrum_untag_resource(ResourceArn, TagKeys)

Arguments

ResourceArn

[required] The ARN of the CloudWatch RUM resource that you're removing tags from.

TagKeys

[required] The list of tag keys to remove from the resource.