Learn R Programming

paws.management (version 0.2.0)

configservice_delete_aggregation_authorization: Deletes the authorization granted to the specified configuration aggregator account in a specified region

Description

Deletes the authorization granted to the specified configuration aggregator account in a specified region.

See https://paws-r.github.io/docs/configservice/delete_aggregation_authorization.html for full documentation.

Usage

configservice_delete_aggregation_authorization(
  AuthorizedAccountId,
  AuthorizedAwsRegion
)

Arguments

AuthorizedAccountId

[required] The 12-digit account ID of the account authorized to aggregate data.

AuthorizedAwsRegion

[required] The region authorized to collect aggregated data.