powered by
Deletes the specified Config rule and all of its evaluation results.
See https://paws-r.github.io/docs/configservice/delete_config_rule.html for full documentation.
configservice_delete_config_rule(ConfigRuleName)
[required] The name of the Config rule that you want to delete.