Learn R Programming

paws.management (version 0.2.0)

configservice_delete_configuration_aggregator: Deletes the specified configuration aggregator and the aggregated data associated with the aggregator

Description

Deletes the specified configuration aggregator and the aggregated data associated with the aggregator.

See https://paws-r.github.io/docs/configservice/delete_configuration_aggregator.html for full documentation.

Usage

configservice_delete_configuration_aggregator(ConfigurationAggregatorName)

Arguments

ConfigurationAggregatorName

[required] The name of the configuration aggregator.