Deletes the specified conformance pack and all the Config rules, remediation actions, and all evaluation results within that conformance pack.
See https://paws-r.github.io/docs/configservice/delete_conformance_pack.html for full documentation.
configservice_delete_conformance_pack(ConformancePackName)[required] Name of the conformance pack you want to delete.