Deletes the evaluation results for the specified Config rule. You can specify one Config rule per request. After you delete the evaluation results, you can call the start_config_rules_evaluation API to start evaluating your Amazon Web Services resources against the rule.
See https://paws-r.github.io/docs/configservice/delete_evaluation_results.html for full documentation.
configservice_delete_evaluation_results(ConfigRuleName)[required] The name of the Config rule for which you want to delete the evaluation results.