Deletes the specified organization Config rule and all of its evaluation results from all member accounts in that organization.
See https://paws-r.github.io/docs/configservice/delete_organization_config_rule.html for full documentation.
configservice_delete_organization_config_rule(OrganizationConfigRuleName)[required] The name of organization Config rule that you want to delete.