Deletes the specified organization conformance pack and all of the Config rules and remediation actions from all member accounts in that organization.
See https://paws-r.github.io/docs/configservice/delete_organization_conformance_pack.html for full documentation.
configservice_delete_organization_conformance_pack(
OrganizationConformancePackName
)[required] The name of organization conformance pack that you want to delete.