Learn R Programming

paws.management (version 0.2.0)

configservice_delete_remediation_exceptions: Deletes one or more remediation exceptions mentioned in the resource keys

Description

Deletes one or more remediation exceptions mentioned in the resource keys.

See https://paws-r.github.io/docs/configservice/delete_remediation_exceptions.html for full documentation.

Usage

configservice_delete_remediation_exceptions(ConfigRuleName, ResourceKeys)

Arguments

ConfigRuleName

[required] The name of the Config rule for which you want to delete remediation exception configuration.

ResourceKeys

[required] An exception list of resource exception keys to be processed with the current request. Config adds exception for each resource key. For example, Config adds 3 exceptions for 3 resource keys.