Records the configuration state for a custom resource that has been deleted. This API records a new ConfigurationItem with a ResourceDeleted status. You can retrieve the ConfigurationItems recorded for this resource in your Config History.
See https://paws-r.github.io/docs/configservice/delete_resource_config.html for full documentation.
configservice_delete_resource_config(ResourceType, ResourceId)[required] The type of the resource.
[required] Unique identifier of the resource.