Learn R Programming

paws.management (version 0.2.0)

configservice_delete_stored_query: Deletes the stored query for a single Amazon Web Services account and a single Amazon Web Services Region

Description

Deletes the stored query for a single Amazon Web Services account and a single Amazon Web Services Region.

See https://paws-r.github.io/docs/configservice/delete_stored_query.html for full documentation.

Usage

configservice_delete_stored_query(QueryName)

Arguments

QueryName

[required] The name of the query that you want to delete.