Learn R Programming

paws.management (version 0.2.0)

configservice_describe_compliance_by_config_rule: Indicates whether the specified Config rules are compliant

Description

Indicates whether the specified Config rules are compliant. If a rule is noncompliant, this action returns the number of Amazon Web Services resources that do not comply with the rule.

See https://paws-r.github.io/docs/configservice/describe_compliance_by_config_rule.html for full documentation.

Usage

configservice_describe_compliance_by_config_rule(
  ConfigRuleNames = NULL,
  ComplianceTypes = NULL,
  NextToken = NULL
)

Arguments

ConfigRuleNames

Specify one or more Config rule names to filter the results by rule.

ComplianceTypes

Filters the results by compliance.

The allowed values are COMPLIANT and NON_COMPLIANT.

NextToken

The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.