Returns details about your Config rules.
See https://paws-r.github.io/docs/configservice/describe_config_rules.html for full documentation.
configservice_describe_config_rules(ConfigRuleNames = NULL, NextToken = NULL)The names of the Config rules for which you want details. If you do not specify any names, Config returns details for all your rules.
The nextToken string returned on a previous page that you use to get
the next page of results in a paginated response.