Learn R Programming

paws.management (version 0.2.0)

configservice_describe_configuration_recorder_status: Returns the current status of the specified configuration recorder

Description

Returns the current status of the specified configuration recorder. If a configuration recorder is not specified, this action returns the status of all configuration recorders associated with the account.

See https://paws-r.github.io/docs/configservice/describe_configuration_recorder_status.html for full documentation.

Usage

configservice_describe_configuration_recorder_status(
  ConfigurationRecorderNames = NULL
)

Arguments

ConfigurationRecorderNames

The name(s) of the configuration recorder. If the name is not specified, the action returns the current status of all the configuration recorders associated with the account.