Returns the details for the specified configuration recorders. If the configuration recorder is not specified, this action returns the details for all configuration recorders associated with the account.
See https://paws-r.github.io/docs/configservice/describe_configuration_recorders.html for full documentation.
configservice_describe_configuration_recorders(
ConfigurationRecorderNames = NULL
)A list of configuration recorder names.