Returns compliance details for each rule in that conformance pack.
See https://paws-r.github.io/docs/configservice/describe_conformance_pack_compliance.html for full documentation.
configservice_describe_conformance_pack_compliance(
ConformancePackName,
Filters = NULL,
Limit = NULL,
NextToken = NULL
)[required] Name of the conformance pack.
A ConformancePackComplianceFilters object.
The maximum number of Config rules within a conformance pack are returned on each page.
The nextToken string returned in a previous request that you use to
request the next page of results in a paginated response.