Provides one or more conformance packs deployment status.
See https://paws-r.github.io/docs/configservice/describe_conformance_pack_status.html for full documentation.
configservice_describe_conformance_pack_status(
ConformancePackNames = NULL,
Limit = NULL,
NextToken = NULL
)Comma-separated list of conformance pack names.
The maximum number of conformance packs status returned on each page.
The nextToken string returned in a previous request that you use to
request the next page of results in a paginated response.