Returns the current status of the specified delivery channel. If a delivery channel is not specified, this action returns the current status of all delivery channels associated with the account.
See https://paws-r.github.io/docs/configservice/describe_delivery_channel_status.html for full documentation.
configservice_describe_delivery_channel_status(DeliveryChannelNames = NULL)A list of delivery channel names.