Returns details about the specified delivery channel. If a delivery channel is not specified, this action returns the details of all delivery channels associated with the account.
See https://paws-r.github.io/docs/configservice/describe_delivery_channels.html for full documentation.
configservice_describe_delivery_channels(DeliveryChannelNames = NULL)A list of delivery channel names.