Returns a list of all pending aggregation requests.
See https://paws-r.github.io/docs/configservice/describe_pending_aggregation_requests.html for full documentation.
configservice_describe_pending_aggregation_requests(
Limit = NULL,
NextToken = NULL
)The maximum number of evaluation results returned on each page. The default is maximum. If you specify 0, Config uses the default.
The nextToken string returned on a previous page that you use to get
the next page of results in a paginated response.