Learn R Programming

paws.management (version 0.2.0)

configservice_get_aggregate_resource_config: Returns configuration item that is aggregated for your specific resource in a specific source account and region

Description

Returns configuration item that is aggregated for your specific resource in a specific source account and region.

See https://paws-r.github.io/docs/configservice/get_aggregate_resource_config.html for full documentation.

Usage

configservice_get_aggregate_resource_config(
  ConfigurationAggregatorName,
  ResourceIdentifier
)

Arguments

ConfigurationAggregatorName

[required] The name of the configuration aggregator.

ResourceIdentifier

[required] An object that identifies aggregate resource.