Learn R Programming

paws.management (version 0.2.0)

configservice_get_compliance_summary_by_config_rule: Returns the number of Config rules that are compliant and noncompliant, up to a maximum of 25 for each

Description

Returns the number of Config rules that are compliant and noncompliant, up to a maximum of 25 for each.

See https://paws-r.github.io/docs/configservice/get_compliance_summary_by_config_rule.html for full documentation.

Usage

configservice_get_compliance_summary_by_config_rule()

Arguments