Returns compliance details for the conformance pack based on the cumulative compliance results of all the rules in that conformance pack.
See https://paws-r.github.io/docs/configservice/get_conformance_pack_compliance_summary.html for full documentation.
configservice_get_conformance_pack_compliance_summary(
ConformancePackNames,
Limit = NULL,
NextToken = NULL
)[required] Names of conformance packs.
The maximum number of conformance packs returned on each page.
The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.