Learn R Programming

paws.management (version 0.2.0)

configservice_get_custom_rule_policy: Returns the policy definition containing the logic for your Config Custom Policy rule

Description

Returns the policy definition containing the logic for your Config Custom Policy rule.

See https://paws-r.github.io/docs/configservice/get_custom_rule_policy.html for full documentation.

Usage

configservice_get_custom_rule_policy(ConfigRuleName = NULL)

Arguments

ConfigRuleName

The name of your Config Custom Policy rule.