Lists the stored queries for a single Amazon Web Services account and a single Amazon Web Services Region. The default is 100.
See https://paws-r.github.io/docs/configservice/list_stored_queries.html for full documentation.
configservice_list_stored_queries(NextToken = NULL, MaxResults = NULL)The nextToken string returned in a previous request that you use to request the next page of results in a paginated response.
The maximum number of results to be returned with a single call.