List the tags for Config resource.
See https://www.paws-r-sdk.com/docs/configservice_list_tags_for_resource/ for full documentation.
configservice_list_tags_for_resource(
ResourceArn,
Limit = NULL,
NextToken = NULL
)[required] The Amazon Resource Name (ARN) that identifies the resource for which to
list the tags. Currently, the supported resources are ConfigRule,
ConfigurationAggregator and AggregatorAuthorization.
The maximum number of tags returned on each page. The limit maximum is 50. You cannot specify a number greater than 50. If you specify 0, Config uses the default.
The nextToken string returned on a previous page that you use to get
the next page of results in a paginated response.