Learn R Programming

paws.management (version 0.2.0)

configservice_put_configuration_recorder: Creates a new configuration recorder to record the selected resource configurations

Description

Creates a new configuration recorder to record the selected resource configurations.

See https://paws-r.github.io/docs/configservice/put_configuration_recorder.html for full documentation.

Usage

configservice_put_configuration_recorder(ConfigurationRecorder)

Arguments

ConfigurationRecorder

[required] The configuration recorder object that records each configuration change made to the resources.