Learn R Programming

paws.management (version 0.2.0)

configservice_put_delivery_channel: Creates a delivery channel object to deliver configuration information to an Amazon S3 bucket and Amazon SNS topic

Description

Creates a delivery channel object to deliver configuration information to an Amazon S3 bucket and Amazon SNS topic.

See https://paws-r.github.io/docs/configservice/put_delivery_channel.html for full documentation.

Usage

configservice_put_delivery_channel(DeliveryChannel)

Arguments

DeliveryChannel

[required] The configuration delivery channel object that delivers the configuration information to an Amazon S3 bucket and to an Amazon SNS topic.