Add or updates the evaluations for process checks. This API checks if the rule is a process check when the name of the Config rule is provided.
See https://paws-r.github.io/docs/configservice/put_external_evaluation.html for full documentation.
configservice_put_external_evaluation(ConfigRuleName, ExternalEvaluation)[required] The name of the Config rule.
[required] An ExternalEvaluation object that provides details about compliance.