Learn R Programming

paws.management (version 0.2.0)

configservice_put_remediation_exceptions: A remediation exception is when a specific resource is no longer considered for auto-remediation

Description

A remediation exception is when a specific resource is no longer considered for auto-remediation. This API adds a new exception or updates an existing exception for a specific resource with a specific Config rule.

See https://paws-r.github.io/docs/configservice/put_remediation_exceptions.html for full documentation.

Usage

configservice_put_remediation_exceptions(
  ConfigRuleName,
  ResourceKeys,
  Message = NULL,
  ExpirationTime = NULL
)

Arguments

ConfigRuleName

[required] The name of the Config rule for which you want to create remediation exception.

ResourceKeys

[required] An exception list of resource exception keys to be processed with the current request. Config adds exception for each resource key. For example, Config adds 3 exceptions for 3 resource keys.

Message

The message contains an explanation of the exception.

ExpirationTime

The exception is automatically deleted after the expiration date.