Accepts a structured query language (SQL) SELECT command, performs the corresponding search, and returns resource configurations matching the properties.
See https://paws-r.github.io/docs/configservice/select_resource_config.html for full documentation.
configservice_select_resource_config(
Expression,
Limit = NULL,
NextToken = NULL
)[required] The SQL query SELECT command.
The maximum number of query results returned on each page.
The nextToken string returned in a previous request that you use to
request the next page of results in a paginated response.