Runs an on-demand evaluation for the specified Config rules against the last known configuration state of the resources. Use start_config_rules_evaluation when you want to test that a rule you updated is working as expected. start_config_rules_evaluation does not re-record the latest configuration state for your resources. It re-runs an evaluation against the last known state of your resources.
See https://paws-r.github.io/docs/configservice/start_config_rules_evaluation.html for full documentation.
configservice_start_config_rules_evaluation(ConfigRuleNames = NULL)The list of names of Config rules that you want to run evaluations for.