Stops recording configurations of the Amazon Web Services resources you have selected to record in your Amazon Web Services account.
See https://paws-r.github.io/docs/configservice/stop_configuration_recorder.html for full documentation.
configservice_stop_configuration_recorder(ConfigurationRecorderName)[required] The name of the recorder object that records each configuration change made to the resources.