Associates the specified tags to a resource with the specified resourceArn. If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are deleted as well.
See https://paws-r.github.io/docs/configservice/tag_resource.html for full documentation.
configservice_tag_resource(ResourceArn, Tags)[required] The Amazon Resource Name (ARN) that identifies the resource for which to
list the tags. Currently, the supported resources are ConfigRule,
ConfigurationAggregator and AggregatorAuthorization.
[required] An array of tag object.