Removes metadata tags from a FinSpace resource.
See https://paws-r.github.io/docs/finspace/untag_resource.html for full documentation.
finspace_untag_resource(resourceArn, tagKeys)[required] A FinSpace resource from which you want to remove a tag or tags. The value for this parameter is an Amazon Resource Name (ARN).
[required] The tag keys (names) of one or more tags to be removed.