Learn R Programming

paws.management (version 0.2.0)

health_disable_health_service_access_for_organization: Disables Health from working with Organizations

Description

Disables Health from working with Organizations. To call this operation, you must sign in as an Identity and Access Management (IAM) user, assume an IAM role, or sign in as the root user (not recommended) in the organization's management account. For more information, see Aggregating Health events in the Health User Guide.

See https://paws-r.github.io/docs/health/disable_health_service_access_for_organization.html for full documentation.

Usage

health_disable_health_service_access_for_organization()

Arguments