Enables Health to work with Organizations. You can use the organizational view feature to aggregate events from all Amazon Web Services accounts in your organization in a centralized location.
See https://paws-r.github.io/docs/health/enable_health_service_access_for_organization.html for full documentation.
health_enable_health_service_access_for_organization()