Learn R Programming

paws.management (version 0.2.0)

licensemanager_create_grant: Creates a grant for the specified license

Description

Creates a grant for the specified license. A grant shares the use of license entitlements with specific Amazon Web Services accounts.

See https://paws-r.github.io/docs/licensemanager/create_grant.html for full documentation.

Usage

licensemanager_create_grant(
  ClientToken,
  GrantName,
  LicenseArn,
  Principals,
  HomeRegion,
  AllowedOperations
)

Arguments

ClientToken

[required] Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

GrantName

[required] Grant name.

LicenseArn

[required] Amazon Resource Name (ARN) of the license.

Principals

[required] The grant principals.

HomeRegion

[required] Home Region of the grant.

AllowedOperations

[required] Allowed operations for the grant.