Learn R Programming

paws.management (version 0.2.0)

licensemanager_create_license_conversion_task_for_resource: Creates a new license conversion task

Description

Creates a new license conversion task.

See https://paws-r.github.io/docs/licensemanager/create_license_conversion_task_for_resource.html for full documentation.

Usage

licensemanager_create_license_conversion_task_for_resource(
  ResourceArn,
  SourceLicenseContext,
  DestinationLicenseContext
)

Arguments

ResourceArn

[required] Amazon Resource Name (ARN) of the resource you are converting the license type for.

SourceLicenseContext

[required] Information that identifies the license type you are converting from. For the structure of the source license, see Convert a license type using the AWS CLI in the License Manager User Guide.

DestinationLicenseContext

[required] Information that identifies the license type you are converting to. For the structure of the destination license, see Convert a license type using the AWS CLI in the License Manager User Guide.