Extends the expiration date for license consumption.
See https://paws-r.github.io/docs/licensemanager/extend_license_consumption.html for full documentation.
licensemanager_extend_license_consumption(
LicenseConsumptionToken,
DryRun = NULL
)[required] License consumption token.
Checks whether you have the required permissions for the action, without actually making the request. Provides an error response if you do not have the required permissions.