Learn R Programming

paws.management (version 0.2.0)

licensemanager_get_access_token: Gets a temporary access token to use with AssumeRoleWithWebIdentity

Description

Gets a temporary access token to use with AssumeRoleWithWebIdentity. Access tokens are valid for one hour.

See https://paws-r.github.io/docs/licensemanager/get_access_token.html for full documentation.

Usage

licensemanager_get_access_token(Token, TokenProperties = NULL)

Arguments

Token

[required] Refresh token, encoded as a JWT token.

TokenProperties

Token properties to validate against those present in the JWT token.