Learn R Programming

paws.management (version 0.2.0)

licensemanager_get_license_conversion_task: Gets information about the specified license type conversion task

Description

Gets information about the specified license type conversion task.

See https://paws-r.github.io/docs/licensemanager/get_license_conversion_task.html for full documentation.

Usage

licensemanager_get_license_conversion_task(LicenseConversionTaskId)

Arguments

LicenseConversionTaskId

[required] ID of the license type conversion task to retrieve information on.