Learn R Programming

paws.management (version 0.2.0)

licensemanager_get_license_usage: Gets detailed information about the usage of the specified license

Description

Gets detailed information about the usage of the specified license.

See https://paws-r.github.io/docs/licensemanager/get_license_usage.html for full documentation.

Usage

licensemanager_get_license_usage(LicenseArn)

Arguments

LicenseArn

[required] Amazon Resource Name (ARN) of the license.