Learn R Programming

paws.management (version 0.2.0)

licensemanager_get_service_settings: Gets the License Manager settings for the current Region

Description

Gets the License Manager settings for the current Region.

See https://paws-r.github.io/docs/licensemanager/get_service_settings.html for full documentation.

Usage

licensemanager_get_service_settings()

Arguments