Lists the resource associations for the specified license configuration.
See https://paws-r.github.io/docs/licensemanager/list_associations_for_license_configuration.html for full documentation.
licensemanager_list_associations_for_license_configuration(
LicenseConfigurationArn,
MaxResults = NULL,
NextToken = NULL
)[required] Amazon Resource Name (ARN) of a license configuration.
Maximum number of results to return in a single call.
Token for the next set of results.