Learn R Programming

paws.management (version 0.2.0)

licensemanager_list_license_conversion_tasks: Lists the license type conversion tasks for your account

Description

Lists the license type conversion tasks for your account.

See https://paws-r.github.io/docs/licensemanager/list_license_conversion_tasks.html for full documentation.

Usage

licensemanager_list_license_conversion_tasks(
  NextToken = NULL,
  MaxResults = NULL,
  Filters = NULL
)

Arguments

NextToken

Token for the next set of results.

MaxResults

Maximum number of results to return in a single call.

Filters

Filters to scope the results. Valid filters are ResourceArns and Status.