Learn R Programming

paws.management (version 0.2.0)

licensemanager_list_license_specifications_for_resource: Describes the license configurations for the specified resource

Description

Describes the license configurations for the specified resource.

See https://paws-r.github.io/docs/licensemanager/list_license_specifications_for_resource.html for full documentation.

Usage

licensemanager_list_license_specifications_for_resource(
  ResourceArn,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

ResourceArn

[required] Amazon Resource Name (ARN) of a resource that has an associated license configuration.

MaxResults

Maximum number of results to return in a single call.

NextToken

Token for the next set of results.