Learn R Programming

paws.management (version 0.2.0)

licensemanager_tag_resource: Adds the specified tags to the specified license configuration

Description

Adds the specified tags to the specified license configuration.

See https://paws-r.github.io/docs/licensemanager/tag_resource.html for full documentation.

Usage

licensemanager_tag_resource(ResourceArn, Tags)

Arguments

ResourceArn

[required] Amazon Resource Name (ARN) of the license configuration.

Tags

[required] One or more tags.