Learn R Programming

paws.management (version 0.2.0)

licensemanager_untag_resource: Removes the specified tags from the specified license configuration

Description

Removes the specified tags from the specified license configuration.

See https://paws-r.github.io/docs/licensemanager/untag_resource.html for full documentation.

Usage

licensemanager_untag_resource(ResourceArn, TagKeys)

Arguments

ResourceArn

[required] Amazon Resource Name (ARN) of the license configuration.

TagKeys

[required] Keys identifying the tags to remove.