Deregisters the Active Directory identity provider from License Manager user-based subscriptions.
See https://www.paws-r-sdk.com/docs/licensemanagerusersubscriptions_deregister_identity_provider/ for full documentation.
licensemanagerusersubscriptions_deregister_identity_provider(
IdentityProvider = NULL,
IdentityProviderArn = NULL,
Product = NULL
)An object that specifies details for the Active Directory identity provider.
The Amazon Resource Name (ARN) that identifies the identity provider to deregister.
The name of the user-based subscription product.
Valid values: VISUAL_STUDIO_ENTERPRISE | VISUAL_STUDIO_PROFESSIONAL
| OFFICE_PROFESSIONAL_PLUS | REMOTE_DESKTOP_SERVICES