Learn R Programming

paws.management (version 0.2.0)

licensemanagerusersubscriptions_disassociate_user: Disassociates the user from an EC2 instance providing user-based subscriptions

Description

Disassociates the user from an EC2 instance providing user-based subscriptions.

See https://paws-r.github.io/docs/licensemanagerusersubscriptions/disassociate_user.html for full documentation.

Usage

licensemanagerusersubscriptions_disassociate_user(
  Domain = NULL,
  IdentityProvider,
  InstanceId,
  Username
)

Arguments

Domain

The domain name of the user.

IdentityProvider

[required] An object that specifies details for the identity provider.

InstanceId

[required] The ID of the EC2 instance, which provides user-based subscriptions.

Username

[required] The user name from the identity provider for the user.