Lists user associations for an identity provider.
See https://paws-r.github.io/docs/licensemanagerusersubscriptions/list_user_associations.html for full documentation.
licensemanagerusersubscriptions_list_user_associations(
Filters = NULL,
IdentityProvider,
InstanceId,
MaxResults = NULL,
NextToken = NULL
)An array of structures that you can use to filter the results to those that match one or more sets of key-value pairs that you specify.
[required] An object that specifies details for the identity provider.
[required] The ID of the EC2 instance, which provides user-based subscriptions.
Maximum number of results to return in a single call.
Token for the next set of results.