Registers an identity provider for user-based subscriptions.
See https://www.paws-r-sdk.com/docs/licensemanagerusersubscriptions_register_identity_provider/ for full documentation.
licensemanagerusersubscriptions_register_identity_provider(
IdentityProvider,
Product,
Settings = NULL,
Tags = NULL
)[required] An object that specifies details for the identity provider to register.
[required] The name of the user-based subscription product.
Valid values: VISUAL_STUDIO_ENTERPRISE | VISUAL_STUDIO_PROFESSIONAL
| OFFICE_PROFESSIONAL_PLUS | REMOTE_DESKTOP_SERVICES
The registered identity provider’s product related configuration settings such as the subnets to provision VPC endpoints.
The tags that apply to the identity provider's registration.