Learn R Programming

paws.management (version 0.2.0)

licensemanagerusersubscriptions_start_product_subscription: Starts a product subscription for a user with the specified identity provider

Description

Starts a product subscription for a user with the specified identity provider.

See https://paws-r.github.io/docs/licensemanagerusersubscriptions/start_product_subscription.html for full documentation.

Usage

licensemanagerusersubscriptions_start_product_subscription(
  Domain = NULL,
  IdentityProvider,
  Product,
  Username
)

Arguments

Domain

The domain name of the user.

IdentityProvider

[required] An object that specifies details for the identity provider.

Product

[required] The name of the user-based subscription product.

Username

[required] The user name from the identity provider of the user.