Updates additional product configuration settings for the registered identity provider.
See https://www.paws-r-sdk.com/docs/licensemanagerusersubscriptions_update_identity_provider_settings/ for full documentation.
licensemanagerusersubscriptions_update_identity_provider_settings(
IdentityProvider = NULL,
IdentityProviderArn = NULL,
Product = NULL,
UpdateSettings
)
The Amazon Resource Name (ARN) of the identity provider to update.
The name of the user-based subscription product.
Valid values: VISUAL_STUDIO_ENTERPRISE | VISUAL_STUDIO_PROFESSIONAL
| OFFICE_PROFESSIONAL_PLUS
[required] Updates the registered identity provider’s product related configuration settings. You can update any combination of settings in a single operation such as the:
Subnets which you want to add to provision VPC endpoints.
Subnets which you want to remove the VPC endpoints from.
Security group ID which permits traffic to the VPC endpoints.