Learn R Programming

paws.management (version 0.2.0)

managedgrafana_create_workspace_api_key: Creates an API key for the workspace

Description

Creates an API key for the workspace. This key can be used to authenticate requests sent to the workspace's HTTP API. See https://docs.aws.amazon.com/grafana/latest/userguide/Using-Grafana-APIs.html for available APIs and example requests.

See https://paws-r.github.io/docs/managedgrafana/create_workspace_api_key.html for full documentation.

Usage

managedgrafana_create_workspace_api_key(
  keyName,
  keyRole,
  secondsToLive,
  workspaceId
)

Arguments

keyName

[required] Specifies the name of the key to create. Key names must be unique to the workspace.

keyRole

[required] Specifies the permission level of the key.

Valid Values: VIEWER | EDITOR | ADMIN

secondsToLive

[required] Specifies the time in seconds until the key expires. Keys can be valid for up to 30 days.

workspaceId

[required] The ID of the workspace in which to create an API key.