Displays information about the authentication methods used in one Amazon Managed Grafana workspace.
See https://paws-r.github.io/docs/managedgrafana/describe_workspace_authentication.html for full documentation.
managedgrafana_describe_workspace_authentication(workspaceId)[required] The ID of the workspace to return authentication information about.