Learn R Programming

paws.management (version 0.2.0)

managedgrafana_disassociate_license: Removes the Grafana Enterprise license from a workspace

Description

Removes the Grafana Enterprise license from a workspace.

See https://paws-r.github.io/docs/managedgrafana/disassociate_license.html for full documentation.

Usage

managedgrafana_disassociate_license(licenseType, workspaceId)

Arguments

licenseType

[required] The type of license to remove from the workspace.

workspaceId

[required] The ID of the workspace to remove the Grafana Enterprise license from.