Learn R Programming

paws.management (version 0.2.0)

managedgrafana_list_workspaces: Returns a list of Amazon Managed Grafana workspaces in the account, with some information about each workspace

Description

Returns a list of Amazon Managed Grafana workspaces in the account, with some information about each workspace. For more complete information about one workspace, use describe_workspace.

See https://paws-r.github.io/docs/managedgrafana/list_workspaces.html for full documentation.

Usage

managedgrafana_list_workspaces(maxResults = NULL, nextToken = NULL)

Arguments

maxResults

The maximum number of workspaces to include in the results.

nextToken

The token for the next set of workspaces to return. (You receive this token from a previous list_workspaces operation.)