Learn R Programming

paws.management (version 0.2.0)

managedgrafana_update_permissions: Updates which users in a workspace have the Grafana Admin or Editor roles

Description

Updates which users in a workspace have the Grafana Admin or Editor roles.

See https://paws-r.github.io/docs/managedgrafana/update_permissions.html for full documentation.

Usage

managedgrafana_update_permissions(updateInstructionBatch, workspaceId)

Arguments

updateInstructionBatch

[required] An array of structures that contain the permission updates to make.

workspaceId

[required] The ID of the workspace to update.