Learn R Programming

paws.management (version 0.2.0)

opsworks_assign_volume: Assigns one of the stack's registered Amazon EBS volumes to a specified instance

Description

Assigns one of the stack's registered Amazon EBS volumes to a specified instance. The volume must first be registered with the stack by calling register_volume. After you register the volume, you must call update_volume to specify a mount point before calling assign_volume. For more information, see Resource Management.

See https://paws-r.github.io/docs/opsworks/assign_volume.html for full documentation.

Usage

opsworks_assign_volume(VolumeId, InstanceId = NULL)

Arguments

VolumeId

[required] The volume ID.

InstanceId

The instance ID.