Associates one of the stack's registered Elastic IP addresses with a
specified instance. The address must first be registered with the stack
by calling register_elastic_ip. For
more information, see Resource Management.
Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.
opsworks_associate_elastic_ip(ElasticIp, InstanceId)[required] The Elastic IP address.
The instance ID.
An empty list.
svc$associate_elastic_ip( ElasticIp = "string", InstanceId = "string" )