Deletes a specified instance, which terminates the associated Amazon EC2 instance. You must stop an instance before you can delete it.
See https://paws-r.github.io/docs/opsworks/delete_instance.html for full documentation.
opsworks_delete_instance(
InstanceId,
DeleteElasticIp = NULL,
DeleteVolumes = NULL
)[required] The instance ID.
Whether to delete the instance Elastic IP address.
Whether to delete the instance's Amazon EBS volumes.