Deregister a registered Amazon EC2 or on-premises instance. This action removes the instance from the stack and returns it to your control. This action cannot be used with instances that were created with AWS OpsWorks Stacks.
See https://www.paws-r-sdk.com/docs/opsworks_deregister_instance/ for full documentation.
opsworks_deregister_instance(InstanceId)[required] The instance ID.