Learn R Programming

paws.management (version 0.3.1)

opsworks_deregister_volume: Deregisters an Amazon EBS volume

Description

Deregisters an Amazon EBS volume. The volume can then be registered by another stack. For more information, see Resource Management.

See https://www.paws-r-sdk.com/docs/opsworks_deregister_volume/ for full documentation.

Usage

opsworks_deregister_volume(VolumeId)

Arguments

VolumeId

[required] The AWS OpsWorks Stacks volume ID, which is the GUID that AWS OpsWorks Stacks assigned to the instance when you registered the volume with the stack, not the Amazon EC2 volume ID.