Learn R Programming

paws.management (version 0.2.0)

opsworks_describe_apps: Requests a description of a specified set of apps

Description

Requests a description of a specified set of apps.

See https://paws-r.github.io/docs/opsworks/describe_apps.html for full documentation.

Usage

opsworks_describe_apps(StackId = NULL, AppIds = NULL)

Arguments

StackId

The app stack ID. If you use this parameter, describe_apps returns a description of the apps in the specified stack.

AppIds

An array of app IDs for the apps to be described. If you use this parameter, describe_apps returns a description of the specified apps. Otherwise, it returns a description of every app.