Requests a description of a specified set of deployments.
See https://paws-r.github.io/docs/opsworks/describe_deployments.html for full documentation.
opsworks_describe_deployments(
StackId = NULL,
AppId = NULL,
DeploymentIds = NULL
)The stack ID. If you include this parameter, the command returns a description of the commands associated with the specified stack.
The app ID. If you include this parameter, the command returns a description of the commands associated with the specified app.
An array of deployment IDs to be described. If you include this parameter, the command returns a description of the specified deployments. Otherwise, it returns a description of every deployment.