Learn R Programming

paws.management (version 0.2.0)

opsworks_describe_instances: Requests a description of a set of instances

Description

Requests a description of a set of instances.

See https://paws-r.github.io/docs/opsworks/describe_instances.html for full documentation.

Usage

opsworks_describe_instances(StackId = NULL, LayerId = NULL, InstanceIds = NULL)

Arguments

StackId

A stack ID. If you use this parameter, describe_instances returns descriptions of the instances associated with the specified stack.

LayerId

A layer ID. If you use this parameter, describe_instances returns descriptions of the instances associated with the specified layer.

InstanceIds

An array of instance IDs to be described. If you use this parameter, describe_instances returns a description of the specified instances. Otherwise, it returns a description of every instance.