Requests a description of one or more layers in a specified stack.
See https://paws-r.github.io/docs/opsworks/describe_layers.html for full documentation.
opsworks_describe_layers(StackId = NULL, LayerIds = NULL)The stack ID.
An array of layer IDs that specify the layers to be described. If you
omit this parameter, describe_layers
returns a description of every layer in the specified stack.