Learn R Programming

paws.management (version 0.2.0)

opsworks_describe_operating_systems: Describes the operating systems that are supported by AWS OpsWorks Stacks

Description

Describes the operating systems that are supported by AWS OpsWorks Stacks.

See https://paws-r.github.io/docs/opsworks/describe_operating_systems.html for full documentation.

Usage

opsworks_describe_operating_systems()

Arguments