Learn R Programming

paws.management (version 0.2.0)

opsworks_describe_service_errors: Describes AWS OpsWorks Stacks service errors

Description

Describes AWS OpsWorks Stacks service errors.

See https://paws-r.github.io/docs/opsworks/describe_service_errors.html for full documentation.

Usage

opsworks_describe_service_errors(
  StackId = NULL,
  InstanceId = NULL,
  ServiceErrorIds = NULL
)

Arguments

StackId

The stack ID. If you use this parameter, describe_service_errors returns descriptions of the errors associated with the specified stack.

InstanceId

The instance ID. If you use this parameter, describe_service_errors returns descriptions of the errors associated with the specified instance.

ServiceErrorIds

An array of service error IDs. If you use this parameter, describe_service_errors returns descriptions of the specified errors. Otherwise, it returns a description of every error.