Describes the number of layers and apps in a specified stack, and the number of instances in each state, such as running_setup or online.
See https://paws-r.github.io/docs/opsworks/describe_stack_summary.html for full documentation.
opsworks_describe_stack_summary(StackId)[required] The stack ID.