Learn R Programming

paws.management (version 0.2.0)

opsworks_detach_elastic_load_balancer: Detaches a specified Elastic Load Balancing instance from its layer

Description

Detaches a specified Elastic Load Balancing instance from its layer.

See https://paws-r.github.io/docs/opsworks/detach_elastic_load_balancer.html for full documentation.

Usage

opsworks_detach_elastic_load_balancer(ElasticLoadBalancerName, LayerId)

Arguments

ElasticLoadBalancerName

[required] The Elastic Load Balancing instance's name.

LayerId

[required] The ID of the layer that the Elastic Load Balancing instance is attached to.