Learn R Programming

paws.management (version 0.2.0)

opsworks_get_hostname_suggestion: Gets a generated host name for the specified layer, based on the current host name theme

Description

Gets a generated host name for the specified layer, based on the current host name theme.

See https://paws-r.github.io/docs/opsworks/get_hostname_suggestion.html for full documentation.

Usage

opsworks_get_hostname_suggestion(LayerId)

Arguments

LayerId

[required] The layer ID.