Learn R Programming

paws.management (version 0.2.0)

opsworks_register_ecs_cluster: Registers a specified Amazon ECS cluster with a stack

Description

Registers a specified Amazon ECS cluster with a stack. You can register only one cluster with a stack. A cluster can be registered with only one stack. For more information, see Resource Management.

See https://paws-r.github.io/docs/opsworks/register_ecs_cluster.html for full documentation.

Usage

opsworks_register_ecs_cluster(EcsClusterArn, StackId)

Arguments

EcsClusterArn

[required] The cluster's ARN.

StackId

[required] The stack ID.