Registers an Elastic IP address with a specified stack. An address can be registered with only one stack at a time. If the address is already registered, you must first deregister it by calling deregister_elastic_ip. For more information, see Resource Management.
See https://paws-r.github.io/docs/opsworks/register_elastic_ip.html for full documentation.
opsworks_register_elastic_ip(ElasticIp, StackId)[required] The Elastic IP address.
[required] The stack ID.