Registers an Amazon EBS volume with a specified stack. A volume can be registered with only one stack at a time. If the volume is already registered, you must first deregister it by calling deregister_volume. For more information, see Resource Management.
See https://paws-r.github.io/docs/opsworks/register_volume.html for full documentation.
opsworks_register_volume(Ec2VolumeId = NULL, StackId)The Amazon EBS volume ID.
[required] The stack ID.