Learn R Programming

paws.management (version 0.2.0)

opsworks_set_load_based_auto_scaling: Specify the load-based auto scaling configuration for a specified layer

Description

Specify the load-based auto scaling configuration for a specified layer. For more information, see Managing Load with Time-based and Load-based Instances.

See https://paws-r.github.io/docs/opsworks/set_load_based_auto_scaling.html for full documentation.

Usage

opsworks_set_load_based_auto_scaling(
  LayerId,
  Enable = NULL,
  UpScaling = NULL,
  DownScaling = NULL
)

Arguments

LayerId

[required] The layer ID.

Enable

Enables load-based auto scaling for the layer.

UpScaling

An AutoScalingThresholds object with the upscaling threshold configuration. If the load exceeds these thresholds for a specified amount of time, AWS OpsWorks Stacks starts a specified number of instances.

DownScaling

An AutoScalingThresholds object with the downscaling threshold configuration. If the load falls below these thresholds for a specified amount of time, AWS OpsWorks Stacks stops a specified number of instances.