Describes backups. The results are ordered by time, with newest backups first. If you do not specify a BackupId or ServerName, the command returns all backups.
See https://paws-r.github.io/docs/opsworkscm/describe_backups.html for full documentation.
opsworkscm_describe_backups(
BackupId = NULL,
ServerName = NULL,
NextToken = NULL,
MaxResults = NULL
)Describes a single backup.
Returns backups for the server with the specified ServerName.
This is not currently implemented for
describe_backups requests.
This is not currently implemented for
describe_backups requests.