Learn R Programming

paws.management (version 0.2.0)

opsworkscm_describe_node_association_status: Returns the current status of an existing association or disassociation request

Description

Returns the current status of an existing association or disassociation request.

See https://paws-r.github.io/docs/opsworkscm/describe_node_association_status.html for full documentation.

Usage

opsworkscm_describe_node_association_status(
  NodeAssociationStatusToken,
  ServerName
)

Arguments

NodeAssociationStatusToken

[required] The token returned in either the AssociateNodeResponse or the DisassociateNodeResponse.

ServerName

[required] The name of the server from which to disassociate the node.