Closes an Amazon Web Services member account within an organization. You can't close the management account with this API. This is an asynchronous request that Amazon Web Services performs in the background. Because close_account operates asynchronously, it can return a successful completion message even though account closure might still be in progress. You need to wait a few minutes before the account is fully closed. To check the status of the request, do one of the following:
See https://paws-r.github.io/docs/organizations/close_account.html for full documentation.
organizations_close_account(AccountId)[required] Retrieves the Amazon Web Services account Id for the current
close_account API request.