Removes the specified member AWS account as a delegated administrator for the specified AWS service.
organizations_deregister_delegated_administrator(AccountId,
ServicePrincipal)[required] The account ID number of the member account in the organization that you want to deregister as a delegated administrator.
[required] The service principal name of an AWS service for which the account is a delegated administrator.
Delegated administrator privileges are revoked for only the specified AWS service from the member account. If the specified service is the only service for which the member account is a delegated administrator, the operation also revokes Organizations read action permissions.
svc$deregister_delegated_administrator( AccountId = "string", ServicePrincipal = "string" )
You can run this action only for AWS services that support this feature. For a current list of services that support it, see the column Supports Delegated Administrator in the table at AWS Services that you can use with AWS Organizations in the AWS Organizations User Guide.
This operation can be called only from the organization\'s master account.