Retrieves the current status of an asynchronous request to create an account.
See https://paws-r.github.io/docs/organizations/describe_create_account_status.html for full documentation.
organizations_describe_create_account_status(CreateAccountRequestId)[required] Specifies the Id value that uniquely identifies the
create_account request. You can get
the value from the CreateAccountStatus.Id response in an earlier
create_account request, or from the
list_create_account_status
operation.
The regex pattern for a create account request ID string requires "car-" followed by from 8 to 32 lowercase letters or digits.