Learn R Programming

paws.management (version 0.2.0)

organizations_leave_organization: Removes a member account from its parent organization

Description

Removes a member account from its parent organization. This version of the operation is performed by the account that wants to leave. To remove a member account as a user in the management account, use remove_account_from_organization instead.

See https://paws-r.github.io/docs/organizations/leave_organization.html for full documentation.

Usage

organizations_leave_organization()

Arguments