Learn R Programming

paws.management (version 0.1.9)

organizations_register_delegated_administrator: Enables the specified member account to administer the Organizations features of the specified AWS service

Description

Enables the specified member account to administer the Organizations features of the specified AWS service. It grants read-only access to AWS Organizations service data. The account still requires IAM permissions to access and administer the AWS service.

Usage

organizations_register_delegated_administrator(AccountId,
  ServicePrincipal)

Arguments

AccountId

[required] The account ID number of the member account in the organization to register as a delegated administrator.

ServicePrincipal

[required] The service principal of the AWS service for which you want to make the member account a delegated administrator.

Request syntax

svc$register_delegated_administrator(
  AccountId = "string",
  ServicePrincipal = "string"
)

Details

You can run this action only for AWS services that support this feature. For a current list of services that support it, see the column Supports Delegated Administrator in the table at AWS Services that you can use with AWS Organizations in the AWS Organizations User Guide.

This operation can be called only from the organization\'s master account.