Learn R Programming

paws.management (version 0.2.0)

pi_get_resource_metadata: Retrieve the metadata for different features

Description

Retrieve the metadata for different features. For example, the metadata might indicate that a feature is turned on or off on a specific DB instance.

See https://paws-r.github.io/docs/pi/get_resource_metadata.html for full documentation.

Usage

pi_get_resource_metadata(ServiceType, Identifier)

Arguments

ServiceType

[required] The Amazon Web Services service for which Performance Insights returns metrics.

Identifier

[required] An immutable identifier for a data source that is unique for an Amazon Web Services Region. Performance Insights gathers metrics from this data source. To use a DB instance as a data source, specify its DbiResourceId value. For example, specify db-ABCDEFGHIJKLMNOPQRSTU1VW2X.