Creates a new AMP workspace.
See https://paws-r.github.io/docs/prometheusservice/create_workspace.html for full documentation.
prometheusservice_create_workspace(
alias = NULL,
clientToken = NULL,
tags = NULL
)An optional user-assigned alias for this workspace. This alias is for user reference and does not need to be unique.
Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the request.
Optional, user-provided tags for this workspace.