Delete a rule groups namespace.
See https://paws-r.github.io/docs/prometheusservice/delete_rule_groups_namespace.html for full documentation.
prometheusservice_delete_rule_groups_namespace(
clientToken = NULL,
name,
workspaceId
)Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the request.
[required] The rule groups namespace name.
[required] The ID of the workspace to delete rule group definition.