Lists rule groups namespaces.
See https://paws-r.github.io/docs/prometheusservice/list_rule_groups_namespaces.html for full documentation.
prometheusservice_list_rule_groups_namespaces(
maxResults = NULL,
name = NULL,
nextToken = NULL,
workspaceId
)Maximum results to return in response (default=100, maximum=1000).
Optional filter for rule groups namespace name. Only the rule groups namespace that begin with this value will be returned.
Pagination token to request the next page in a paginated list. This token is obtained from the output of the previous ListRuleGroupsNamespaces request.
[required] The ID of the workspace.