Update an alert manager definition.
See https://paws-r.github.io/docs/prometheusservice/put_alert_manager_definition.html for full documentation.
prometheusservice_put_alert_manager_definition(
clientToken = NULL,
data,
workspaceId
)Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the request.
[required] The alert manager definition data.
[required] The ID of the workspace in which to update the alert manager definition.