Learn R Programming

paws.management (version 0.2.0)

prometheusservice_put_rule_groups_namespace: Update a rule groups namespace

Description

Update a rule groups namespace.

See https://paws-r.github.io/docs/prometheusservice/put_rule_groups_namespace.html for full documentation.

Usage

prometheusservice_put_rule_groups_namespace(
  clientToken = NULL,
  data,
  name,
  workspaceId
)

Arguments

clientToken

Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the request.

data

[required] The namespace data that define the rule groups.

name

[required] The rule groups namespace name.

workspaceId

[required] The ID of the workspace in which to update the rule group namespace.