Accepts the resource grouping recommendations suggested by Resilience Hub for your application.
See https://www.paws-r-sdk.com/docs/resiliencehub_accept_resource_grouping_recommendations/ for full documentation.
resiliencehub_accept_resource_grouping_recommendations(appArn, entries)[required] Amazon Resource Name (ARN) of the Resilience Hub application. The format
for this ARN is:
arn:partition:resiliencehub:region:account:app/app-id. For more
information about ARNs, see Amazon Resource Names (ARNs)
in the Amazon Web Services General Reference guide.
[required] List of resource grouping recommendations you want to include in your application.