Adds the resource mapping for the draft application version.
See https://paws-r.github.io/docs/resiliencehub/add_draft_app_version_resource_mappings.html for full documentation.
resiliencehub_add_draft_app_version_resource_mappings(appArn, resourceMappings)[required] The Amazon Resource Name (ARN) of the application. The format for this
ARN is: arn:partition:resiliencehub:region:account:app/app-id.
For more information about ARNs, see Amazon Resource Names (ARNs)
in the AWS General Reference.
[required] Mappings used to map logical resources from the template to physical
resources. You can use the mapping type CFN_STACK if the application
template uses a logical stack name. Or you can map individual resources
by using the mapping type RESOURCE. We recommend using the mapping
type CFN_STACK if the application is backed by a CloudFormation stack.