Learn R Programming

paws.management (version 0.2.0)

resiliencehub_create_app: Creates a Resilience Hub application

Description

Creates a Resilience Hub application. A Resilience Hub application is a collection of Amazon Web Services resources structured to prevent and recover Amazon Web Services application disruptions. To describe a Resilience Hub application, you provide an application name, resources from one or more–up to five–CloudFormation stacks, and an appropriate resiliency policy.

See https://paws-r.github.io/docs/resiliencehub/create_app.html for full documentation.

Usage

resiliencehub_create_app(
  assessmentSchedule = NULL,
  clientToken = NULL,
  description = NULL,
  name,
  policyArn = NULL,
  tags = NULL
)

Arguments

assessmentSchedule

Assessment execution schedule with 'Daily' or 'Disabled' values.

clientToken

Used for an idempotency token. A client token is a unique, case-sensitive string of up to 64 ASCII characters. You should not reuse the same client token for other API requests.

description

The optional description for an app.

name

[required] The name for the application.

policyArn

The Amazon Resource Name (ARN) of the resiliency policy. The format for this ARN is: arn:partition:resiliencehub:region:account:resiliency-policy/policy-id. For more information about ARNs, see Amazon Resource Names (ARNs) in the AWS General Reference.

tags

The tags assigned to the resource. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key/value pair.