Learn R Programming

paws.management (version 0.2.0)

resiliencehub_delete_app: Deletes an AWS Resilience Hub application

Description

Deletes an AWS Resilience Hub application. This is a destructive action that can't be undone.

See https://paws-r.github.io/docs/resiliencehub/delete_app.html for full documentation.

Usage

resiliencehub_delete_app(appArn, clientToken = NULL, forceDelete = NULL)

Arguments

appArn

[required] The Amazon Resource Name (ARN) of the application. The format for this ARN is: arn:partition:resiliencehub:region:account:app/app-id. For more information about ARNs, see Amazon Resource Names (ARNs) in the AWS General Reference.

clientToken

Used for an idempotency token. A client token is a unique, case-sensitive string of up to 64 ASCII characters. You should not reuse the same client token for other API requests.

forceDelete

A boolean option to force the deletion of a Resilience Hub application.