Returns the resolution status for the specified resolution identifier for an application version. If resolutionId is not specified, the current resolution status is returned.
See https://paws-r.github.io/docs/resiliencehub/describe_app_version_resources_resolution_status.html for full documentation.
resiliencehub_describe_app_version_resources_resolution_status(
appArn,
appVersion,
resolutionId = NULL
)[required] The Amazon Resource Name (ARN) of the application. The format for this
ARN is: arn:partition:resiliencehub:region:account:app/app-id.
For more information about ARNs, see Amazon Resource Names (ARNs)
in the AWS General Reference.
[required] The version of the application.
The identifier for a specific resolution.