Learn R Programming

paws.management (version 0.2.0)

resiliencehub_import_resources_to_draft_app_version: Imports resources from sources such as a CloudFormation stack, resource-groups, or application registry app to a draft application version

Description

Imports resources from sources such as a CloudFormation stack, resource-groups, or application registry app to a draft application version.

See https://paws-r.github.io/docs/resiliencehub/import_resources_to_draft_app_version.html for full documentation.

Usage

resiliencehub_import_resources_to_draft_app_version(
  appArn,
  sourceArns = NULL,
  terraformSources = NULL
)

Arguments

appArn

[required] The Amazon Resource Name (ARN) of the application. The format for this ARN is: arn:partition:resiliencehub:region:account:app/app-id. For more information about ARNs, see Amazon Resource Names (ARNs) in the AWS General Reference.

sourceArns

The Amazon Resource Names (ARNs) for the resources that you want to import.

terraformSources

A list of terraform file s3 URLs you need to import.