Learn R Programming

paws.management (version 0.2.0)

resiliencehub_list_alarm_recommendations: Lists the alarm recommendations for a AWS Resilience Hub application

Description

Lists the alarm recommendations for a AWS Resilience Hub application.

See https://paws-r.github.io/docs/resiliencehub/list_alarm_recommendations.html for full documentation.

Usage

resiliencehub_list_alarm_recommendations(
  assessmentArn,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

assessmentArn

[required] The Amazon Resource Name (ARN) of the assessment. The format for this ARN is: arn:partition:resiliencehub:region:account:app-assessment/app-id. For more information about ARNs, see Amazon Resource Names (ARNs) in the AWS General Reference.

maxResults

The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

nextToken

Null, or the token from a previous call to get the next set of results.