Learn R Programming

paws.management (version 0.2.0)

resiliencehub_list_app_version_resources: Lists all the resources in an application version

Description

Lists all the resources in an application version.

See https://paws-r.github.io/docs/resiliencehub/list_app_version_resources.html for full documentation.

Usage

resiliencehub_list_app_version_resources(
  appArn,
  appVersion,
  maxResults = NULL,
  nextToken = NULL,
  resolutionId = NULL
)

Arguments

appArn

[required] The Amazon Resource Name (ARN) of the application. The format for this ARN is: arn:partition:resiliencehub:region:account:app/app-id. For more information about ARNs, see Amazon Resource Names (ARNs) in the AWS General Reference.

appVersion

[required] The version of the application.

maxResults

The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

nextToken

Null, or the token from a previous call to get the next set of results.

resolutionId

The identifier for a specific resolution.