Lists your Resilience Hub applications.
See https://paws-r.github.io/docs/resiliencehub/list_apps.html for full documentation.
resiliencehub_list_apps(
appArn = NULL,
maxResults = NULL,
name = NULL,
nextToken = NULL
)The Amazon Resource Name (ARN) of the application. The format for this
ARN is: arn:partition:resiliencehub:region:account:app/app-id.
For more information about ARNs, see Amazon Resource Names (ARNs)
in the AWS General Reference.
The maximum number of results to include in the response. If more
results exist than the specified MaxResults value, a token is included
in the response so that the remaining results can be retrieved.
The name for the one of the listed applications.
Null, or the token from a previous call to get the next set of results.