Learn R Programming

paws.management (version 0.2.0)

resiliencehub_list_suggested_resiliency_policies: Lists the suggested resiliency policies for the Resilience Hub applications

Description

Lists the suggested resiliency policies for the Resilience Hub applications.

See https://paws-r.github.io/docs/resiliencehub/list_suggested_resiliency_policies.html for full documentation.

Usage

resiliencehub_list_suggested_resiliency_policies(
  maxResults = NULL,
  nextToken = NULL
)

Arguments

maxResults

The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

nextToken

Null, or the token from a previous call to get the next set of results.