Lists the resources that are not currently supported in AWS Resilience Hub. An unsupported resource is a resource that exists in the object that was used to create an app, but is not supported by Resilience Hub.
See https://paws-r.github.io/docs/resiliencehub/list_unsupported_app_version_resources.html for full documentation.
resiliencehub_list_unsupported_app_version_resources(
appArn,
appVersion,
maxResults = NULL,
nextToken = NULL,
resolutionId = NULL
)[required] The Amazon Resource Name (ARN) of the application. The format for this
ARN is: arn:partition:resiliencehub:region:account:app/app-id.
For more information about ARNs, see Amazon Resource Names (ARNs)
in the AWS General Reference.
[required] The version of the application.
The maximum number of results to include in the response. If more
results exist than the specified MaxResults value, a token is included
in the response so that the remaining results can be retrieved.
Null, or the token from a previous call to get the next set of results.
The identifier for a specific resolution.