Creates a new application assessment for an application.
See https://paws-r.github.io/docs/resiliencehub/start_app_assessment.html for full documentation.
resiliencehub_start_app_assessment(
appArn,
appVersion,
assessmentName,
clientToken = NULL,
tags = NULL
)[required] The Amazon Resource Name (ARN) of the application. The format for this
ARN is: arn:partition:resiliencehub:region:account:app/app-id.
For more information about ARNs, see Amazon Resource Names (ARNs)
in the AWS General Reference.
[required] The version of the application.
[required] The name for the assessment.
Used for an idempotency token. A client token is a unique, case-sensitive string of up to 64 ASCII characters. You should not reuse the same client token for other API requests.
The tags assigned to the resource. A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key/value pair.