Updates a resiliency policy.
See https://paws-r.github.io/docs/resiliencehub/update_resiliency_policy.html for full documentation.
resiliencehub_update_resiliency_policy(
dataLocationConstraint = NULL,
policy = NULL,
policyArn,
policyDescription = NULL,
policyName = NULL,
tier = NULL
)Specifies a high-level geographical location constraint for where your resilience policy data can be stored.
The type of resiliency policy to be created, including the recovery time objective (RTO) and recovery point objective (RPO) in seconds.
[required] The Amazon Resource Name (ARN) of the resiliency policy. The format for
this ARN is:
arn:partition:resiliencehub:region:account:resiliency-policy/policy-id.
For more information about ARNs, see Amazon Resource Names (ARNs)
in the AWS General Reference.
The description for the policy.
The name of the policy
The tier for this resiliency policy, ranging from the highest severity
(MissionCritical) to lowest (NonCritical).