Learn R Programming

paws.management (version 0.2.0)

resourcegroups_get_group_configuration: Returns the service configuration associated with the specified resource group

Description

Returns the service configuration associated with the specified resource group. For details about the service configuration syntax, see Service configurations for resource groups.

See https://paws-r.github.io/docs/resourcegroups/get_group_configuration.html for full documentation.

Usage

resourcegroups_get_group_configuration(Group = NULL)

Arguments

Group

The name or the ARN of the resource group.