Retrieves the resource query associated with the specified resource group. For more information about resource queries, see Create a tag-based group in Resource Groups.
See https://paws-r.github.io/docs/resourcegroups/get_group_query.html for full documentation.
resourcegroups_get_group_query(GroupName = NULL, Group = NULL)Don't use this parameter. Use Group instead.
The name or the ARN of the resource group to query.