Learn R Programming

paws.management (version 0.2.0)

resourcegroups_group_resources: Adds the specified resources to the specified group

Description

Adds the specified resources to the specified group.

See https://paws-r.github.io/docs/resourcegroups/group_resources.html for full documentation.

Usage

resourcegroups_group_resources(Group, ResourceArns)

Arguments

Group

[required] The name or the ARN of the resource group to add resources to.

ResourceArns

[required] The list of ARNs for resources to be added to the group.