Adds tags to a resource group with the specified ARN. Existing tags on a resource group are not changed if they are not specified in the request parameters.
See https://paws-r.github.io/docs/resourcegroups/tag.html for full documentation.
resourcegroups_tag(Arn, Tags)[required] The ARN of the resource group to which to add tags.
[required] The tags to add to the specified resource group. A tag is a string-to-string map of key-value pairs.