Learn R Programming

paws.management (version 0.2.0)

resourcegroups_ungroup_resources: Removes the specified resources from the specified group

Description

Removes the specified resources from the specified group.

See https://paws-r.github.io/docs/resourcegroups/ungroup_resources.html for full documentation.

Usage

resourcegroups_ungroup_resources(Group, ResourceArns)

Arguments

Group

[required] The name or the ARN of the resource group from which to remove the resources.

ResourceArns

[required] The ARNs of the resources to be removed from the group.