Learn R Programming

paws.management (version 0.2.0)

servicecatalog_delete_provisioned_product_plan: Deletes the specified plan

Description

Deletes the specified plan.

See https://paws-r.github.io/docs/servicecatalog/delete_provisioned_product_plan.html for full documentation.

Usage

servicecatalog_delete_provisioned_product_plan(
  AcceptLanguage = NULL,
  PlanId,
  IgnoreErrors = NULL
)

Arguments

AcceptLanguage

The language code.

  • en - English (default)

  • jp - Japanese

  • zh - Chinese

PlanId

[required] The plan identifier.

IgnoreErrors

If set to true, AWS Service Catalog stops managing the specified provisioned product even if it cannot delete the underlying resources.