Gets the status of the specified portfolio share operation. This API can only be called by the management account in the organization or by a delegated admin.
See https://paws-r.github.io/docs/servicecatalog/describe_portfolio_share_status.html for full documentation.
servicecatalog_describe_portfolio_share_status(PortfolioShareToken)[required] The token for the portfolio share operation. This token is returned either by CreatePortfolioShare or by DeletePortfolioShare.