Learn R Programming

paws.management (version 0.2.0)

servicecatalog_describe_service_action_execution_parameters: Finds the default parameters for a specific self-service action on a specific provisioned product and returns a map of the results to the user

Description

Finds the default parameters for a specific self-service action on a specific provisioned product and returns a map of the results to the user.

See https://paws-r.github.io/docs/servicecatalog/describe_service_action_execution_parameters.html for full documentation.

Usage

servicecatalog_describe_service_action_execution_parameters(
  ProvisionedProductId,
  ServiceActionId,
  AcceptLanguage = NULL
)

Arguments

ProvisionedProductId

[required] The identifier of the provisioned product.

ServiceActionId

[required] The self-service action identifier.

AcceptLanguage

The language code.

  • en - English (default)

  • jp - Japanese

  • zh - Chinese