Learn R Programming

paws.management (version 0.2.0)

servicecatalog_enable_aws_organizations_access: Enable portfolio sharing feature through AWS Organizations

Description

Enable portfolio sharing feature through AWS Organizations. This API will allow Service Catalog to receive updates on your organization in order to sync your shares with the current structure. This API can only be called by the management account in the organization.

See https://paws-r.github.io/docs/servicecatalog/enable_aws_organizations_access.html for full documentation.

Usage

servicecatalog_enable_aws_organizations_access()

Arguments