Learn R Programming

paws.management (version 0.2.0)

servicecatalog_execute_provisioned_product_plan: Provisions or modifies a product based on the resource changes for the specified plan

Description

Provisions or modifies a product based on the resource changes for the specified plan.

See https://paws-r.github.io/docs/servicecatalog/execute_provisioned_product_plan.html for full documentation.

Usage

servicecatalog_execute_provisioned_product_plan(
  AcceptLanguage = NULL,
  PlanId,
  IdempotencyToken
)

Arguments

AcceptLanguage

The language code.

  • en - English (default)

  • jp - Japanese

  • zh - Chinese

PlanId

[required] The plan identifier.

IdempotencyToken

[required] A unique identifier that you provide to ensure idempotency. If multiple requests differ only by the idempotency token, the same response is returned for each repeated request.