Get the Access Status for AWS Organization portfolio share feature. This API can only be called by the management account in the organization or by a delegated admin.
See https://paws-r.github.io/docs/servicecatalog/get_aws_organizations_access_status.html for full documentation.
servicecatalog_get_aws_organizations_access_status()