Lists all portfolios in the catalog.
See https://paws-r.github.io/docs/servicecatalog/list_portfolios.html for full documentation.
servicecatalog_list_portfolios(
AcceptLanguage = NULL,
PageToken = NULL,
PageSize = NULL
)The language code.
en - English (default)
jp - Japanese
zh - Chinese
The page token for the next set of results. To retrieve the first set of results, use null.
The maximum number of items to return with this call.