Lists all self-service actions.
See https://paws-r.github.io/docs/servicecatalog/list_service_actions.html for full documentation.
servicecatalog_list_service_actions(
AcceptLanguage = NULL,
PageSize = NULL,
PageToken = NULL
)The language code.
en - English (default)
jp - Japanese
zh - Chinese
The maximum number of items to return with this call.
The page token for the next set of results. To retrieve the first set of results, use null.