Learn R Programming

paws.management (version 0.2.0)

servicecatalog_update_portfolio_share: Updates the specified portfolio share

Description

Updates the specified portfolio share. You can use this API to enable or disable TagOptions sharing for an existing portfolio share.

See https://paws-r.github.io/docs/servicecatalog/update_portfolio_share.html for full documentation.

Usage

servicecatalog_update_portfolio_share(
  AcceptLanguage = NULL,
  PortfolioId,
  AccountId = NULL,
  OrganizationNode = NULL,
  ShareTagOptions = NULL
)

Arguments

AcceptLanguage

The language code.

  • en - English (default)

  • jp - Japanese

  • zh - Chinese

PortfolioId

[required] The unique identifier of the portfolio for which the share will be updated.

AccountId

The AWS Account Id of the recipient account. This field is required when updating an external account to account type share.

OrganizationNode

ShareTagOptions

A flag to enable or disable TagOptions sharing for the portfolio share. If this field is not provided, the current state of TagOptions sharing on the portfolio share will not be modified.