Learn R Programming

paws.management (version 0.2.0)

servicequotas_associate_service_quota_template: Associates your quota request template with your organization

Description

Associates your quota request template with your organization. When a new account is created in your organization, the quota increase requests in the template are automatically applied to the account. You can add a quota increase request for any adjustable quota to your template.

See https://paws-r.github.io/docs/servicequotas/associate_service_quota_template.html for full documentation.

Usage

servicequotas_associate_service_quota_template()

Arguments