Retrieves the applied quota value for the specified quota. For some quotas, only the default values are available. If the applied quota value is not available for a quota, the quota is not retrieved.
See https://paws-r.github.io/docs/servicequotas/get_service_quota.html for full documentation.
servicequotas_get_service_quota(ServiceCode, QuotaCode)[required] The service identifier.
[required] The quota identifier.