Lists the default values for the quotas for the specified AWS service. A default value does not reflect any quota increases.
See https://paws-r.github.io/docs/servicequotas/list_aws_default_service_quotas.html for full documentation.
servicequotas_list_aws_default_service_quotas(
ServiceCode,
NextToken = NULL,
MaxResults = NULL
)[required] The service identifier.
The token for the next page of results.
The maximum number of results to return with a single call. To retrieve the remaining results, if any, make another call with the token returned from this call.