Lists the applied quota values for the specified AWS service. For some quotas, only the default values are available. If the applied quota value is not available for a quota, the quota is not retrieved.
See https://paws-r.github.io/docs/servicequotas/list_service_quotas.html for full documentation.
servicequotas_list_service_quotas(
ServiceCode,
NextToken = NULL,
MaxResults = NULL
)[required] The service identifier.
The token for the next page of results.
The maximum number of results to return with a single call. To retrieve the remaining results, if any, make another call with the token returned from this call.