Lists the names and codes for the services integrated with Service Quotas.
See https://paws-r.github.io/docs/servicequotas/list_services.html for full documentation.
servicequotas_list_services(NextToken = NULL, MaxResults = NULL)The token for the next page of results.
The maximum number of results to return with a single call. To retrieve the remaining results, if any, make another call with the token returned from this call.