Attempts to cancel the command specified by the Command ID. There is no guarantee that the command will be terminated and the underlying process stopped.
See https://paws-r.github.io/docs/ssm/cancel_command.html for full documentation.
ssm_cancel_command(CommandId, InstanceIds = NULL)[required] The ID of the command you want to cancel.
(Optional) A list of managed node IDs on which you want to cancel the command. If not provided, the command is canceled on every node on which it was requested.