Stops a maintenance window execution that is already in progress and cancels any tasks in the window that haven't already starting running. Tasks already in progress will continue to completion.
See https://paws-r.github.io/docs/ssm/cancel_maintenance_window_execution.html for full documentation.
ssm_cancel_maintenance_window_execution(WindowExecutionId)[required] The ID of the maintenance window execution to stop.