ssm_deregister_managed_instance: Removes the server or virtual machine from the list of registered
servers
Description
Removes the server or virtual machine from the list of registered
servers. You can reregister the instance again at any time. If you don't
plan to use Run Command on the server, we suggest uninstalling SSM Agent
first.
Usage
ssm_deregister_managed_instance(InstanceId)
Arguments
InstanceId
[required] The ID assigned to the managed instance when you registered it using the
activation process.
Request syntax
svc$deregister_managed_instance(
InstanceId = "string"
)