Learn R Programming

paws.management (version 0.2.0)

ssm_deregister_patch_baseline_for_patch_group: Removes a patch group from a patch baseline

Description

Removes a patch group from a patch baseline.

See https://paws-r.github.io/docs/ssm/deregister_patch_baseline_for_patch_group.html for full documentation.

Usage

ssm_deregister_patch_baseline_for_patch_group(BaselineId, PatchGroup)

Arguments

BaselineId

[required] The ID of the patch baseline to deregister the patch group from.

PatchGroup

[required] The name of the patch group that should be deregistered from the patch baseline.