Removes a target from a maintenance window.
See https://paws-r.github.io/docs/ssm/deregister_target_from_maintenance_window.html for full documentation.
ssm_deregister_target_from_maintenance_window(
WindowId,
WindowTargetId,
Safe = NULL
)[required] The ID of the maintenance window the target should be removed from.
[required] The ID of the target definition to remove.
The system checks if the target is being referenced by a task. If the target is being referenced, the system returns an error and doesn't deregister the target from the maintenance window.