Learn R Programming

paws.management (version 0.2.0)

ssm_deregister_task_from_maintenance_window: Removes a task from a maintenance window

Description

Removes a task from a maintenance window.

See https://paws-r.github.io/docs/ssm/deregister_task_from_maintenance_window.html for full documentation.

Usage

ssm_deregister_task_from_maintenance_window(WindowId, WindowTaskId)

Arguments

WindowId

[required] The ID of the maintenance window the task should be removed from.

WindowTaskId

[required] The ID of the task to remove from the maintenance window.