Learn R Programming

paws.management (version 0.2.0)

ssm_describe_automation_executions: Provides details about all active and terminated Automation executions

Description

Provides details about all active and terminated Automation executions.

See https://paws-r.github.io/docs/ssm/describe_automation_executions.html for full documentation.

Usage

ssm_describe_automation_executions(
  Filters = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

Filters

Filters used to limit the scope of executions that are requested.

MaxResults

The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.

NextToken

The token for the next set of items to return. (You received this token from a previous call.)