Describes the permissions for a Systems Manager document. If you created the document, you are the owner. If a document is shared, it can either be shared privately (by specifying a user's AWS account ID) or publicly (All).
ssm_describe_document_permission(Name, PermissionType)[required] The name of the document for which you are the owner.
[required] The permission type for the document. The permission type can be Share.
A list with the following syntax:
list(
AccountIds = list(
"string"
),
AccountSharingInfoList = list(
list(
AccountId = "string",
SharedDocumentVersion = "string"
)
)
)
svc$describe_document_permission( Name = "string", PermissionType = "Share" )