All associations for the instance(s).
ssm_describe_effective_instance_associations(InstanceId, MaxResults,
NextToken)[required] The instance ID for which you want to view all associations.
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
The token for the next set of items to return. (You received this token from a previous call.)
A list with the following syntax:
list(
Associations = list(
list(
AssociationId = "string",
InstanceId = "string",
Content = "string",
AssociationVersion = "string"
)
),
NextToken = "string"
)
svc$describe_effective_instance_associations( InstanceId = "string", MaxResults = 123, NextToken = "string" )