Learn R Programming

paws.management (version 0.2.0)

ssm_describe_instance_patch_states: Retrieves the high-level patch state of one or more managed nodes

Description

Retrieves the high-level patch state of one or more managed nodes.

See https://paws-r.github.io/docs/ssm/describe_instance_patch_states.html for full documentation.

Usage

ssm_describe_instance_patch_states(
  InstanceIds,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

InstanceIds

[required] The ID of the managed node for which patch state information should be retrieved.

NextToken

The token for the next set of items to return. (You received this token from a previous call.)

MaxResults

The maximum number of managed nodes to return (per page).