Learn R Programming

paws.management (version 0.2.0)

ssm_describe_inventory_deletions: Describes a specific delete inventory operation

Description

Describes a specific delete inventory operation.

See https://paws-r.github.io/docs/ssm/describe_inventory_deletions.html for full documentation.

Usage

ssm_describe_inventory_deletions(
  DeletionId = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

DeletionId

Specify the delete inventory ID for which you want information. This ID was returned by the delete_inventory operation.

NextToken

A token to start the list. Use this token to get the next set of results.

MaxResults

The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.