Retrieves the maintenance windows in an Amazon Web Services account.
See https://paws-r.github.io/docs/ssm/describe_maintenance_windows.html for full documentation.
ssm_describe_maintenance_windows(
Filters = NULL,
MaxResults = NULL,
NextToken = NULL
)Optional filters used to narrow down the scope of the returned
maintenance windows. Supported filter keys are Name and Enabled. For
example, Name=MyMaintenanceWindow and Enabled=True.
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
The token for the next set of items to return. (You received this token from a previous call.)