Retrieves information about the maintenance window targets or tasks that a managed node is associated with.
See https://paws-r.github.io/docs/ssm/describe_maintenance_windows_for_target.html for full documentation.
ssm_describe_maintenance_windows_for_target(
Targets,
ResourceType,
MaxResults = NULL,
NextToken = NULL
)[required] The managed node ID or key-value pair to retrieve information about.
[required] The type of resource you want to retrieve information about. For
example, INSTANCE.
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results.
The token for the next set of items to return. (You received this token from a previous call.)