Learn R Programming

paws.management (version 0.2.0)

ssm_describe_patch_baselines: Lists the patch baselines in your Amazon Web Services account

Description

Lists the patch baselines in your Amazon Web Services account.

See https://paws-r.github.io/docs/ssm/describe_patch_baselines.html for full documentation.

Usage

ssm_describe_patch_baselines(
  Filters = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

Filters

Each element in the array is a structure containing a key-value pair.

Supported keys for describe_patch_baselines include the following:

  • NAME_PREFIX

    Sample values: AWS- | My-

  • OWNER

    Sample values: AWS | Self

  • OPERATING_SYSTEM

    Sample values: AMAZON_LINUX | SUSE | WINDOWS

MaxResults

The maximum number of patch baselines to return (per page).

NextToken

The token for the next set of items to return. (You received this token from a previous call.)