Learn R Programming

paws.management (version 0.2.0)

ssm_describe_patch_group_state: Returns high-level aggregated patch compliance state information for a patch group

Description

Returns high-level aggregated patch compliance state information for a patch group.

See https://paws-r.github.io/docs/ssm/describe_patch_group_state.html for full documentation.

Usage

ssm_describe_patch_group_state(PatchGroup)

Arguments

PatchGroup

[required] The name of the patch group whose patch snapshot should be retrieved.