Deletes the association between an OpsItem and a related item. For example, this API operation can delete an Incident Manager incident from an OpsItem. Incident Manager is a capability of Amazon Web Services Systems Manager.
See https://paws-r.github.io/docs/ssm/disassociate_ops_item_related_item.html for full documentation.
ssm_disassociate_ops_item_related_item(OpsItemId, AssociationId)[required] The ID of the OpsItem for which you want to delete an association between the OpsItem and a related item.
[required] The ID of the association for which you want to delete an association between the OpsItem and a related item.