Learn R Programming

paws.management (version 0.2.0)

ssm_get_automation_execution: Get detailed information about a particular Automation execution

Description

Get detailed information about a particular Automation execution.

See https://paws-r.github.io/docs/ssm/get_automation_execution.html for full documentation.

Usage

ssm_get_automation_execution(AutomationExecutionId)

Arguments

AutomationExecutionId

[required] The unique identifier for an existing automation execution to examine. The execution ID is returned by StartAutomationExecution when the execution of an Automation runbook is initiated.