ssm_get_deployable_patch_snapshot_for_instance: Retrieves the current snapshot for the patch baseline the...

View source: R/ssm_operations.R

ssm_get_deployable_patch_snapshot_for_instanceR Documentation

Retrieves the current snapshot for the patch baseline the managed node uses

Description

Retrieves the current snapshot for the patch baseline the managed node uses. This API is primarily used by the AWS-RunPatchBaseline Systems Manager document (SSM document).

See https://www.paws-r-sdk.com/docs/ssm_get_deployable_patch_snapshot_for_instance/ for full documentation.

Usage

ssm_get_deployable_patch_snapshot_for_instance(
  InstanceId,
  SnapshotId,
  BaselineOverride = NULL,
  UseS3DualStackEndpoint = NULL
)

Arguments

InstanceId

[required] The ID of the managed node for which the appropriate patch snapshot should be retrieved.

SnapshotId

[required] The snapshot ID provided by the user when running AWS-RunPatchBaseline.

BaselineOverride

Defines the basic information about a patch baseline override.

UseS3DualStackEndpoint

Specifies whether to use S3 dualstack endpoints for the patch snapshot download URL. Set to true to receive a presigned URL that supports both IPv4 and IPv6 connectivity. Set to false to use standard IPv4-only endpoints. Default is false. This parameter is required for managed nodes in IPv6-only environments.


paws.management documentation built on Oct. 8, 2026, 1:25 a.m.