Learn R Programming

paws.management (version 0.2.0)

ssm_get_maintenance_window_execution: Retrieves details about a specific a maintenance window execution

Description

Retrieves details about a specific a maintenance window execution.

See https://paws-r.github.io/docs/ssm/get_maintenance_window_execution.html for full documentation.

Usage

ssm_get_maintenance_window_execution(WindowExecutionId)

Arguments

WindowExecutionId

[required] The ID of the maintenance window execution that includes the task.