Retrieves information about a specific task running on a specific target.
See https://paws-r.github.io/docs/ssm/get_maintenance_window_execution_task_invocation.html for full documentation.
ssm_get_maintenance_window_execution_task_invocation(
WindowExecutionId,
TaskId,
InvocationId
)[required] The ID of the maintenance window execution for which the task is a part.
[required] The ID of the specific task in the maintenance window task that should be retrieved.
[required] The invocation ID to retrieve.