Learn R Programming

paws.management (version 0.2.0)

ssm_get_parameters: Get information about one or more parameters by specifying multiple parameter names

Description

Get information about one or more parameters by specifying multiple parameter names.

See https://paws-r.github.io/docs/ssm/get_parameters.html for full documentation.

Usage

ssm_get_parameters(Names, WithDecryption = NULL)

Arguments

Names

[required] Names of the parameters for which you want to query information.

To query by parameter label, use "Name": "name:label". To query by parameter version, use "Name": "name:version".

WithDecryption

Return decrypted secure string value. Return decrypted values for secure string parameters. This flag is ignored for String and StringList parameter types.