Learn R Programming

paws.management (version 0.2.0)

ssm_get_patch_baseline_for_patch_group: Retrieves the patch baseline that should be used for the specified patch group

Description

Retrieves the patch baseline that should be used for the specified patch group.

See https://paws-r.github.io/docs/ssm/get_patch_baseline_for_patch_group.html for full documentation.

Usage

ssm_get_patch_baseline_for_patch_group(PatchGroup, OperatingSystem = NULL)

Arguments

PatchGroup

[required] The name of the patch group whose patch baseline should be retrieved.

OperatingSystem

Returns the operating system rule specified for patch groups using the patch baseline.