ServiceSetting is an account-level setting for an AWS service. This
setting defines how a user interacts with or uses a service or a feature
of a service. For example, if an AWS service charges money to the
account based on feature or service usage, then the AWS service team
might create a default setting of "false". This means the user can't use
this feature unless they change the setting to "true" and intentionally
opt in for a paid feature.
Services map a SettingId object to a setting value. AWS services teams
define the default value for a SettingId. You can't create a new
SettingId, but you can overwrite the default value if you have the
ssm:UpdateServiceSetting permission for the setting. Use the
update_service_setting API action to
change the default setting. Or use the
reset_service_setting to change the value
back to the original value defined by the AWS service team.
Query the current service setting for the account.
ssm_get_service_setting(SettingId)[required] The ID of the service setting to get. The setting ID can be
/ssm/parameter-store/default-parameter-tier,
/ssm/parameter-store/high-throughput-enabled, or
/ssm/managed-instance/activation-tier.
A list with the following syntax:
list(
ServiceSetting = list(
SettingId = "string",
SettingValue = "string",
LastModifiedDate = as.POSIXct(
"2015-01-01"
),
LastModifiedUser = "string",
ARN = "string",
Status = "string"
)
)
svc$get_service_setting( SettingId = "string" )