ssm_list_tags_for_resource: Returns a list of the tags assigned to the specified resource
Usage
ssm_list_tags_for_resource(ResourceType, ResourceId)
Arguments
- ResourceType
[required] Returns a list of tags for a specific resource type.
- ResourceId
[required] The resource ID for which you want to see a list of tags.