Learn R Programming

paws.management (version 0.2.0)

ssm_register_default_patch_baseline: Defines the default patch baseline for the relevant operating system

Description

Defines the default patch baseline for the relevant operating system.

See https://paws-r.github.io/docs/ssm/register_default_patch_baseline.html for full documentation.

Usage

ssm_register_default_patch_baseline(BaselineId)

Arguments

BaselineId

[required] The ID of the patch baseline that should be the default patch baseline.