Learn R Programming

paws.management (version 0.2.0)

ssm_register_patch_baseline_for_patch_group: Registers a patch baseline for a patch group

Description

Registers a patch baseline for a patch group.

See https://paws-r.github.io/docs/ssm/register_patch_baseline_for_patch_group.html for full documentation.

Usage

ssm_register_patch_baseline_for_patch_group(BaselineId, PatchGroup)

Arguments

BaselineId

[required] The ID of the patch baseline to register with the patch group.

PatchGroup

[required] The name of the patch group to be registered with the patch baseline.