Adds a new task to a maintenance window.
ssm_register_task_with_maintenance_window(WindowId, Targets, TaskArn,
ServiceRoleArn, TaskType, TaskParameters, TaskInvocationParameters,
Priority, MaxConcurrency, MaxErrors, LoggingInfo, Name, Description,
ClientToken)[required] The ID of the maintenance window the task should be added to.
The targets (either instances or maintenance window targets).
One or more targets must be specified for maintenance window Run Command-type tasks. Depending on the task, targets are optional for other maintenance window task types (Automation, AWS Lambda, and AWS Step Functions). For more information about running tasks that do not specify targets, see see Registering maintenance window tasks without targets in the AWS Systems Manager User Guide.
Specify instances using the following format:
Key=InstanceIds,Values=<instance-id-1>,<instance-id-2>
Specify maintenance window targets using the following format:
Key=WindowTargetIds,Values=<window-target-id-1>,<window-target-id-2>
[required] The ARN of the task to run.
The ARN of the IAM service role for Systems Manager to assume when
running a maintenance window task. If you do not specify a service role
ARN, Systems Manager uses your account's service-linked role. If no
service-linked role for Systems Manager exists in your account, it is
created when you run
register_task_with_maintenance_window.
For more information, see the following topics in the in the AWS Systems Manager User Guide:
[required] The type of task being registered.
The parameters that should be passed to the task when it is run.
TaskParameters has been deprecated. To specify parameters to pass to a
task when it runs, instead use the Parameters option in the
TaskInvocationParameters structure. For information about how Systems
Manager handles these options for the supported maintenance window task
types, see MaintenanceWindowTaskInvocationParameters.
The parameters that the task should use during execution. Populate only the fields that match the task type. All other fields should be empty.
The priority of the task in the maintenance window, the lower the number the higher the priority. Tasks in a maintenance window are scheduled in priority order with tasks that have the same priority scheduled in parallel.
The maximum number of targets this task can be run for in parallel.
For maintenance window tasks without a target specified, you cannot
supply a value for this option. Instead, the system inserts a
placeholder value of 1. This value does not affect the running of your
task.
The maximum number of errors allowed before this task stops being scheduled.
For maintenance window tasks without a target specified, you cannot
supply a value for this option. Instead, the system inserts a
placeholder value of 1. This value does not affect the running of your
task.
A structure containing information about an S3 bucket to write instance-level logs to.
LoggingInfo has been deprecated. To specify an S3 bucket to contain
logs, instead use the OutputS3BucketName and OutputS3KeyPrefix
options in the TaskInvocationParameters structure. For information
about how Systems Manager handles these options for the supported
maintenance window task types, see
MaintenanceWindowTaskInvocationParameters.
An optional name for the task.
An optional description for the task.
User-provided idempotency token.
A list with the following syntax:
list( WindowTaskId = "string" )
svc$register_task_with_maintenance_window(
WindowId = "string",
Targets = list(
list(
Key = "string",
Values = list(
"string"
)
)
),
TaskArn = "string",
ServiceRoleArn = "string",
TaskType = "RUN_COMMAND"|"AUTOMATION"|"STEP_FUNCTIONS"|"LAMBDA",
TaskParameters = list(
list(
Values = list(
"string"
)
)
),
TaskInvocationParameters = list(
RunCommand = list(
Comment = "string",
CloudWatchOutputConfig = list(
CloudWatchLogGroupName = "string",
CloudWatchOutputEnabled = TRUE|FALSE
),
DocumentHash = "string",
DocumentHashType = "Sha256"|"Sha1",
DocumentVersion = "string",
NotificationConfig = list(
NotificationArn = "string",
NotificationEvents = list(
"All"|"InProgress"|"Success"|"TimedOut"|"Cancelled"|"Failed"
),
NotificationType = "Command"|"Invocation"
),
OutputS3BucketName = "string",
OutputS3KeyPrefix = "string",
Parameters = list(
list(
"string"
)
),
ServiceRoleArn = "string",
TimeoutSeconds = 123
),
Automation = list(
DocumentVersion = "string",
Parameters = list(
list(
"string"
)
)
),
StepFunctions = list(
Input = "string",
Name = "string"
),
Lambda = list(
ClientContext = "string",
Qualifier = "string",
Payload = raw
)
),
Priority = 123,
MaxConcurrency = "string",
MaxErrors = "string",
LoggingInfo = list(
S3BucketName = "string",
S3KeyPrefix = "string",
S3Region = "string"
),
Name = "string",
Description = "string",
ClientToken = "string"
)