Learn R Programming

paws.management (version 0.2.0)

ssm_resume_session: Reconnects a session to a managed node after it has been disconnected

Description

Reconnects a session to a managed node after it has been disconnected. Connections can be resumed for disconnected sessions, but not terminated sessions.

See https://paws-r.github.io/docs/ssm/resume_session.html for full documentation.

Usage

ssm_resume_session(SessionId)

Arguments

SessionId

[required] The ID of the disconnected session to resume.