Learn R Programming

paws.management (version 0.2.0)

ssm_terminate_session: Permanently ends a session and closes the data connection between the Session Manager client and SSM Agent on the managed node

Description

Permanently ends a session and closes the data connection between the Session Manager client and SSM Agent on the managed node. A terminated session can't be resumed.

See https://paws-r.github.io/docs/ssm/terminate_session.html for full documentation.

Usage

ssm_terminate_session(SessionId)

Arguments

SessionId

[required] The ID of the session to terminate.