Learn R Programming

paws.management (version 0.2.0)

ssm_update_document_default_version: Set the default version of a document

Description

Set the default version of a document.

See https://paws-r.github.io/docs/ssm/update_document_default_version.html for full documentation.

Usage

ssm_update_document_default_version(Name, DocumentVersion)

Arguments

Name

[required] The name of a custom document that you want to set as the default version.

DocumentVersion

[required] The version of a custom document that you want to set as the default version.