Learn R Programming

paws.management (version 0.2.0)

ssm_update_document_metadata: Updates information related to approval reviews for a specific version of a change template in Change Manager

Description

Updates information related to approval reviews for a specific version of a change template in Change Manager.

See https://paws-r.github.io/docs/ssm/update_document_metadata.html for full documentation.

Usage

ssm_update_document_metadata(Name, DocumentVersion = NULL, DocumentReviews)

Arguments

Name

[required] The name of the change template for which a version's metadata is to be updated.

DocumentVersion

The version of a change template in which to update approval metadata.

DocumentReviews

[required] The change template review details to update.