Learn R Programming

paws.management (version 0.2.0)

ssm_update_managed_instance_role: Changes the Identity and Access Management (IAM) role that is assigned to the on-premises server, edge device, or virtual machines (VM)

Description

Changes the Identity and Access Management (IAM) role that is assigned to the on-premises server, edge device, or virtual machines (VM). IAM roles are first assigned to these hybrid nodes during the activation process. For more information, see create_activation.

See https://paws-r.github.io/docs/ssm/update_managed_instance_role.html for full documentation.

Usage

ssm_update_managed_instance_role(InstanceId, IamRole)

Arguments

InstanceId

[required] The ID of the managed node where you want to update the role.

IamRole

[required] The IAM role you want to assign or change.