Learn R Programming

paws.management (version 0.2.0)

ssmcontacts_deactivate_contact_channel: To no longer receive Incident Manager engagements to a contact channel, you can deactivate the channel

Description

To no longer receive Incident Manager engagements to a contact channel, you can deactivate the channel.

See https://paws-r.github.io/docs/ssmcontacts/deactivate_contact_channel.html for full documentation.

Usage

ssmcontacts_deactivate_contact_channel(ContactChannelId)

Arguments

ContactChannelId

[required] The Amazon Resource Name (ARN) of the contact channel you're deactivating.