Learn R Programming

paws.management (version 0.2.0)

ssmcontacts_describe_page: Lists details of the engagement to a contact channel

Description

Lists details of the engagement to a contact channel.

See https://paws-r.github.io/docs/ssmcontacts/describe_page.html for full documentation.

Usage

ssmcontacts_describe_page(PageId)

Arguments

PageId

[required] The ID of the engagement to a contact channel.