Learn R Programming

paws.management (version 0.2.0)

ssmcontacts_get_contact: Retrieves information about the specified contact or escalation plan

Description

Retrieves information about the specified contact or escalation plan.

See https://paws-r.github.io/docs/ssmcontacts/get_contact.html for full documentation.

Usage

ssmcontacts_get_contact(ContactId)

Arguments

ContactId

[required] The Amazon Resource Name (ARN) of the contact or escalation plan.