Learn R Programming

paws.management (version 0.2.0)

ssmcontacts_get_contact_policy: Retrieves the resource policies attached to the specified contact or escalation plan

Description

Retrieves the resource policies attached to the specified contact or escalation plan.

See https://paws-r.github.io/docs/ssmcontacts/get_contact_policy.html for full documentation.

Usage

ssmcontacts_get_contact_policy(ContactArn)

Arguments

ContactArn

[required] The Amazon Resource Name (ARN) of the contact or escalation plan.