Learn R Programming

paws.management (version 0.2.0)

ssmcontacts_list_page_receipts: Lists all of the engagements to contact channels that have been acknowledged

Description

Lists all of the engagements to contact channels that have been acknowledged.

See https://paws-r.github.io/docs/ssmcontacts/list_page_receipts.html for full documentation.

Usage

ssmcontacts_list_page_receipts(PageId, NextToken = NULL, MaxResults = NULL)

Arguments

PageId

[required] The Amazon Resource Name (ARN) of the engagement to a specific contact channel.

NextToken

The pagination token to continue to the next page of results.

MaxResults

The maximum number of acknowledgements per page of results.