Learn R Programming

paws.management (version 0.2.0)

ssmcontacts_send_activation_code: Sends an activation code to a contact channel

Description

Sends an activation code to a contact channel. The contact can use this code to activate the contact channel in the console or with the ActivateChannel operation. Incident Manager can't engage a contact channel until it has been activated.

See https://paws-r.github.io/docs/ssmcontacts/send_activation_code.html for full documentation.

Usage

ssmcontacts_send_activation_code(ContactChannelId)

Arguments

ContactChannelId

[required] The Amazon Resource Name (ARN) of the contact channel.