Starts an engagement to a contact or escalation plan. The engagement engages each contact specified in the incident.
See https://www.paws-r-sdk.com/docs/ssmcontacts_start_engagement/ for full documentation.
ssmcontacts_start_engagement(
ContactId,
Sender,
Subject,
Content,
PublicSubject = NULL,
PublicContent = NULL,
IncidentId = NULL,
IdempotencyToken = NULL
)[required] The Amazon Resource Name (ARN) of the contact being engaged.
[required] The user that started the engagement.
[required] The secure subject of the message that was sent to the contact. Use this
field for engagements to VOICE or EMAIL.
[required] The secure content of the message that was sent to the contact. Use this
field for engagements to VOICE or EMAIL.
The insecure subject of the message that was sent to the contact. Use
this field for engagements to SMS.
The insecure content of the message that was sent to the contact. Use
this field for engagements to SMS.
The ARN of the incident that the engagement is part of.
A token ensuring that the operation is called only once with the specified details.