Learn R Programming

paws.management (version 0.2.0)

ssmincidents_create_replication_set: A replication set replicates and encrypts your data to the provided Regions with the provided KMS key

Description

A replication set replicates and encrypts your data to the provided Regions with the provided KMS key.

See https://paws-r.github.io/docs/ssmincidents/create_replication_set.html for full documentation.

Usage

ssmincidents_create_replication_set(clientToken = NULL, regions)

Arguments

clientToken

A token ensuring that the operation is called only once with the specified details.

regions

[required] The Regions that Incident Manager replicates your data to. You can have up to three Regions in your replication set.