Learn R Programming

paws.management (version 0.2.0)

ssmincidents_create_timeline_event: Creates a custom timeline event on the incident details page of an incident record

Description

Creates a custom timeline event on the incident details page of an incident record. Timeline events are automatically created by Incident Manager, marking key moment during an incident. You can create custom timeline events to mark important events that are automatically detected by Incident Manager.

See https://paws-r.github.io/docs/ssmincidents/create_timeline_event.html for full documentation.

Usage

ssmincidents_create_timeline_event(
  clientToken = NULL,
  eventData,
  eventTime,
  eventType,
  incidentRecordArn
)

Arguments

clientToken

A token ensuring that the action is called only once with the specified details.

eventData

[required] A short description of the event.

eventTime

[required] The time that the event occurred.

eventType

[required] The type of the event. You can create timeline events of type Custom Event.

incidentRecordArn

[required] The Amazon Resource Name (ARN) of the incident record to which the event will be added.