Learn R Programming

paws.management (version 0.2.0)

ssmincidents_get_resource_policies: Retrieves the resource policies attached to the specified response plan

Description

Retrieves the resource policies attached to the specified response plan.

See https://paws-r.github.io/docs/ssmincidents/get_resource_policies.html for full documentation.

Usage

ssmincidents_get_resource_policies(
  maxResults = NULL,
  nextToken = NULL,
  resourceArn
)

Arguments

maxResults

The maximum number of resource policies to display per page of results.

nextToken

The pagination token to continue to the next page of results.

resourceArn

[required] The Amazon Resource Name (ARN) of the response plan with the attached resource policy.