Learn R Programming

paws.management (version 0.2.0)

ssmincidents_list_incident_records: Lists all incident records in your account

Description

Lists all incident records in your account. Use this command to retrieve the Amazon Resource Name (ARN) of the incident record you want to update.

See https://paws-r.github.io/docs/ssmincidents/list_incident_records.html for full documentation.

Usage

ssmincidents_list_incident_records(
  filters = NULL,
  maxResults = NULL,
  nextToken = NULL
)

Arguments

filters

Filters the list of incident records through which you are searching. You can filter on the following keys:

  • creationTime

  • impact

  • status

  • createdBy

Note the following when deciding how to use Filters:

  • If you don't specify a Filter, the response includes all incident records.

  • If you specify more than one filter in a single request, the response returns incident records that match all filters.

  • If you specify a filter with more than one value, the response returns incident records that match any of the values provided.

maxResults

The maximum number of results per page.

nextToken

The pagination token to continue to the next page of results.