Learn R Programming

paws.management (version 0.2.0)

ssmincidents_list_replication_sets: Lists details about the replication set configured in your account

Description

Lists details about the replication set configured in your account.

See https://paws-r.github.io/docs/ssmincidents/list_replication_sets.html for full documentation.

Usage

ssmincidents_list_replication_sets(maxResults = NULL, nextToken = NULL)

Arguments

maxResults

The maximum number of results per page.

nextToken

The pagination token to continue to the next page of results.