Used to start an incident from CloudWatch alarms, EventBridge events, or manually.
See https://www.paws-r-sdk.com/docs/ssmincidents_start_incident/ for full documentation.
ssmincidents_start_incident(
clientToken = NULL,
impact = NULL,
relatedItems = NULL,
responsePlanArn,
title = NULL,
triggerDetails = NULL
)A token ensuring that the operation is called only once with the specified details.
Defines the impact to the customers. Providing an impact overwrites the impact provided by a response plan.
Supported impact codes
1 - Critical
2 - High
3 - Medium
4 - Low
5 - No Impact
Add related items to the incident for other responders to use. Related items are Amazon Web Services resources, external links, or files uploaded to an Amazon S3 bucket.
[required] The Amazon Resource Name (ARN) of the response plan that pre-defines summary, chat channels, Amazon SNS topics, runbooks, title, and impact of the incident.
Provide a title for the incident. Providing a title overwrites the title provided by the response plan.
Details of what created the incident record in Incident Manager.