Learn R Programming

paws.management (version 0.2.0)

ssmincidents_update_deletion_protection: Update deletion protection to either allow or deny deletion of the final Region in a replication set

Description

Update deletion protection to either allow or deny deletion of the final Region in a replication set.

See https://paws-r.github.io/docs/ssmincidents/update_deletion_protection.html for full documentation.

Usage

ssmincidents_update_deletion_protection(
  arn,
  clientToken = NULL,
  deletionProtected
)

Arguments

arn

[required] The Amazon Resource Name (ARN) of the replication set you're updating.

clientToken

A token ensuring that the operation is called only once with the specified details.

deletionProtected

[required] Details if deletion protection is enabled or disabled in your account.