Learn R Programming

paws.management (version 0.2.0)

ssmincidents_update_incident_record: Update the details of an incident record

Description

Update the details of an incident record. You can use this operation to update an incident record from the defined chat channel. For more information about using actions in chat channels, see Interacting through chat.

See https://paws-r.github.io/docs/ssmincidents/update_incident_record.html for full documentation.

Usage

ssmincidents_update_incident_record(
  arn,
  chatChannel = NULL,
  clientToken = NULL,
  impact = NULL,
  notificationTargets = NULL,
  status = NULL,
  summary = NULL,
  title = NULL
)

Arguments

arn

[required] The Amazon Resource Name (ARN) of the incident record you are updating.

chatChannel

The Chatbot chat channel where responders can collaborate.

clientToken

A token that ensures that the operation is called only once with the specified details.

impact

Defines the impact of the incident to customers and applications. Providing an impact overwrites the impact provided by the response plan.

Possible impacts:

  • 1 - Critical impact, full application failure that impacts many to all customers.

  • 2 - High impact, partial application failure with impact to many customers.

  • 3 - Medium impact, the application is providing reduced service to customers.

  • 4 - Low impact, customer aren't impacted by the problem yet.

  • 5 - No impact, customers aren't currently impacted but urgent action is needed to avoid impact.

notificationTargets

The Amazon SNS targets that are notified when updates are made to an incident.

Using multiple SNS topics creates redundancy in the event that a Region is down during the incident.

status

The status of the incident. An incident can be Open or Resolved.

summary

A longer description of what occurred during the incident.

title

A brief description of the incident.