Learn R Programming

paws.management (version 0.2.0)

ssmincidents_update_related_items: Add or remove related items from the related items tab of an incident record

Description

Add or remove related items from the related items tab of an incident record.

See https://paws-r.github.io/docs/ssmincidents/update_related_items.html for full documentation.

Usage

ssmincidents_update_related_items(
  clientToken = NULL,
  incidentRecordArn,
  relatedItemsUpdate
)

Arguments

clientToken

A token ensuring that the operation is called only once with the specified details.

incidentRecordArn

[required] The Amazon Resource Name (ARN) of the incident record containing the related items you are updating.

relatedItemsUpdate

[required] Details about the item you are adding or deleting.