Learn R Programming

paws.management (version 0.2.0)

ssmincidents_update_response_plan: Updates the specified response plan

Description

Updates the specified response plan.

See https://paws-r.github.io/docs/ssmincidents/update_response_plan.html for full documentation.

Usage

ssmincidents_update_response_plan(
  actions = NULL,
  arn,
  chatChannel = NULL,
  clientToken = NULL,
  displayName = NULL,
  engagements = NULL,
  incidentTemplateDedupeString = NULL,
  incidentTemplateImpact = NULL,
  incidentTemplateNotificationTargets = NULL,
  incidentTemplateSummary = NULL,
  incidentTemplateTags = NULL,
  incidentTemplateTitle = NULL
)

Arguments

actions

The actions that this response plan takes at the beginning of an incident.

arn

[required] The Amazon Resource Name (ARN) of the response plan.

chatChannel

The Chatbot chat channel used for collaboration during an incident.

Use the empty structure to remove the chat channel from the response plan.

clientToken

A token ensuring that the operation is called only once with the specified details.

displayName

The long format name of the response plan. The display name can't contain spaces.

engagements

The contacts and escalation plans that Incident Manager engages at the start of the incident.

incidentTemplateDedupeString

The string Incident Manager uses to prevent duplicate incidents from being created by the same incident in the same account.

incidentTemplateImpact

Defines the impact to the customers. Providing an impact overwrites the impact provided by a response plan.

Possible impacts:

  • 5 - Severe impact

  • 4 - High impact

  • 3 - Medium impact

  • 2 - Low impact

  • 1 - No impact

incidentTemplateNotificationTargets

The Amazon SNS targets that are notified when updates are made to an incident.

incidentTemplateSummary

A brief summary of the incident. This typically contains what has happened, what's currently happening, and next steps.

incidentTemplateTags

Tags to apply to an incident when calling the start_incident API action. To call this action, you must also have permission to call the tag_resource API action for the incident record resource.

incidentTemplateTitle

The short format name of the incident. The title can't contain spaces.