Lists all the applications registered with AWS Systems Manager for SAP.
See https://www.paws-r-sdk.com/docs/ssmsap_list_applications/ for full documentation.
ssmsap_list_applications(NextToken = NULL, MaxResults = NULL, Filters = NULL)The token for the next page of results.
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
The filter of name, value, and operator.