Lists all the components registered with AWS Systems Manager for SAP.
See https://www.paws-r-sdk.com/docs/ssmsap_list_components/ for full documentation.
ssmsap_list_components(
ApplicationId = NULL,
NextToken = NULL,
MaxResults = NULL
)The ID of the application.
The token for the next page of results.
The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
If you do not specify a value for MaxResults, the request returns 50 items per page by default.