Returns a list of cases that you specify by passing one or more case IDs. You can use the afterTime and beforeTime parameters to filter the cases by date. You can set values for the includeResolvedCases and includeCommunications parameters to specify how much information to return.
See https://paws-r.github.io/docs/support/describe_cases.html for full documentation.
support_describe_cases(
caseIdList = NULL,
displayId = NULL,
afterTime = NULL,
beforeTime = NULL,
includeResolvedCases = NULL,
nextToken = NULL,
maxResults = NULL,
language = NULL,
includeCommunications = NULL
)A list of ID numbers of the support cases you want returned. The maximum number of cases is 100.
The ID displayed for a case in the Amazon Web Services Support Center user interface.
The start date for a filtered date search on support case communications. Case communications are available for 12 months after creation.
The end date for a filtered date search on support case communications. Case communications are available for 12 months after creation.
Specifies whether to include resolved support cases in the
describe_cases response. By default,
resolved cases aren't included.
A resumption point for pagination.
The maximum number of results to return before paginating.
The ISO 639-1 code for the language in which Amazon Web Services provides support. Amazon Web Services Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.
Specifies whether to include communications in the
describe_cases response. By default,
communications are included.