Learn R Programming

paws.management (version 0.2.0)

support_describe_services: Returns the current list of Amazon Web Services services and a list of service categories for each service

Description

Returns the current list of Amazon Web Services services and a list of service categories for each service. You then use service names and categories in your create_case requests. Each Amazon Web Services service has its own set of categories.

See https://paws-r.github.io/docs/support/describe_services.html for full documentation.

Usage

support_describe_services(serviceCodeList = NULL, language = NULL)

Arguments

serviceCodeList

A JSON-formatted list of service codes available for Amazon Web Services services.

language

The ISO 639-1 code for the language in which Amazon Web Services provides support. Amazon Web Services Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.