Learn R Programming

paws.management (version 0.2.0)

support_describe_severity_levels: Returns the list of severity levels that you can assign to a support case

Description

Returns the list of severity levels that you can assign to a support case. The severity level for a case is also a field in the CaseDetails data type that you include for a create_case request.

See https://paws-r.github.io/docs/support/describe_severity_levels.html for full documentation.

Usage

support_describe_severity_levels(language = NULL)

Arguments

language

The ISO 639-1 code for the language in which Amazon Web Services provides support. Amazon Web Services Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.