Returns the refresh status of the Trusted Advisor checks that have the specified check IDs. You can get the check IDs by calling the describe_trusted_advisor_checks operation.
See https://paws-r.github.io/docs/support/describe_trusted_advisor_check_refresh_statuses.html for full documentation.
support_describe_trusted_advisor_check_refresh_statuses(checkIds)[required] The IDs of the Trusted Advisor checks to get the status.
If you specify the check ID of a check that is automatically refreshed,
you might see an InvalidParameterValue error.