Learn R Programming

paws.management (version 0.2.0)

support_describe_trusted_advisor_checks: Returns information about all available Trusted Advisor checks, including the name, ID, category, description, and metadata

Description

Returns information about all available Trusted Advisor checks, including the name, ID, category, description, and metadata. You must specify a language code. The Amazon Web Services Support API currently supports English ("en") and Japanese ("ja"). The response contains a TrustedAdvisorCheckDescription object for each check. You must set the Amazon Web Services Region to us-east-1.

See https://paws-r.github.io/docs/support/describe_trusted_advisor_checks.html for full documentation.

Usage

support_describe_trusted_advisor_checks(language)

Arguments

language

[required] The ISO 639-1 code for the language in which Amazon Web Services provides support. Amazon Web Services Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.