Learn R Programming

paws.management (version 0.2.0)

support_resolve_case: Resolves a support case

Description

Resolves a support case. This operation takes a caseId and returns the initial and final state of the case.

See https://paws-r.github.io/docs/support/resolve_case.html for full documentation.

Usage

support_resolve_case(caseId = NULL)

Arguments

caseId

The support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47