Learn R Programming

paws.management (version 0.2.0)

synthetics_delete_canary: Permanently deletes the specified canary

Description

Permanently deletes the specified canary.

See https://paws-r.github.io/docs/synthetics/delete_canary.html for full documentation.

Usage

synthetics_delete_canary(Name, DeleteLambda = NULL)

Arguments

Name

[required] The name of the canary that you want to delete. To find the names of your canaries, use describe_canaries.

DeleteLambda

Specifies whether to also delete the Lambda functions and layers used by this canary. The default is false.

Type: Boolean