Learn R Programming

paws.management (version 0.2.0)

synthetics_disassociate_resource: Removes a canary from a group

Description

Removes a canary from a group. You must run this operation in the Region where the canary exists.

See https://paws-r.github.io/docs/synthetics/disassociate_resource.html for full documentation.

Usage

synthetics_disassociate_resource(GroupIdentifier, ResourceArn)

Arguments

GroupIdentifier

[required] Specifies the group. You can specify the group name, the ARN, or the group ID as the GroupIdentifier.

ResourceArn

[required] The ARN of the canary that you want to remove from the specified group.