Learn R Programming

paws.management (version 0.2.0)

synthetics_get_canary: Retrieves complete information about one canary

Description

Retrieves complete information about one canary. You must specify the name of the canary that you want. To get a list of canaries and their names, use describe_canaries.

See https://paws-r.github.io/docs/synthetics/get_canary.html for full documentation.

Usage

synthetics_get_canary(Name)

Arguments

Name

[required] The name of the canary that you want details for.