Retrieves a list of runs for a specified canary.
See https://paws-r.github.io/docs/synthetics/get_canary_runs.html for full documentation.
synthetics_get_canary_runs(Name, NextToken = NULL, MaxResults = NULL)[required] The name of the canary that you want to see runs for.
A token that indicates that there is more data available. You can use
this token in a subsequent
get_canary_runs operation to retrieve
the next set of results.
Specify this parameter to limit how many runs are returned each time you
use the get_canary_runs operation. If
you omit this parameter, the default of 100 is used.