This operation returns a list of the ARNs of the canaries that are associated with the specified group.
See https://paws-r.github.io/docs/synthetics/list_group_resources.html for full documentation.
synthetics_list_group_resources(
NextToken = NULL,
MaxResults = NULL,
GroupIdentifier
)A token that indicates that there is more data available. You can use this token in a subsequent operation to retrieve the next set of results.
Specify this parameter to limit how many canary ARNs are returned each
time you use the
list_group_resources operation. If
you omit this parameter, the default of 20 is used.
[required] Specifies the group to return information for. You can specify the group
name, the ARN, or the group ID as the GroupIdentifier.