Learn R Programming

paws.management (version 0.2.0)

synthetics_start_canary: Use this operation to run a canary that has already been created

Description

Use this operation to run a canary that has already been created. The frequency of the canary runs is determined by the value of the canary's Schedule. To see a canary's schedule, use get_canary.

See https://paws-r.github.io/docs/synthetics/start_canary.html for full documentation.

Usage

synthetics_start_canary(Name)

Arguments

Name

[required] The name of the canary that you want to run. To find canary names, use describe_canaries.