Removes one or more tags from the specified resource.
See https://paws-r.github.io/docs/synthetics/untag_resource.html for full documentation.
synthetics_untag_resource(ResourceArn, TagKeys)[required] The ARN of the canary or group that you're removing tags from.
The ARN format of a canary is
arn:aws:synthetics:Region:account-id:canary:canary-name .
The ARN format of a group is
arn:aws:synthetics:Region:account-id:group:group-name
[required] The list of tag keys to remove from the resource.