Retrieves a list of all reports and their configurations for your AWS account.
See https://paws-r.github.io/docs/applicationcostprofiler/list_report_definitions.html for full documentation.
applicationcostprofiler_list_report_definitions(
nextToken = NULL,
maxResults = NULL
)The token value from a previous call to access the next page of results.
The maximum number of results to return.