Ungroups a custom component. When you ungroup custom components, all applicable monitors that are set up for the component are removed and the instances revert to their standalone status.
See https://paws-r.github.io/docs/applicationinsights/delete_component.html for full documentation.
applicationinsights_delete_component(ResourceGroupName, ComponentName)[required] The name of the resource group.
[required] The name of the component.