Lists the IDs of the applications that you are monitoring.
See https://paws-r.github.io/docs/applicationinsights/list_applications.html for full documentation.
applicationinsights_list_applications(MaxResults = NULL, NextToken = NULL)The maximum number of results to return in a single call. To retrieve
the remaining results, make another call with the returned NextToken
value.
The token to request the next page of results.