Lists the auto-grouped, standalone, and custom components of the application.
applicationinsights_list_components(ResourceGroupName, MaxResults,
NextToken)[required] The name of the resource group.
The maximum number of results to return in a single call. To retrieve
the remaining results, make another call with the returned NextToken
value.
The token to request the next page of results.
A list with the following syntax:
list(
ApplicationComponentList = list(
list(
ComponentName = "string",
ComponentRemarks = "string",
ResourceType = "string",
OsType = "WINDOWS"|"LINUX",
Tier = "CUSTOM"|"DEFAULT"|"DOT_NET_CORE"|"DOT_NET_WORKER"|"DOT_NET_WEB_TIER"|"DOT_NET_WEB"|"SQL_SERVER"|"SQL_SERVER_ALWAYSON_AVAILABILITY_GROUP"|"MYSQL"|"POSTGRESQL"|"JAVA_JMX"|"ORACLE",
Monitor = TRUE|FALSE,
DetectedWorkload = list(
list(
"string"
)
)
)
),
NextToken = "string"
)
svc$list_components( ResourceGroupName = "string", MaxResults = 123, NextToken = "string" )