Lists the log patterns in the specific log LogPatternSet.
See https://paws-r.github.io/docs/applicationinsights/list_log_patterns.html for full documentation.
applicationinsights_list_log_patterns(
ResourceGroupName,
PatternSetName = NULL,
MaxResults = NULL,
NextToken = NULL
)[required] The name of the resource group.
The name of the log pattern set.
The maximum number of results to return in a single call. To retrieve
the remaining results, make another call with the returned NextToken
value.
The token to request the next page of results.