Associates a resource with an application. Both the resource and the application can be specified either by ID or name.
See https://paws-r.github.io/docs/appregistry/associate_resource.html for full documentation.
appregistry_associate_resource(application, resourceType, resource)[required] The name or ID of the application.
[required] The type of resource of which the application will be associated.
[required] The name or ID of the resource of which the application will be associated.