Deletes an application that is specified either by its application ID or name. All associated attribute groups and resources must be disassociated from it before deleting an application.
See https://paws-r.github.io/docs/appregistry/delete_application.html for full documentation.
appregistry_delete_application(application)[required] The name or ID of the application.