Deletes an attribute group, specified either by its attribute group ID or name.
See https://paws-r.github.io/docs/appregistry/delete_attribute_group.html for full documentation.
appregistry_delete_attribute_group(attributeGroup)[required] The name or ID of the attribute group that holds the attributes to describe the application.