Syncs the resource with current AppRegistry records.
See https://paws-r.github.io/docs/appregistry/sync_resource.html for full documentation.
appregistry_sync_resource(resourceType, resource)[required] The type of resource of which the application will be associated.
[required] An entity you can work with and specify with a name or ID. Examples include an Amazon EC2 instance, an Amazon Web Services CloudFormation stack, or an Amazon S3 bucket.