Returns a list of the frameworks that are available in the Audit Manager framework library.
See https://paws-r.github.io/docs/auditmanager/list_assessment_frameworks.html for full documentation.
auditmanager_list_assessment_frameworks(
frameworkType,
nextToken = NULL,
maxResults = NULL
)[required] The type of framework, such as a standard framework or a custom framework.
The pagination token that's used to fetch the next set of results.
Represents the maximum number of results on a page or for an API request call.