Attaches one or more target groups to the specified Auto Scaling group.
See https://paws-r.github.io/docs/autoscaling/attach_load_balancer_target_groups.html for full documentation.
autoscaling_attach_load_balancer_target_groups(
AutoScalingGroupName,
TargetGroupARNs
)[required] The name of the Auto Scaling group.
[required] The Amazon Resource Names (ARN) of the target groups. You can specify up to 10 target groups. To get the ARN of a target group, use the Elastic Load Balancing DescribeTargetGroups API operation.