Gets information about the lifecycle hooks for the specified Auto Scaling group.
See https://paws-r.github.io/docs/autoscaling/describe_lifecycle_hooks.html for full documentation.
autoscaling_describe_lifecycle_hooks(
AutoScalingGroupName,
LifecycleHookNames = NULL
)[required] The name of the Auto Scaling group.
The names of one or more lifecycle hooks. If you omit this property, all lifecycle hooks are described.