Gets information about the Elastic Load Balancing target groups for the specified Auto Scaling group.
See https://paws-r.github.io/docs/autoscaling/describe_load_balancer_target_groups.html for full documentation.
autoscaling_describe_load_balancer_target_groups(
AutoScalingGroupName,
NextToken = NULL,
MaxRecords = NULL
)[required] The name of the Auto Scaling group.
The token for the next set of items to return. (You received this token from a previous call.)
The maximum number of items to return with this call. The default value
is 100 and the maximum value is 100.