Removes one or more instances from the specified Auto Scaling group.
See https://paws-r.github.io/docs/autoscaling/detach_instances.html for full documentation.
autoscaling_detach_instances(
InstanceIds = NULL,
AutoScalingGroupName,
ShouldDecrementDesiredCapacity
)The IDs of the instances. You can specify up to 20 instances.
[required] The name of the Auto Scaling group.
[required] Indicates whether the Auto Scaling group decrements the desired capacity value by the number of instances detached.