Moves the specified instances into the standby state.
See https://paws-r.github.io/docs/autoscaling/enter_standby.html for full documentation.
autoscaling_enter_standby(
InstanceIds = NULL,
AutoScalingGroupName,
ShouldDecrementDesiredCapacity
)The IDs of the instances. You can specify up to 20 instances.
[required] The name of the Auto Scaling group.
[required] Indicates whether to decrement the desired capacity of the Auto Scaling
group by the number of instances moved to Standby mode.