Cancels an update on the specified stack. If the call completes successfully, the stack rolls back the update and reverts to the previous stack configuration.
See https://paws-r.github.io/docs/cloudformation/cancel_update_stack.html for full documentation.
cloudformation_cancel_update_stack(StackName, ClientRequestToken = NULL)[required] The name or the unique stack ID that's associated with the stack.
A unique identifier for this
cancel_update_stack request.
Specify this token if you plan to retry requests so that CloudFormation
knows that you're not attempting to cancel an update on a stack with the
same name. You might retry
cancel_update_stack requests to
ensure that CloudFormation successfully received them.