Returns the description for the specified stack; if no stack name was specified, then it returns the description for all the stacks created.
See https://paws-r.github.io/docs/cloudformation/describe_stacks.html for full documentation.
cloudformation_describe_stacks(StackName = NULL, NextToken = NULL)The name or the unique stack ID that's associated with the stack, which aren't always interchangeable:
Running stacks: You can specify either the stack's name or its unique stack ID.
Deleted stacks: You must specify the unique stack ID.
Default: There is no default value.
A string that identifies the next page of stacks that you want to retrieve.