Creates a new event data store.
See https://paws-r.github.io/docs/cloudtrail/create_event_data_store.html for full documentation.
cloudtrail_create_event_data_store(
Name,
AdvancedEventSelectors = NULL,
MultiRegionEnabled = NULL,
OrganizationEnabled = NULL,
RetentionPeriod = NULL,
TerminationProtectionEnabled = NULL,
TagsList = NULL
)[required] The name of the event data store.
The advanced event selectors to use to select the events for the data store. For more information about how to use advanced event selectors, see Log events by using advanced event selectors in the CloudTrail User Guide.
Specifies whether the event data store includes events from all regions, or only from the region in which the event data store is created.
Specifies whether an event data store collects events logged for an organization in Organizations.
The retention period of the event data store, in days. You can set a retention period of up to 2555 days, the equivalent of seven years.
Specifies whether termination protection is enabled for the event data store. If termination protection is enabled, you cannot delete the event data store until termination protection is disabled.