Returns metadata about a query, including query run time in milliseconds, number of events scanned and matched, and query status. You must specify an ARN for EventDataStore, and a value for QueryID.
See https://paws-r.github.io/docs/cloudtrail/describe_query.html for full documentation.
cloudtrail_describe_query(EventDataStore, QueryId)[required] The ARN (or the ID suffix of the ARN) of an event data store on which the specified query was run.
[required] The query ID.