Lets you enable Insights event logging by specifying the Insights selectors that you want to enable on an existing trail. You also use put_insight_selectors to turn off Insights event logging, by passing an empty list of insight types. The valid Insights event types in this release are ApiErrorRateInsight and ApiCallRateInsight.
See https://paws-r.github.io/docs/cloudtrail/put_insight_selectors.html for full documentation.
cloudtrail_put_insight_selectors(TrailName, InsightSelectors)[required] The name of the CloudTrail trail for which you want to change or add Insights selectors.
[required] A JSON string that contains the insight types you want to log on a
trail. ApiCallRateInsight and ApiErrorRateInsight are valid insight
types.