Lets you enable Insights event logging by specifying the Insights
selectors that you want to enable on an existing trail. You also use
put_insight_selectors to turn off
Insights event logging, by passing an empty list of insight types. In
this release, only ApiCallRateInsight is supported as an Insights
selector.
cloudtrail_put_insight_selectors(TrailName, InsightSelectors)[required] The name of the CloudTrail trail for which you want to change or add Insights selectors.
[required] A JSON string that contains the insight types you want to log on a
trail. In this release, only ApiCallRateInsight is supported as an
insight type.
A list with the following syntax:
list(
TrailARN = "string",
InsightSelectors = list(
list(
InsightType = "ApiCallRateInsight"
)
)
)
svc$put_insight_selectors(
TrailName = "string",
InsightSelectors = list(
list(
InsightType = "ApiCallRateInsight"
)
)
)