Updates an event data store. The required EventDataStore value is an ARN or the ID portion of the ARN. Other parameters are optional, but at least one optional parameter must be specified, or CloudTrail throws an error. RetentionPeriod is in days, and valid values are integers between 90 and 2555. By default, TerminationProtection is enabled. AdvancedEventSelectors includes or excludes management and data events in your event data store; for more information about AdvancedEventSelectors, see PutEventSelectorsRequest$AdvancedEventSelectors.
See https://paws-r.github.io/docs/cloudtrail/update_event_data_store.html for full documentation.
cloudtrail_update_event_data_store(
EventDataStore,
Name = NULL,
AdvancedEventSelectors = NULL,
MultiRegionEnabled = NULL,
OrganizationEnabled = NULL,
RetentionPeriod = NULL,
TerminationProtectionEnabled = NULL
)[required] The ARN (or the ID suffix of the ARN) of the event data store that you want to update.
The event data store name.
The advanced event selectors used to select events for the event data store.
Specifies whether an event data store collects events from all regions, or only from the region in which it was created.
Specifies whether an event data store collects events logged for an organization in Organizations.
The retention period, in days.
Indicates that termination protection is enabled and the event data store cannot be automatically deleted.