powered by
Returns information about the metric stream that you specify.
See https://paws-r.github.io/docs/cloudwatch/get_metric_stream.html for full documentation.
cloudwatch_get_metric_stream(Name)
[required] The name of the metric stream to retrieve information about.