Activates a partner event source that has been deactivated. Once activated, your matching event bus will start receiving events from the event source.
See https://paws-r.github.io/docs/cloudwatchevents/activate_event_source.html for full documentation.
cloudwatchevents_activate_event_source(Name)[required] The name of the partner event source to activate.