You can use this operation to temporarily stop receiving events from the specified partner event source. The matching event bus is not deleted.
See https://paws-r.github.io/docs/cloudwatchevents/deactivate_event_source.html for full documentation.
cloudwatchevents_deactivate_event_source(Name)[required] The name of the partner event source to deactivate.