Disables the specified rule. A disabled rule won't match any events, and won't self-trigger if it has a schedule expression.
See https://paws-r.github.io/docs/cloudwatchevents/disable_rule.html for full documentation.
cloudwatchevents_disable_rule(Name, EventBusName = NULL)[required] The name of the rule.
The name or ARN of the event bus associated with the rule. If you omit this, the default event bus is used.