Retrieves a list of API destination in the account in the current Region.
See https://paws-r.github.io/docs/cloudwatchevents/list_api_destinations.html for full documentation.
cloudwatchevents_list_api_destinations(
NamePrefix = NULL,
ConnectionArn = NULL,
NextToken = NULL,
Limit = NULL
)A name prefix to filter results returned. Only API destinations with a name that starts with the prefix are returned.
The ARN of the connection specified for the API destination.
The token returned by a previous call to retrieve the next set of results.
The maximum number of API destinations to include in the response.