Retrieves a list of connections from the account.
See https://paws-r.github.io/docs/cloudwatchevents/list_connections.html for full documentation.
cloudwatchevents_list_connections(
NamePrefix = NULL,
ConnectionState = NULL,
NextToken = NULL,
Limit = NULL
)A name prefix to filter results returned. Only connections with a name that starts with the prefix are returned.
The state of the connection.
The token returned by a previous call to retrieve the next set of results.
The maximum number of connections to return.