Deletes an Evidently experiment. The feature used for the experiment is not deleted.
See https://paws-r.github.io/docs/cloudwatchevidently/delete_experiment.html for full documentation.
cloudwatchevidently_delete_experiment(experiment, project)[required] The name of the experiment to delete.
[required] The name or ARN of the project that contains the experiment to delete.