powered by
Returns the details about one launch. You must already know the project name. To retrieve a list of projects in your account, use list_projects.
list_projects
See https://paws-r.github.io/docs/cloudwatchevidently/get_project.html for full documentation.
cloudwatchevidently_get_project(project)
[required] The name or ARN of the project that you want to see the details of.