Returns configuration details about all the features in the specified project.
See https://paws-r.github.io/docs/cloudwatchevidently/list_features.html for full documentation.
cloudwatchevidently_list_features(maxResults = NULL, nextToken = NULL, project)The maximum number of results to include in the response.
The token to use when requesting the next set of results. You received
this token from a previous
list_features operation.
[required] The name or ARN of the project to return the feature list from.