Sends performance events to Evidently. These events can be used to evaluate a launch or an experiment.
See https://paws-r.github.io/docs/cloudwatchevidently/put_project_events.html for full documentation.
cloudwatchevidently_put_project_events(events, project)[required] An array of event structures that contain the performance data that is being sent to Evidently.
[required] The name or ARN of the project to write the events to.