Stops an experiment that is currently running. If you stop an experiment, you can't resume it or restart it.
See https://paws-r.github.io/docs/cloudwatchevidently/stop_experiment.html for full documentation.
cloudwatchevidently_stop_experiment(
desiredState = NULL,
experiment,
project,
reason = NULL
)Specify whether the experiment is to be considered COMPLETED or
CANCELLED after it stops.
[required] The name of the experiment to stop.
[required] The name or ARN of the project that contains the experiment to stop.
A string that describes why you are stopping the experiment.