Removes one or more tags from the specified resource.
See https://paws-r.github.io/docs/cloudwatchevidently/untag_resource.html for full documentation.
cloudwatchevidently_untag_resource(resourceArn, tagKeys)[required] The ARN of the CloudWatch Evidently resource that you're removing tags from.
[required] The list of tag keys to remove from the resource.