Associates the specified Key Management Service customer master key (CMK) with the specified log group.
See https://paws-r.github.io/docs/cloudwatchlogs/associate_kms_key.html for full documentation.
cloudwatchlogs_associate_kms_key(logGroupName, kmsKeyId)[required] The name of the log group.
[required] The Amazon Resource Name (ARN) of the CMK to use when encrypting log data. This must be a symmetric CMK. For more information, see Amazon Resource Names - Key Management Service and Using Symmetric and Asymmetric Keys.