Creates a log group with the specified name. You can create up to 20,000 log groups per account.
See https://paws-r.github.io/docs/cloudwatchlogs/create_log_group.html for full documentation.
cloudwatchlogs_create_log_group(logGroupName, kmsKeyId = NULL, tags = NULL)[required] The name of the log group.
The Amazon Resource Name (ARN) of the CMK to use when encrypting log data. For more information, see Amazon Resource Names - Key Management Service.
The key-value pairs to use for the tags.
CloudWatch Logs doesn’t support IAM policies that prevent users from
assigning specified tags to log groups using the
aws:Resource/key-name or aws:TagKeys condition keys. For more
information about using tags to control access, see Controlling access to Amazon Web Services resources using tags.