Creates a log stream for the specified log group. A log stream is a sequence of log events that originate from a single source, such as an application instance or a resource that is being monitored.
See https://paws-r.github.io/docs/cloudwatchlogs/create_log_stream.html for full documentation.
cloudwatchlogs_create_log_stream(logGroupName, logStreamName)[required] The name of the log group.
[required] The name of the log stream.