Deletes a resource policy from this account. This revokes the access of the identities in that policy to put log events to this account.
See https://paws-r.github.io/docs/cloudwatchlogs/delete_resource_policy.html for full documentation.
cloudwatchlogs_delete_resource_policy(policyName = NULL)The name of the policy to be revoked. This parameter is required.