Lists all your destinations. The results are ASCII-sorted by destination name.
See https://paws-r.github.io/docs/cloudwatchlogs/describe_destinations.html for full documentation.
cloudwatchlogs_describe_destinations(
DestinationNamePrefix = NULL,
nextToken = NULL,
limit = NULL
)The prefix to match. If you don't specify a value, no prefix filter is applied.
The token for the next set of items to return. (You received this token from a previous call.)
The maximum number of items returned. If you don't specify a value, the default is up to 50 items.