Lists the specified log groups. You can list all your log groups or filter the results by prefix. The results are ASCII-sorted by log group name.
See https://paws-r.github.io/docs/cloudwatchlogs/describe_log_groups.html for full documentation.
cloudwatchlogs_describe_log_groups(
logGroupNamePrefix = NULL,
nextToken = NULL,
limit = NULL
)The prefix to match.
The token for the next set of items to return. (You received this token from a previous call.)
The maximum number of items returned. If you don't specify a value, the default is up to 50 items.