Returns a list of the fields that are included in log events in the specified log group, along with the percentage of log events that contain each field. The search is limited to a time period that you specify.
See https://paws-r.github.io/docs/cloudwatchlogs/get_log_group_fields.html for full documentation.
cloudwatchlogs_get_log_group_fields(logGroupName, time = NULL)[required] The name of the log group to search.
The time to set as the center of the query. If you specify time, the
15 minutes before this time are queries. If you omit time the 8
minutes before and 8 minutes after this time are searched.
The time value is specified as epoch time, the number of seconds since
January 1, 1970, 00:00:00 UTC.