Retrieves all of the fields and values of a single log event. All fields are retrieved, even if the original query that produced the logRecordPointer retrieved only a subset of fields. Fields are returned as field name/field value pairs.
See https://paws-r.github.io/docs/cloudwatchlogs/get_log_record.html for full documentation.
cloudwatchlogs_get_log_record(logRecordPointer)[required] The pointer corresponding to the log event record you want to retrieve.
You get this from the response of a
get_query_results operation. In
that response, the value of the @ptr field for a log event is the
value to use as logRecordPointer to retrieve that complete log event
record.