Creates or updates a destination. This operation is used only to create destinations for cross-account subscriptions.
See https://paws-r.github.io/docs/cloudwatchlogs/put_destination.html for full documentation.
cloudwatchlogs_put_destination(destinationName, targetArn, roleArn)[required] A name for the destination.
[required] The ARN of an Amazon Kinesis stream to which to deliver matching log events.
[required] The ARN of an IAM role that grants CloudWatch Logs permissions to call
the Amazon Kinesis PutRecord operation on the destination stream.