Uploads a batch of log events to the specified log stream.
See https://paws-r.github.io/docs/cloudwatchlogs/put_log_events.html for full documentation.
cloudwatchlogs_put_log_events(
logGroupName,
logStreamName,
logEvents,
sequenceToken = NULL
)[required] The name of the log group.
[required] The name of the log stream.
[required] The log events.
The sequence token obtained from the response of the previous
put_log_events call. An upload in a
newly created log stream does not require a sequence token. You can also
get the sequence token using
describe_log_streams. If you
call put_log_events twice within a
narrow time period using the same value for sequenceToken, both calls
might be successful or one might be rejected.