Sets the retention of the specified log group. A retention policy allows you to configure the number of days for which to retain log events in the specified log group.
See https://paws-r.github.io/docs/cloudwatchlogs/put_retention_policy.html for full documentation.
cloudwatchlogs_put_retention_policy(logGroupName, retentionInDays)[required] The name of the log group.
[required]