Returns a list of the Amazon CloudWatch RUM app monitors in the account.
See https://paws-r.github.io/docs/cloudwatchrum/list_app_monitors.html for full documentation.
cloudwatchrum_list_app_monitors(MaxResults = NULL, NextToken = NULL)The maximum number of results to return in one operation.
Use the token returned by the previous operation to request the next page of results.