Deletes the specified AWS Config rule and all of its evaluation results.
AWS Config sets the state of a rule to DELETING until the deletion is
complete. You cannot update a rule while it is in this state. If you
make a put_config_rule or
delete_config_rule request for the
rule, you will receive a ResourceInUseException.
You can check the state of a rule by using the
describe_config_rules request.
configservice_delete_config_rule(ConfigRuleName)[required] The name of the AWS Config rule that you want to delete.
An empty list.
svc$delete_config_rule( ConfigRuleName = "string" )