Deletes the configuration recorder.
See https://paws-r.github.io/docs/configservice/delete_configuration_recorder.html for full documentation.
configservice_delete_configuration_recorder(ConfigurationRecorderName)[required] The name of the configuration recorder to be deleted. You can retrieve
the name of your configuration recorder by using the
describe_configuration_recorders
action.