Deletes one or more remediation exceptions mentioned in the resource keys.
See https://paws-r.github.io/docs/configservice/delete_remediation_exceptions.html for full documentation.
configservice_delete_remediation_exceptions(ConfigRuleName, ResourceKeys)[required] The name of the Config rule for which you want to delete remediation exception configuration.
[required] An exception list of resource exception keys to be processed with the current request. Config adds exception for each resource key. For example, Config adds 3 exceptions for 3 resource keys.