Deletes the stored query for a single Amazon Web Services account and a single Amazon Web Services Region.
See https://paws-r.github.io/docs/configservice/delete_stored_query.html for full documentation.
configservice_delete_stored_query(QueryName)[required] The name of the query that you want to delete.