Returns the current status of the specified configuration recorder. If a configuration recorder is not specified, this action returns the status of all configuration recorders associated with the account.
See https://paws-r.github.io/docs/configservice/describe_configuration_recorder_status.html for full documentation.
configservice_describe_configuration_recorder_status(
ConfigurationRecorderNames = NULL
)The name(s) of the configuration recorder. If the name is not specified, the action returns the current status of all the configuration recorders associated with the account.