Returns a list of organization conformance packs.
See https://paws-r.github.io/docs/configservice/describe_organization_conformance_packs.html for full documentation.
configservice_describe_organization_conformance_packs(
OrganizationConformancePackNames = NULL,
Limit = NULL,
NextToken = NULL
)The name that you assign to an organization conformance pack.
The maximum number of organization config packs returned on each page. If you do no specify a number, Config uses the default. The default is 100.
The nextToken string returned on a previous page that you use to get the next page of results in a paginated response.