Returns a list of all pending aggregation requests.
configservice_describe_pending_aggregation_requests(Limit, NextToken)The maximum number of evaluation results returned on each page. The default is maximum. If you specify 0, AWS Config uses the default.
The nextToken string returned on a previous page that you use to get
the next page of results in a paginated response.
A list with the following syntax:
list(
PendingAggregationRequests = list(
list(
RequesterAccountId = "string",
RequesterAwsRegion = "string"
)
),
NextToken = "string"
)
svc$describe_pending_aggregation_requests( Limit = 123, NextToken = "string" )