Returns configuration item that is aggregated for your specific resource in a specific source account and region.
See https://paws-r.github.io/docs/configservice/get_aggregate_resource_config.html for full documentation.
configservice_get_aggregate_resource_config(
ConfigurationAggregatorName,
ResourceIdentifier
)[required] The name of the configuration aggregator.
[required] An object that identifies aggregate resource.