Returns the evaluation results for the specified Amazon Web Services resource. The results indicate which Config rules were used to evaluate the resource, when each rule was last used, and whether the resource complies with each rule.
See https://paws-r.github.io/docs/configservice/get_compliance_details_by_resource.html for full documentation.
configservice_get_compliance_details_by_resource(
ResourceType,
ResourceId,
ComplianceTypes = NULL,
NextToken = NULL
)[required] The type of the Amazon Web Services resource for which you want compliance information.
[required] The ID of the Amazon Web Services resource for which you want compliance information.
Filters the results by compliance.
The allowed values are COMPLIANT, NON_COMPLIANT, and
NOT_APPLICABLE.
The nextToken string returned on a previous page that you use to get
the next page of results in a paginated response.