List the stored queries for an AWS account in an AWS Region. The default is 100.
configservice_list_stored_queries(NextToken, MaxResults)The nextToken string returned in a previous request that you use to request the next page of results in a paginated response.
The maximum number of results to be returned with a single call.
A list with the following syntax:
list(
StoredQueryMetadata = list(
list(
QueryId = "string",
QueryArn = "string",
QueryName = "string",
Description = "string"
)
),
NextToken = "string"
)
svc$list_stored_queries( NextToken = "string", MaxResults = 123 )