Creates a new configuration recorder to record the selected resource configurations.
See https://paws-r.github.io/docs/configservice/put_configuration_recorder.html for full documentation.
configservice_put_configuration_recorder(ConfigurationRecorder)[required] The configuration recorder object that records each configuration change made to the resources.