Creates a grant for the specified license. A grant shares the use of license entitlements with specific Amazon Web Services accounts.
See https://paws-r.github.io/docs/licensemanager/create_grant.html for full documentation.
licensemanager_create_grant(
ClientToken,
GrantName,
LicenseArn,
Principals,
HomeRegion,
AllowedOperations
)[required] Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
[required] Grant name.
[required] Amazon Resource Name (ARN) of the license.
[required] The grant principals.
[required] Home Region of the grant.
[required] Allowed operations for the grant.