Creates a new license conversion task.
See https://paws-r.github.io/docs/licensemanager/create_license_conversion_task_for_resource.html for full documentation.
licensemanager_create_license_conversion_task_for_resource(
ResourceArn,
SourceLicenseContext,
DestinationLicenseContext
)[required] Amazon Resource Name (ARN) of the resource you are converting the license type for.
[required] Information that identifies the license type you are converting from. For the structure of the source license, see Convert a license type using the AWS CLI in the License Manager User Guide.
[required] Information that identifies the license type you are converting to. For the structure of the destination license, see Convert a license type using the AWS CLI in the License Manager User Guide.