Gets a temporary access token to use with AssumeRoleWithWebIdentity. Access tokens are valid for one hour.
See https://paws-r.github.io/docs/licensemanager/get_access_token.html for full documentation.
licensemanager_get_access_token(Token, TokenProperties = NULL)[required] Refresh token, encoded as a JWT token.
Token properties to validate against those present in the JWT token.