Lists the resource associations for the specified license configuration.
Resource associations need not consume licenses from a license configuration. For example, an AMI or a stopped instance might not consume a license (depending on the license rules).
licensemanager_list_associations_for_license_configuration(
LicenseConfigurationArn, MaxResults, NextToken)[required] Amazon Resource Name (ARN) of a license configuration.
Maximum number of results to return in a single call.
Token for the next set of results.
A list with the following syntax:
list(
LicenseConfigurationAssociations = list(
list(
ResourceArn = "string",
ResourceType = "EC2_INSTANCE"|"EC2_HOST"|"EC2_AMI"|"RDS"|"SYSTEMS_MANAGER_MANAGED_INSTANCE",
ResourceOwnerId = "string",
AssociationTime = as.POSIXct(
"2015-01-01"
),
AmiAssociationScope = "string"
)
),
NextToken = "string"
)
svc$list_associations_for_license_configuration( LicenseConfigurationArn = "string", MaxResults = 123, NextToken = "string" )