Lists the license type conversion tasks for your account.
See https://paws-r.github.io/docs/licensemanager/list_license_conversion_tasks.html for full documentation.
licensemanager_list_license_conversion_tasks(
NextToken = NULL,
MaxResults = NULL,
Filters = NULL
)Token for the next set of results.
Maximum number of results to return in a single call.
Filters to scope the results. Valid filters are ResourceArns and
Status.