Describes the license configurations for the specified resource.
See https://paws-r.github.io/docs/licensemanager/list_license_specifications_for_resource.html for full documentation.
licensemanager_list_license_specifications_for_resource(
ResourceArn,
MaxResults = NULL,
NextToken = NULL
)[required] Amazon Resource Name (ARN) of a resource that has an associated license configuration.
Maximum number of results to return in a single call.
Token for the next set of results.