Describes the license configurations for the specified resource.
licensemanager_list_license_specifications_for_resource(ResourceArn,
MaxResults, NextToken)[required] Amazon Resource Name (ARN) of a resource that has an associated license configuration.
Maximum number of results to return in a single call.
Token for the next set of results.
A list with the following syntax:
list(
LicenseSpecifications = list(
list(
LicenseConfigurationArn = "string",
AmiAssociationScope = "string"
)
),
NextToken = "string"
)
svc$list_license_specifications_for_resource( ResourceArn = "string", MaxResults = 123, NextToken = "string" )