Registers an identity provider for user-based subscriptions.
See https://www.paws-r-sdk.com/docs/licensemanagerusersubscriptions_register_identity_provider/ for full documentation.
licensemanagerusersubscriptions_register_identity_provider(
IdentityProvider,
Product,
Settings = NULL
)[required] An object that specifies details for the identity provider.
[required] The name of the user-based subscription product.
The registered identity provider’s product related configuration settings such as the subnets to provision VPC endpoints.