Starts a product subscription for a user with the specified identity provider.
See https://paws-r.github.io/docs/licensemanagerusersubscriptions/start_product_subscription.html for full documentation.
licensemanagerusersubscriptions_start_product_subscription(
Domain = NULL,
IdentityProvider,
Product,
Username
)The domain name of the user.
[required] An object that specifies details for the identity provider.
[required] The name of the user-based subscription product.
[required] The user name from the identity provider of the user.