Updates additional product configuration settings for the registered identity provider.
See https://www.paws-r-sdk.com/docs/licensemanagerusersubscriptions_update_identity_provider_settings/ for full documentation.
licensemanagerusersubscriptions_update_identity_provider_settings(
IdentityProvider,
Product,
UpdateSettings
)[required]
[required] The name of the user-based subscription product.
[required] Updates the registered identity provider’s product related configuration settings. You can update any combination of settings in a single operation such as the:
Subnets which you want to add to provision VPC endpoints.
Subnets which you want to remove the VPC endpoints from.
Security group ID which permits traffic to the VPC endpoints.