Creates an API key for the workspace. This key can be used to authenticate requests sent to the workspace's HTTP API. See https://docs.aws.amazon.com/grafana/latest/userguide/Using-Grafana-APIs.html for available APIs and example requests.
See https://paws-r.github.io/docs/managedgrafana/create_workspace_api_key.html for full documentation.
managedgrafana_create_workspace_api_key(
keyName,
keyRole,
secondsToLive,
workspaceId
)[required] Specifies the name of the key to create. Key names must be unique to the workspace.
[required] Specifies the permission level of the key.
Valid Values: VIEWER | EDITOR | ADMIN
[required] Specifies the time in seconds until the key expires. Keys can be valid for up to 30 days.
[required] The ID of the workspace in which to create an API key.