Removes the Grafana Enterprise license from a workspace.
See https://paws-r.github.io/docs/managedgrafana/disassociate_license.html for full documentation.
managedgrafana_disassociate_license(licenseType, workspaceId)[required] The type of license to remove from the workspace.
[required] The ID of the workspace to remove the Grafana Enterprise license from.