Returns a list of Amazon Managed Grafana workspaces in the account, with some information about each workspace. For more complete information about one workspace, use describe_workspace.
See https://paws-r.github.io/docs/managedgrafana/list_workspaces.html for full documentation.
managedgrafana_list_workspaces(maxResults = NULL, nextToken = NULL)The maximum number of workspaces to include in the results.
The token for the next set of workspaces to return. (You receive this
token from a previous
list_workspaces operation.)