Updates which users in a workspace have the Grafana Admin or Editor roles.
See https://paws-r.github.io/docs/managedgrafana/update_permissions.html for full documentation.
managedgrafana_update_permissions(updateInstructionBatch, workspaceId)[required] An array of structures that contain the permission updates to make.
[required] The ID of the workspace to update.