Learn R Programming

paws.management (version 0.1.12)

opsworks_assign_volume: Assigns one of the stack's registered Amazon EBS volumes to a specified instance

Description

Assigns one of the stack's registered Amazon EBS volumes to a specified instance. The volume must first be registered with the stack by calling register_volume. After you register the volume, you must call update_volume to specify a mount point before calling assign_volume. For more information, see Resource Management.

Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

Usage

opsworks_assign_volume(VolumeId, InstanceId)

Value

An empty list.

Arguments

VolumeId

[required] The volume ID.

InstanceId

The instance ID.

Request syntax

svc$assign_volume(
  VolumeId = "string",
  InstanceId = "string"
)