Assigns one of the stack's registered Amazon EBS volumes to a specified
instance. The volume must first be registered with the stack by calling
register_volume. After you register the
volume, you must call update_volume to
specify a mount point before calling
assign_volume. For more information, see
Resource Management.
Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.
opsworks_assign_volume(VolumeId, InstanceId)[required] The volume ID.
The instance ID.
An empty list.
svc$assign_volume( VolumeId = "string", InstanceId = "string" )