Deletes a specified layer. You must first stop and then delete all associated instances or unassign registered instances. For more information, see How to Delete a Layer.
See https://paws-r.github.io/docs/opsworks/delete_layer.html for full documentation.