Describes AWS OpsWorks Stacks service errors.
See https://paws-r.github.io/docs/opsworks/describe_service_errors.html for full documentation.
opsworks_describe_service_errors(
StackId = NULL,
InstanceId = NULL,
ServiceErrorIds = NULL
)The stack ID. If you use this parameter,
describe_service_errors returns
descriptions of the errors associated with the specified stack.
The instance ID. If you use this parameter,
describe_service_errors returns
descriptions of the errors associated with the specified instance.
An array of service error IDs. If you use this parameter,
describe_service_errors returns
descriptions of the specified errors. Otherwise, it returns a
description of every error.