Detaches a specified Elastic Load Balancing instance from its layer.
See https://paws-r.github.io/docs/opsworks/detach_elastic_load_balancer.html for full documentation.
opsworks_detach_elastic_load_balancer(ElasticLoadBalancerName, LayerId)[required] The Elastic Load Balancing instance's name.
[required] The ID of the layer that the Elastic Load Balancing instance is attached to.