Registers a specified Amazon ECS cluster with a stack. You can register only one cluster with a stack. A cluster can be registered with only one stack. For more information, see Resource Management.
See https://paws-r.github.io/docs/opsworks/register_ecs_cluster.html for full documentation.
opsworks_register_ecs_cluster(EcsClusterArn, StackId)[required] The cluster's ARN.
[required] The stack ID.