Registers an Elastic IP address with a specified stack. An address can
be registered with only one stack at a time. If the address is already
registered, you must first deregister it by calling
deregister_elastic_ip. For more
information, see Resource Management.
Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.
opsworks_register_elastic_ip(ElasticIp, StackId)[required] The Elastic IP address.
[required] The stack ID.
A list with the following syntax:
list( ElasticIp = "string" )
svc$register_elastic_ip( ElasticIp = "string", StackId = "string" )