Registers an Amazon EBS volume with a specified stack. A volume can be
registered with only one stack at a time. If the volume is already
registered, you must first deregister it by calling
deregister_volume. For more information,
see Resource Management.
Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.
opsworks_register_volume(Ec2VolumeId, StackId)A list with the following syntax:
list(
VolumeId = "string"
)
The Amazon EBS volume ID.
[required] The stack ID.
svc$register_volume(
Ec2VolumeId = "string",
StackId = "string"
)