Returns the current status of an existing association or disassociation request.
See https://paws-r.github.io/docs/opsworkscm/describe_node_association_status.html for full documentation.
opsworkscm_describe_node_association_status(
NodeAssociationStatusToken,
ServerName
)[required] The token returned in either the AssociateNodeResponse or the DisassociateNodeResponse.
[required] The name of the server from which to disassociate the node.