Sends a response to the originator of a handshake agreeing to the action proposed by the handshake request.
See https://paws-r.github.io/docs/organizations/accept_handshake.html for full documentation.
organizations_accept_handshake(HandshakeId)[required] The unique identifier (ID) of the handshake that you want to accept.
The regex pattern for handshake ID string requires "h-" followed by from 8 to 32 lowercase letters or digits.