Update a rule groups namespace.
See https://paws-r.github.io/docs/prometheusservice/put_rule_groups_namespace.html for full documentation.
prometheusservice_put_rule_groups_namespace(
clientToken = NULL,
data,
name,
workspaceId
)Optional, unique, case-sensitive, user-provided identifier to ensure the idempotency of the request.
[required] The namespace data that define the rule groups.
[required] The rule groups namespace name.
[required] The ID of the workspace in which to update the rule group namespace.