Deletes an AWS Resilience Hub application. This is a destructive action that can't be undone.
See https://paws-r.github.io/docs/resiliencehub/delete_app.html for full documentation.
resiliencehub_delete_app(appArn, clientToken = NULL, forceDelete = NULL)[required] The Amazon Resource Name (ARN) of the application. The format for this
ARN is: arn:partition:resiliencehub:region:account:app/app-id.
For more information about ARNs, see Amazon Resource Names (ARNs)
in the AWS General Reference.
Used for an idempotency token. A client token is a unique, case-sensitive string of up to 64 ASCII characters. You should not reuse the same client token for other API requests.
A boolean option to force the deletion of a Resilience Hub application.