Adds or updates the app template for a draft version of a Resilience Hub app.
See https://paws-r.github.io/docs/resiliencehub/put_draft_app_version_template.html for full documentation.
resiliencehub_put_draft_app_version_template(appArn, appTemplateBody)[required] The Amazon Resource Name (ARN) of the application. The format for this
ARN is: arn:partition:resiliencehub:region:account:app/app-id.
For more information about ARNs, see Amazon Resource Names (ARNs)
in the AWS General Reference.
[required] A JSON string that contains the body of the app template.