Removes resource mappings from a draft application version.
See https://paws-r.github.io/docs/resiliencehub/remove_draft_app_version_resource_mappings.html for full documentation.
resiliencehub_remove_draft_app_version_resource_mappings(
appArn,
appRegistryAppNames = NULL,
logicalStackNames = NULL,
resourceGroupNames = NULL,
resourceNames = NULL,
terraformSourceNames = NULL
)[required] The Amazon Resource Name (ARN) of the application. The format for this
ARN is: arn:partition:resiliencehub:region:account:app/app-id.
For more information about ARNs, see Amazon Resource Names (ARNs)
in the AWS General Reference.
The names of the registered applications to remove from the resource mappings.
The names of the CloudFormation stacks to remove from the resource mappings.
The names of the resource groups to remove from the resource mappings.
The names of the resources to remove from the resource mappings.
</p>