Updates the resource query of a group. For more information about resource queries, see Create a tag-based group in Resource Groups.
See https://paws-r.github.io/docs/resourcegroups/update_group_query.html for full documentation.
resourcegroups_update_group_query(
GroupName = NULL,
Group = NULL,
ResourceQuery
)Don't use this parameter. Use Group instead.
The name or the ARN of the resource group to query.
[required] The resource query to determine which AWS resources are members of this resource group.
A resource group can contain either a Configuration or a
ResourceQuery, but not both.