Shares the specified portfolio with the specified account or organization node. Shares to an organization node can only be created by the management account of an organization or by a delegated administrator. You can share portfolios to an organization, an organizational unit, or a specific account.
See https://paws-r.github.io/docs/servicecatalog/create_portfolio_share.html for full documentation.
servicecatalog_create_portfolio_share(
AcceptLanguage = NULL,
PortfolioId,
AccountId = NULL,
OrganizationNode = NULL,
ShareTagOptions = NULL
)The language code.
en - English (default)
jp - Japanese
zh - Chinese
[required] The portfolio identifier.
The AWS account ID. For example, 123456789012.
The organization node to whom you are going to share. If
OrganizationNode is passed in, PortfolioShare will be created for
the node an ListOrganizationPortfolioAccessd its children (when
applies), and a PortfolioShareToken will be returned in the output in
order for the administrator to monitor the status of the
PortfolioShare creation process.
Enables or disables TagOptions sharing when creating the portfolio
share. If this flag is not provided, TagOptions sharing is disabled.