Deletes the specified plan.
See https://paws-r.github.io/docs/servicecatalog/delete_provisioned_product_plan.html for full documentation.
servicecatalog_delete_provisioned_product_plan(
AcceptLanguage = NULL,
PlanId,
IgnoreErrors = NULL
)The language code.
en - English (default)
jp - Japanese
zh - Chinese
[required] The plan identifier.
If set to true, AWS Service Catalog stops managing the specified provisioned product even if it cannot delete the underlying resources.