Finds the default parameters for a specific self-service action on a specific provisioned product and returns a map of the results to the user.
See https://paws-r.github.io/docs/servicecatalog/describe_service_action_execution_parameters.html for full documentation.
servicecatalog_describe_service_action_execution_parameters(
ProvisionedProductId,
ServiceActionId,
AcceptLanguage = NULL
)[required] The identifier of the provisioned product.
[required] The self-service action identifier.
The language code.
en - English (default)
jp - Japanese
zh - Chinese