Finds the default parameters for a specific self-service action on a specific provisioned product and returns a map of the results to the user.
servicecatalog_describe_service_action_execution_parameters(
ProvisionedProductId, ServiceActionId, AcceptLanguage)[required] The identifier of the provisioned product.
[required] The self-service action identifier.
The language code.
en - English (default)
jp - Japanese
zh - Chinese
A list with the following syntax:
list(
ServiceActionParameters = list(
list(
Name = "string",
Type = "string",
DefaultValues = list(
"string"
)
)
)
)
svc$describe_service_action_execution_parameters( ProvisionedProductId = "string", ServiceActionId = "string", AcceptLanguage = "string" )