Lists all self-service actions.
servicecatalog_list_service_actions(AcceptLanguage, PageSize, PageToken)The language code.
en - English (default)
jp - Japanese
zh - Chinese
The maximum number of items to return with this call.
The page token for the next set of results. To retrieve the first set of results, use null.
A list with the following syntax:
list(
ServiceActionSummaries = list(
list(
Id = "string",
Name = "string",
Description = "string",
DefinitionType = "SSM_AUTOMATION"
)
),
NextPageToken = "string"
)
svc$list_service_actions( AcceptLanguage = "string", PageSize = 123, PageToken = "string" )