Updates the specified portfolio share. You can use this API to enable or disable TagOptions sharing for an existing portfolio share.
See https://paws-r.github.io/docs/servicecatalog/update_portfolio_share.html for full documentation.
servicecatalog_update_portfolio_share(
AcceptLanguage = NULL,
PortfolioId,
AccountId = NULL,
OrganizationNode = NULL,
ShareTagOptions = NULL
)The language code.
en - English (default)
jp - Japanese
zh - Chinese
[required] The unique identifier of the portfolio for which the share will be updated.
The AWS Account Id of the recipient account. This field is required when updating an external account to account type share.
A flag to enable or disable TagOptions sharing for the portfolio share. If this field is not provided, the current state of TagOptions sharing on the portfolio share will not be modified.