Lists the names and codes for the services integrated with Service Quotas.
servicequotas_list_services(NextToken, MaxResults)The token for the next page of results.
The maximum number of results to return with a single call. To retrieve the remaining results, if any, make another call with the token returned from this call.
A list with the following syntax:
list(
NextToken = "string",
Services = list(
list(
ServiceCode = "string",
ServiceName = "string"
)
)
)
svc$list_services( NextToken = "string", MaxResults = 123 )