Deletes a resource data sync configuration. After the configuration is deleted, changes to data on managed nodes are no longer synced to or from the target. Deleting a sync configuration doesn't delete data.
See https://paws-r.github.io/docs/ssm/delete_resource_data_sync.html for full documentation.
ssm_delete_resource_data_sync(SyncName, SyncType = NULL)[required] The name of the configuration to delete.
Specify the type of resource data sync to delete.