Removes a patch group from a patch baseline.
See https://paws-r.github.io/docs/ssm/deregister_patch_baseline_for_patch_group.html for full documentation.
ssm_deregister_patch_baseline_for_patch_group(BaselineId, PatchGroup)[required] The ID of the patch baseline to deregister the patch group from.
[required] The name of the patch group that should be deregistered from the patch baseline.