Removes a patch group from a patch baseline.
ssm_deregister_patch_baseline_for_patch_group(BaselineId, PatchGroup)A list with the following syntax:
list(
BaselineId = "string",
PatchGroup = "string"
)
[required] The ID of the patch baseline to deregister the patch group from.
[required] The name of the patch group that should be deregistered from the patch baseline.
svc$deregister_patch_baseline_for_patch_group(
BaselineId = "string",
PatchGroup = "string"
)