Removes a target from a maintenance window.
ssm_deregister_target_from_maintenance_window(WindowId, WindowTargetId,
Safe)A list with the following syntax:
list(
WindowId = "string",
WindowTargetId = "string"
)
[required] The ID of the maintenance window the target should be removed from.
[required] The ID of the target definition to remove.
The system checks if the target is being referenced by a task. If the target is being referenced, the system returns an error and does not deregister the target from the maintenance window.
svc$deregister_target_from_maintenance_window(
WindowId = "string",
WindowTargetId = "string",
Safe = TRUE|FALSE
)