Removes a task from a maintenance window.
See https://paws-r.github.io/docs/ssm/deregister_task_from_maintenance_window.html for full documentation.
ssm_deregister_task_from_maintenance_window(WindowId, WindowTaskId)[required] The ID of the maintenance window the task should be removed from.
[required] The ID of the task to remove from the maintenance window.