ssm_deregister_task_from_maintenance_window: Removes a task from a maintenance window
Description
Removes a task from a maintenance window.
Usage
ssm_deregister_task_from_maintenance_window(WindowId, WindowTaskId)
Value
A list with the following syntax:
list(
WindowId = "string",
WindowTaskId = "string"
)
Arguments
- WindowId
[required] The ID of the maintenance window the task should be removed from.
- WindowTaskId
[required] The ID of the task to remove from the maintenance window.
Request syntax
svc$deregister_task_from_maintenance_window(
WindowId = "string",
WindowTaskId = "string"
)