Get detailed information about a particular Automation execution.
See https://paws-r.github.io/docs/ssm/get_automation_execution.html for full documentation.
ssm_get_automation_execution(AutomationExecutionId)[required] The unique identifier for an existing automation execution to examine. The execution ID is returned by StartAutomationExecution when the execution of an Automation runbook is initiated.