Retrieves the Session Manager connection status for a managed node to determine whether it is running and ready to receive Session Manager connections.
See https://paws-r.github.io/docs/ssm/get_connection_status.html for full documentation.
ssm_get_connection_status(Target)[required] The managed node ID.