Retrieves the current snapshot for the patch baseline the managed node uses. This API is primarily used by the AWS-RunPatchBaseline Systems Manager document (SSM document).
See https://paws-r.github.io/docs/ssm/get_deployable_patch_snapshot_for_instance.html for full documentation.
ssm_get_deployable_patch_snapshot_for_instance(
InstanceId,
SnapshotId,
BaselineOverride = NULL
)[required] The ID of the managed node for which the appropriate patch snapshot should be retrieved.
[required] The snapshot ID provided by the user when running
AWS-RunPatchBaseline.
Defines the basic information about a patch baseline override.