Retrieves the details about a specific task run as part of a maintenance window execution.
See https://paws-r.github.io/docs/ssm/get_maintenance_window_execution_task.html for full documentation.
ssm_get_maintenance_window_execution_task(WindowExecutionId, TaskId)[required] The ID of the maintenance window execution that includes the task.
[required] The ID of the specific task execution in the maintenance window task that should be retrieved.