Retrieves the patch baseline that should be used for the specified patch group.
See https://paws-r.github.io/docs/ssm/get_patch_baseline_for_patch_group.html for full documentation.
ssm_get_patch_baseline_for_patch_group(PatchGroup, OperatingSystem = NULL)[required] The name of the patch group whose patch baseline should be retrieved.
Returns the operating system rule specified for patch groups using the patch baseline.