Registers a patch baseline for a patch group.
See https://paws-r.github.io/docs/ssm/register_patch_baseline_for_patch_group.html for full documentation.
ssm_register_patch_baseline_for_patch_group(BaselineId, PatchGroup)[required] The ID of the patch baseline to register with the patch group.
[required] The name of the patch group to be registered with the patch baseline.