Set the default version of a document.
See https://paws-r.github.io/docs/ssm/update_document_default_version.html for full documentation.
ssm_update_document_default_version(Name, DocumentVersion)[required] The name of a custom document that you want to set as the default version.
[required] The version of a custom document that you want to set as the default version.