Updates information related to approval reviews for a specific version of a change template in Change Manager.
See https://paws-r.github.io/docs/ssm/update_document_metadata.html for full documentation.
ssm_update_document_metadata(Name, DocumentVersion = NULL, DocumentReviews)[required] The name of the change template for which a version's metadata is to be updated.
The version of a change template in which to update approval metadata.
[required] The change template review details to update.