Changes the Identity and Access Management (IAM) role that is assigned to the on-premises server, edge device, or virtual machines (VM). IAM roles are first assigned to these hybrid nodes during the activation process. For more information, see create_activation.
See https://paws-r.github.io/docs/ssm/update_managed_instance_role.html for full documentation.
ssm_update_managed_instance_role(InstanceId, IamRole)[required] The ID of the managed node where you want to update the role.
[required] The IAM role you want to assign or change.