ServiceSetting is an account-level setting for an Amazon Web Services service. This setting defines how a user interacts with or uses a service or a feature of a service. For example, if an Amazon Web Services service charges money to the account based on feature or service usage, then the Amazon Web Services service team might create a default setting of "false". This means the user can't use this feature unless they change the setting to "true" and intentionally opt in for a paid feature.
See https://paws-r.github.io/docs/ssm/update_service_setting.html for full documentation.
ssm_update_service_setting(SettingId, SettingValue)[required] The Amazon Resource Name (ARN) of the service setting to reset. For
example,
arn:aws:ssm:us-east-1:111122223333:servicesetting/ssm/parameter-store/high-throughput-enabled.
The setting ID can be one of the following.
/ssm/automation/customer-script-log-destination
/ssm/automation/customer-script-log-group-name
/ssm/documents/console/public-sharing-permission
/ssm/managed-instance/activation-tier
/ssm/opsinsights/opscenter
/ssm/parameter-store/default-parameter-tier
/ssm/parameter-store/high-throughput-enabled
[required] The new value to specify for the service setting. The following list specifies the available values for each setting.
/ssm/automation/customer-script-log-destination: CloudWatch
/ssm/automation/customer-script-log-group-name: the name of an
Amazon CloudWatch Logs log group
/ssm/documents/console/public-sharing-permission: Enable or
Disable
/ssm/managed-instance/activation-tier: standard or advanced
/ssm/opsinsights/opscenter: Enabled or Disabled
/ssm/parameter-store/default-parameter-tier: Standard,
Advanced, Intelligent-Tiering
/ssm/parameter-store/high-throughput-enabled: true or false