Lists all of the engagements to contact channels that have been acknowledged.
See https://paws-r.github.io/docs/ssmcontacts/list_page_receipts.html for full documentation.
ssmcontacts_list_page_receipts(PageId, NextToken = NULL, MaxResults = NULL)[required] The Amazon Resource Name (ARN) of the engagement to a specific contact channel.
The pagination token to continue to the next page of results.
The maximum number of acknowledgements per page of results.