Sends an activation code to a contact channel. The contact can use this code to activate the contact channel in the console or with the ActivateChannel operation. Incident Manager can't engage a contact channel until it has been activated.
See https://paws-r.github.io/docs/ssmcontacts/send_activation_code.html for full documentation.
ssmcontacts_send_activation_code(ContactChannelId)[required] The Amazon Resource Name (ARN) of the contact channel.