Retrieves the resource policies attached to the specified response plan.
See https://paws-r.github.io/docs/ssmincidents/get_resource_policies.html for full documentation.
ssmincidents_get_resource_policies(
maxResults = NULL,
nextToken = NULL,
resourceArn
)The maximum number of resource policies to display per page of results.
The pagination token to continue to the next page of results.
[required] The Amazon Resource Name (ARN) of the response plan with the attached resource policy.