Lists details about the replication set configured in your account.
See https://paws-r.github.io/docs/ssmincidents/list_replication_sets.html for full documentation.
ssmincidents_list_replication_sets(maxResults = NULL, nextToken = NULL)The maximum number of results per page.
The pagination token to continue to the next page of results.