Adds a resource policy to the specified response plan. The resource policy is used to share the response plan using Resource Access Manager (RAM). For more information about cross-account sharing, see Setting up cross-account functionality.
See https://paws-r.github.io/docs/ssmincidents/put_resource_policy.html for full documentation.
ssmincidents_put_resource_policy(policy, resourceArn)[required] Details of the resource policy.
[required] The Amazon Resource Name (ARN) of the response plan you're adding the resource policy to.