Update deletion protection to either allow or deny deletion of the final Region in a replication set.
See https://paws-r.github.io/docs/ssmincidents/update_deletion_protection.html for full documentation.
ssmincidents_update_deletion_protection(
arn,
clientToken = NULL,
deletionProtected
)[required] The Amazon Resource Name (ARN) of the replication set you're updating.
A token ensuring that the operation is called only once with the specified details.
[required] Details if deletion protection is enabled or disabled in your account.