Add or remove related items from the related items tab of an incident record.
See https://paws-r.github.io/docs/ssmincidents/update_related_items.html for full documentation.
ssmincidents_update_related_items(
clientToken = NULL,
incidentRecordArn,
relatedItemsUpdate
)A token ensuring that the operation is called only once with the specified details.
[required] The Amazon Resource Name (ARN) of the incident record containing the related items you are updating.
[required] Details about the item you are adding or deleting.