Returns the list of severity levels that you can assign to an AWS
Support case. The severity level for a case is also a field in the
CaseDetails data type that you include for a
create_case request.
You must have a Business or Enterprise support plan to use the AWS Support API.
If you call the AWS Support API from an account that does not have a
Business or Enterprise support plan, the
SubscriptionRequiredException error message appears. For
information about changing your support plan, see AWS Support.
support_describe_severity_levels(language)The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.
A list with the following syntax:
list(
severityLevels = list(
list(
code = "string",
name = "string"
)
)
)
svc$describe_severity_levels( language = "string" )