Returns the results of the Trusted Advisor check that has the specified check ID. You can get the check IDs by calling the describe_trusted_advisor_checks operation.
See https://paws-r.github.io/docs/support/describe_trusted_advisor_check_result.html for full documentation.
support_describe_trusted_advisor_check_result(checkId, language = NULL)[required] The unique identifier for the Trusted Advisor check.
The ISO 639-1 code for the language in which Amazon Web Services provides support. Amazon Web Services Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.