Permanently deletes the specified canary.
See https://paws-r.github.io/docs/synthetics/delete_canary.html for full documentation.
synthetics_delete_canary(Name, DeleteLambda = NULL)[required] The name of the canary that you want to delete. To find the names of
your canaries, use describe_canaries.
Specifies whether to also delete the Lambda functions and layers used by this canary. The default is false.
Type: Boolean