Removes a canary from a group. You must run this operation in the Region where the canary exists.
See https://paws-r.github.io/docs/synthetics/disassociate_resource.html for full documentation.
synthetics_disassociate_resource(GroupIdentifier, ResourceArn)[required] Specifies the group. You can specify the group name, the ARN, or the
group ID as the GroupIdentifier.
[required] The ARN of the canary that you want to remove from the specified group.